<?php

return [
    '🧑🏻‍❤‍💋‍🧑🏼' => 'bitsch: persuna, persuna, pel clera, pel mez clera',
    '🧑🏻‍❤‍💋‍🧑🏽' => 'bitsch: persuna, persuna, pel clera, pel media',
    '🧑🏻‍❤‍💋‍🧑🏾' => 'bitsch: persuna, persuna, pel clera, pel mez stgira',
    '🧑🏻‍❤‍💋‍🧑🏿' => 'bitsch: persuna, persuna, pel clera, pel stgira',
    '🧑🏼‍❤‍💋‍🧑🏻' => 'bitsch: persuna, persuna, pel mez clera, pel clera',
    '🧑🏼‍❤‍💋‍🧑🏽' => 'bitsch: persuna, persuna, pel mez clera, pel media',
    '🧑🏼‍❤‍💋‍🧑🏾' => 'bitsch: persuna, persuna, pel mez clera, pel mez stgira',
    '🧑🏼‍❤‍💋‍🧑🏿' => 'bitsch: persuna, persuna, pel mez clera, pel stgira',
    '🧑🏽‍❤‍💋‍🧑🏻' => 'bitsch: persuna, persuna, pel media, pel clera',
    '🧑🏽‍❤‍💋‍🧑🏼' => 'bitsch: persuna, persuna, pel media, pel mez clera',
    '🧑🏽‍❤‍💋‍🧑🏾' => 'bitsch: persuna, persuna, pel media, pel mez stgira',
    '🧑🏽‍❤‍💋‍🧑🏿' => 'bitsch: persuna, persuna, pel media, pel stgira',
    '🧑🏾‍❤‍💋‍🧑🏻' => 'bitsch: persuna, persuna, pel mez stgira, pel clera',
    '🧑🏾‍❤‍💋‍🧑🏼' => 'bitsch: persuna, persuna, pel mez stgira, pel mez clera',
    '🧑🏾‍❤‍💋‍🧑🏽' => 'bitsch: persuna, persuna, pel mez stgira, pel media',
    '🧑🏾‍❤‍💋‍🧑🏿' => 'bitsch: persuna, persuna, pel mez stgira, pel stgira',
    '🧑🏿‍❤‍💋‍🧑🏻' => 'bitsch: persuna, persuna, pel stgira, pel clera',
    '🧑🏿‍❤‍💋‍🧑🏼' => 'bitsch: persuna, persuna, pel stgira, pel mez clera',
    '🧑🏿‍❤‍💋‍🧑🏽' => 'bitsch: persuna, persuna, pel stgira, pel media',
    '🧑🏿‍❤‍💋‍🧑🏾' => 'bitsch: persuna, persuna, pel stgira, pel mez stgira',
    '👨🏻‍❤‍💋‍👨🏻' => 'bitsch: um, um, pel clera',
    '👨🏻‍❤‍💋‍👨🏼' => 'bitsch: um, um, pel clera, pel mez clera',
    '👨🏻‍❤‍💋‍👨🏽' => 'bitsch: um, um, pel clera, pel media',
    '👨🏻‍❤‍💋‍👨🏾' => 'bitsch: um, um, pel clera, pel mez stgira',
    '👨🏻‍❤‍💋‍👨🏿' => 'bitsch: um, um, pel clera, pel stgira',
    '👨🏼‍❤‍💋‍👨🏻' => 'bitsch: um, um, pel mez clera, pel clera',
    '👨🏼‍❤‍💋‍👨🏼' => 'bitsch: um, um, pel mez clera',
    '👨🏼‍❤‍💋‍👨🏽' => 'bitsch: um, um, pel mez clera, pel media',
    '👨🏼‍❤‍💋‍👨🏾' => 'bitsch: um, um, pel mez clera, pel mez stgira',
    '👨🏼‍❤‍💋‍👨🏿' => 'bitsch: um, um, pel mez clera, pel stgira',
    '👨🏽‍❤‍💋‍👨🏻' => 'bitsch: um, um, pel media, pel clera',
    '👨🏽‍❤‍💋‍👨🏼' => 'bitsch: um, um, pel media, pel mez clera',
    '👨🏽‍❤‍💋‍👨🏽' => 'bitsch: um, um, pel media',
    '👨🏽‍❤‍💋‍👨🏾' => 'bitsch: um, um, pel media, pel mez stgira',
    '👨🏽‍❤‍💋‍👨🏿' => 'bitsch: um, um, pel media, pel stgira',
    '👨🏾‍❤‍💋‍👨🏻' => 'bitsch: um, um, pel mez stgira, pel clera',
    '👨🏾‍❤‍💋‍👨🏼' => 'bitsch: um, um, pel mez stgira, pel mez clera',
    '👨🏾‍❤‍💋‍👨🏽' => 'bitsch: um, um, pel mez stgira, pel media',
    '👨🏾‍❤‍💋‍👨🏾' => 'bitsch: um, um, pel mez stgira',
    '👨🏾‍❤‍💋‍👨🏿' => 'bitsch: um, um, pel mez stgira, pel stgira',
    '👨🏿‍❤‍💋‍👨🏻' => 'bitsch: um, um, pel stgira, pel clera',
    '👨🏿‍❤‍💋‍👨🏼' => 'bitsch: um, um, pel stgira, pel mez clera',
    '👨🏿‍❤‍💋‍👨🏽' => 'bitsch: um, um, pel stgira, pel media',
    '👨🏿‍❤‍💋‍👨🏾' => 'bitsch: um, um, pel stgira, pel mez stgira',
    '👨🏿‍❤‍💋‍👨🏿' => 'bitsch: um, um, pel stgira',
    '👩🏻‍❤‍💋‍👨🏻' => 'bitsch: dunna, um, pel clera',
    '👩🏻‍❤‍💋‍👨🏼' => 'bitsch: dunna, um, pel clera, pel mez clera',
    '👩🏻‍❤‍💋‍👨🏽' => 'bitsch: dunna, um, pel clera, pel media',
    '👩🏻‍❤‍💋‍👨🏾' => 'bitsch: dunna, um, pel clera, pel mez stgira',
    '👩🏻‍❤‍💋‍👨🏿' => 'bitsch: dunna, um, pel clera, pel stgira',
    '👩🏼‍❤‍💋‍👨🏻' => 'bitsch: dunna, um, pel mez clera, pel clera',
    '👩🏼‍❤‍💋‍👨🏼' => 'bitsch: dunna, um, pel mez clera',
    '👩🏼‍❤‍💋‍👨🏽' => 'bitsch: dunna, um, pel mez clera, pel media',
    '👩🏼‍❤‍💋‍👨🏾' => 'bitsch: dunna, um, pel mez clera, pel mez stgira',
    '👩🏼‍❤‍💋‍👨🏿' => 'bitsch: dunna, um, pel mez clera, pel stgira',
    '👩🏽‍❤‍💋‍👨🏻' => 'bitsch: dunna, um, pel media, pel clera',
    '👩🏽‍❤‍💋‍👨🏼' => 'bitsch: dunna, um, pel media, pel mez clera',
    '👩🏽‍❤‍💋‍👨🏽' => 'bitsch: dunna, um, pel media',
    '👩🏽‍❤‍💋‍👨🏾' => 'bitsch: dunna, um, pel media, pel mez stgira',
    '👩🏽‍❤‍💋‍👨🏿' => 'bitsch: dunna, um, pel media, pel stgira',
    '👩🏾‍❤‍💋‍👨🏻' => 'bitsch: dunna, um, pel mez stgira, pel clera',
    '👩🏾‍❤‍💋‍👨🏼' => 'bitsch: dunna, um, pel mez stgira, pel mez clera',
    '👩🏾‍❤‍💋‍👨🏽' => 'bitsch: dunna, um, pel mez stgira, pel media',
    '👩🏾‍❤‍💋‍👨🏾' => 'bitsch: dunna, um, pel mez stgira',
    '👩🏾‍❤‍💋‍👨🏿' => 'bitsch: dunna, um, pel mez stgira, pel stgira',
    '👩🏿‍❤‍💋‍👨🏻' => 'bitsch: dunna, um, pel stgira, pel clera',
    '👩🏿‍❤‍💋‍👨🏼' => 'bitsch: dunna, um, pel stgira, pel mez clera',
    '👩🏿‍❤‍💋‍👨🏽' => 'bitsch: dunna, um, pel stgira, pel media',
    '👩🏿‍❤‍💋‍👨🏾' => 'bitsch: dunna, um, pel stgira, pel mez stgira',
    '👩🏿‍❤‍💋‍👨🏿' => 'bitsch: dunna, um, pel stgira',
    '👩🏻‍❤‍💋‍👩🏻' => 'bitsch: dunna, dunna, pel clera',
    '👩🏻‍❤‍💋‍👩🏼' => 'bitsch: dunna, dunna, pel clera, pel mez clera',
    '👩🏻‍❤‍💋‍👩🏽' => 'bitsch: dunna, dunna, pel clera, pel media',
    '👩🏻‍❤‍💋‍👩🏾' => 'bitsch: dunna, dunna, pel clera, pel mez stgira',
    '👩🏻‍❤‍💋‍👩🏿' => 'bitsch: dunna, dunna, pel clera, pel stgira',
    '👩🏼‍❤‍💋‍👩🏻' => 'bitsch: dunna, dunna, pel mez clera, pel clera',
    '👩🏼‍❤‍💋‍👩🏼' => 'bitsch: dunna, dunna, pel mez clera',
    '👩🏼‍❤‍💋‍👩🏽' => 'bitsch: dunna, dunna, pel mez clera, pel media',
    '👩🏼‍❤‍💋‍👩🏾' => 'bitsch: dunna, dunna, pel mez clera, pel mez stgira',
    '👩🏼‍❤‍💋‍👩🏿' => 'bitsch: dunna, dunna, pel mez clera, pel stgira',
    '👩🏽‍❤‍💋‍👩🏻' => 'bitsch: dunna, dunna, pel media, pel clera',
    '👩🏽‍❤‍💋‍👩🏼' => 'bitsch: dunna, dunna, pel media, pel mez clera',
    '👩🏽‍❤‍💋‍👩🏽' => 'bitsch: dunna, dunna, pel media',
    '👩🏽‍❤‍💋‍👩🏾' => 'bitsch: dunna, dunna, pel media, pel mez stgira',
    '👩🏽‍❤‍💋‍👩🏿' => 'bitsch: dunna, dunna, pel media, pel stgira',
    '👩🏾‍❤‍💋‍👩🏻' => 'bitsch: dunna, dunna, pel mez stgira, pel clera',
    '👩🏾‍❤‍💋‍👩🏼' => 'bitsch: dunna, dunna, pel mez stgira, pel mez clera',
    '👩🏾‍❤‍💋‍👩🏽' => 'bitsch: dunna, dunna, pel mez stgira, pel media',
    '👩🏾‍❤‍💋‍👩🏾' => 'bitsch: dunna, dunna, pel mez stgira',
    '👩🏾‍❤‍💋‍👩🏿' => 'bitsch: dunna, dunna, pel mez stgira, pel stgira',
    '👩🏿‍❤‍💋‍👩🏻' => 'bitsch: dunna, dunna, pel stgira, pel clera',
    '👩🏿‍❤‍💋‍👩🏼' => 'bitsch: dunna, dunna, pel stgira, pel mez clera',
    '👩🏿‍❤‍💋‍👩🏽' => 'bitsch: dunna, dunna, pel stgira, pel media',
    '👩🏿‍❤‍💋‍👩🏾' => 'bitsch: dunna, dunna, pel stgira, pel mez stgira',
    '👩🏿‍❤‍💋‍👩🏿' => 'bitsch: dunna, dunna, pel stgira',
    '🧑🏻‍🫯‍🧑🏼' => 'persunas che lutgan: pel clera, pel mez clera',
    '🧑🏻‍🫯‍🧑🏽' => 'persunas che lutgan: pel clera, pel media',
    '🧑🏻‍🫯‍🧑🏾' => 'persunas che lutgan: pel clera, pel mez stgira',
    '🧑🏻‍🫯‍🧑🏿' => 'persunas che lutgan: pel clera, pel stgira',
    '🧑🏼‍🫯‍🧑🏻' => 'persunas che lutgan: pel mez clera, pel clera',
    '🧑🏼‍🫯‍🧑🏽' => 'persunas che lutgan: pel mez clera, pel media',
    '🧑🏼‍🫯‍🧑🏾' => 'persunas che lutgan: pel mez clera, pel mez stgira',
    '🧑🏼‍🫯‍🧑🏿' => 'persunas che lutgan: pel mez clera, pel stgira',
    '🧑🏽‍🫯‍🧑🏻' => 'persunas che lutgan: pel media, pel clera',
    '🧑🏽‍🫯‍🧑🏼' => 'persunas che lutgan: pel media, pel mez clera',
    '🧑🏽‍🫯‍🧑🏾' => 'persunas che lutgan: pel media, pel mez stgira',
    '🧑🏽‍🫯‍🧑🏿' => 'persunas che lutgan: pel media, pel stgira',
    '🧑🏾‍🫯‍🧑🏻' => 'persunas che lutgan: pel mez stgira, pel clera',
    '🧑🏾‍🫯‍🧑🏼' => 'persunas che lutgan: pel mez stgira, pel mez clera',
    '🧑🏾‍🫯‍🧑🏽' => 'persunas che lutgan: pel mez stgira, pel media',
    '🧑🏾‍🫯‍🧑🏿' => 'persunas che lutgan: pel mez stgira, pel stgira',
    '🧑🏿‍🫯‍🧑🏻' => 'persunas che lutgan: pel stgira, pel clera',
    '🧑🏿‍🫯‍🧑🏼' => 'persunas che lutgan: pel stgira, pel mez clera',
    '🧑🏿‍🫯‍🧑🏽' => 'persunas che lutgan: pel stgira, pel media',
    '🧑🏿‍🫯‍🧑🏾' => 'persunas che lutgan: pel stgira, pel mez stgira',
    '🧑🏻‍❤‍🧑🏼' => 'pèr cun cor: persuna, persuna, pel clera, pel mez clera',
    '🧑🏻‍❤‍🧑🏽' => 'pèr cun cor: persuna, persuna, pel clera, pel media',
    '🧑🏻‍❤‍🧑🏾' => 'pèr cun cor: persuna, persuna, pel clera, pel mez stgira',
    '🧑🏻‍❤‍🧑🏿' => 'pèr cun cor: persuna, persuna, pel clera, pel stgira',
    '🧑🏼‍❤‍🧑🏻' => 'pèr cun cor: persuna, persuna, pel mez clera, pel clera',
    '🧑🏼‍❤‍🧑🏽' => 'pèr cun cor: persuna, persuna, pel mez clera, pel media',
    '🧑🏼‍❤‍🧑🏾' => 'pèr cun cor: persuna, persuna, pel mez clera, pel mez stgira',
    '🧑🏼‍❤‍🧑🏿' => 'pèr cun cor: persuna, persuna, pel mez clera, pel stgira',
    '🧑🏽‍❤‍🧑🏻' => 'pèr cun cor: persuna, persuna, pel media, pel clera',
    '🧑🏽‍❤‍🧑🏼' => 'pèr cun cor: persuna, persuna, pel media, pel mez clera',
    '🧑🏽‍❤‍🧑🏾' => 'pèr cun cor: persuna, persuna, pel media, pel mez stgira',
    '🧑🏽‍❤‍🧑🏿' => 'pèr cun cor: persuna, persuna, pel media, pel stgira',
    '🧑🏾‍❤‍🧑🏻' => 'pèr cun cor: persuna, persuna, pel mez stgira, pel clera',
    '🧑🏾‍❤‍🧑🏼' => 'pèr cun cor: persuna, persuna, pel mez stgira, pel mez clera',
    '🧑🏾‍❤‍🧑🏽' => 'pèr cun cor: persuna, persuna, pel mez stgira, pel media',
    '🧑🏾‍❤‍🧑🏿' => 'pèr cun cor: persuna, persuna, pel mez stgira, pel stgira',
    '🧑🏿‍❤‍🧑🏻' => 'pèr cun cor: persuna, persuna, pel stgira, pel clera',
    '🧑🏿‍❤‍🧑🏼' => 'pèr cun cor: persuna, persuna, pel stgira, pel mez clera',
    '🧑🏿‍❤‍🧑🏽' => 'pèr cun cor: persuna, persuna, pel stgira, pel media',
    '🧑🏿‍❤‍🧑🏾' => 'pèr cun cor: persuna, persuna, pel stgira, pel mez stgira',
    '🧑🏻‍🐰‍🧑🏼' => 'persunas cun ureglias da lieur: pel clera, pel mez clera',
    '🧑🏻‍🐰‍🧑🏽' => 'persunas cun ureglias da lieur: pel clera, pel media',
    '🧑🏻‍🐰‍🧑🏾' => 'persunas cun ureglias da lieur: pel clera, pel mez stgira',
    '🧑🏻‍🐰‍🧑🏿' => 'persunas cun ureglias da lieur: pel clera, pel stgira',
    '🧑🏼‍🐰‍🧑🏻' => 'persunas cun ureglias da lieur: pel mez clera, pel clera',
    '🧑🏼‍🐰‍🧑🏽' => 'persunas cun ureglias da lieur: pel mez clera, pel media',
    '🧑🏼‍🐰‍🧑🏾' => 'persunas cun ureglias da lieur: pel mez clera, pel mez stgira',
    '🧑🏼‍🐰‍🧑🏿' => 'persunas cun ureglias da lieur: pel mez clera, pel stgira',
    '🧑🏽‍🐰‍🧑🏻' => 'persunas cun ureglias da lieur: pel media, pel clera',
    '🧑🏽‍🐰‍🧑🏼' => 'persunas cun ureglias da lieur: pel media, pel mez clera',
    '🧑🏽‍🐰‍🧑🏾' => 'persunas cun ureglias da lieur: pel media, pel mez stgira',
    '🧑🏽‍🐰‍🧑🏿' => 'persunas cun ureglias da lieur: pel media, pel stgira',
    '🧑🏾‍🐰‍🧑🏻' => 'persunas cun ureglias da lieur: pel mez stgira, pel clera',
    '🧑🏾‍🐰‍🧑🏼' => 'persunas cun ureglias da lieur: pel mez stgira, pel mez clera',
    '🧑🏾‍🐰‍🧑🏽' => 'persunas cun ureglias da lieur: pel mez stgira, pel media',
    '🧑🏾‍🐰‍🧑🏿' => 'persunas cun ureglias da lieur: pel mez stgira, pel stgira',
    '🧑🏿‍🐰‍🧑🏻' => 'persunas cun ureglias da lieur: pel stgira, pel clera',
    '🧑🏿‍🐰‍🧑🏼' => 'persunas cun ureglias da lieur: pel stgira, pel mez clera',
    '🧑🏿‍🐰‍🧑🏽' => 'persunas cun ureglias da lieur: pel stgira, pel media',
    '🧑🏿‍🐰‍🧑🏾' => 'persunas cun ureglias da lieur: pel stgira, pel mez stgira',
    '👨🏻‍🫯‍👨🏼' => 'umens che lutgan: pel clera, pel mez clera',
    '👨🏻‍🫯‍👨🏽' => 'umens che lutgan: pel clera, pel media',
    '👨🏻‍🫯‍👨🏾' => 'umens che lutgan: pel clera, pel mez stgira',
    '👨🏻‍🫯‍👨🏿' => 'umens che lutgan: pel clera, pel stgira',
    '👨🏼‍🫯‍👨🏻' => 'umens che lutgan: pel mez clera, pel clera',
    '👨🏼‍🫯‍👨🏽' => 'umens che lutgan: pel mez clera, pel media',
    '👨🏼‍🫯‍👨🏾' => 'umens che lutgan: pel mez clera, pel mez stgira',
    '👨🏼‍🫯‍👨🏿' => 'umens che lutgan: pel mez clera, pel stgira',
    '👨🏽‍🫯‍👨🏻' => 'umens che lutgan: pel media, pel clera',
    '👨🏽‍🫯‍👨🏼' => 'umens che lutgan: pel media, pel mez clera',
    '👨🏽‍🫯‍👨🏾' => 'umens che lutgan: pel media, pel mez stgira',
    '👨🏽‍🫯‍👨🏿' => 'umens che lutgan: pel media, pel stgira',
    '👨🏾‍🫯‍👨🏻' => 'umens che lutgan: pel mez stgira, pel clera',
    '👨🏾‍🫯‍👨🏼' => 'umens che lutgan: pel mez stgira, pel mez clera',
    '👨🏾‍🫯‍👨🏽' => 'umens che lutgan: pel mez stgira, pel media',
    '👨🏾‍🫯‍👨🏿' => 'umens che lutgan: pel mez stgira, pel stgira',
    '👨🏿‍🫯‍👨🏻' => 'umens che lutgan: pel stgira, pel clera',
    '👨🏿‍🫯‍👨🏼' => 'umens che lutgan: pel stgira, pel mez clera',
    '👨🏿‍🫯‍👨🏽' => 'umens che lutgan: pel stgira, pel media',
    '👨🏿‍🫯‍👨🏾' => 'umens che lutgan: pel stgira, pel mez stgira',
    '👨🏻‍❤‍👨🏻' => 'pèr cun cor: um, um, pel clera',
    '👨🏻‍❤‍👨🏼' => 'pèr cun cor: um, um, pel clera, pel mez clera',
    '👨🏻‍❤‍👨🏽' => 'pèr cun cor: um, um, pel clera, pel media',
    '👨🏻‍❤‍👨🏾' => 'pèr cun cor: um, um, pel clera, pel mez stgira',
    '👨🏻‍❤‍👨🏿' => 'pèr cun cor: um, um, pel clera, pel stgira',
    '👨🏼‍❤‍👨🏻' => 'pèr cun cor: um, um, pel mez clera, pel clera',
    '👨🏼‍❤‍👨🏼' => 'pèr cun cor: um, um, pel mez clera',
    '👨🏼‍❤‍👨🏽' => 'pèr cun cor: um, um, pel mez clera, pel media',
    '👨🏼‍❤‍👨🏾' => 'pèr cun cor: um, um, pel mez clera, pel mez stgira',
    '👨🏼‍❤‍👨🏿' => 'pèr cun cor: um, um, pel mez clera, pel stgira',
    '👨🏽‍❤‍👨🏻' => 'pèr cun cor: um, um, pel media, pel clera',
    '👨🏽‍❤‍👨🏼' => 'pèr cun cor: um, um, pel media, pel mez clera',
    '👨🏽‍❤‍👨🏽' => 'pèr cun cor: um, um, pel media',
    '👨🏽‍❤‍👨🏾' => 'pèr cun cor: um, um, pel media, pel mez stgira',
    '👨🏽‍❤‍👨🏿' => 'pèr cun cor: um, um, pel media, pel stgira',
    '👨🏾‍❤‍👨🏻' => 'pèr cun cor: um, um, pel mez stgira, pel clera',
    '👨🏾‍❤‍👨🏼' => 'pèr cun cor: um, um, pel mez stgira, pel mez clera',
    '👨🏾‍❤‍👨🏽' => 'pèr cun cor: um, um, pel mez stgira, pel media',
    '👨🏾‍❤‍👨🏾' => 'pèr cun cor: um, um, pel mez stgira',
    '👨🏾‍❤‍👨🏿' => 'pèr cun cor: um, um, pel mez stgira, pel stgira',
    '👨🏿‍❤‍👨🏻' => 'pèr cun cor: um, um, pel stgira, pel clera',
    '👨🏿‍❤‍👨🏼' => 'pèr cun cor: um, um, pel stgira, pel mez clera',
    '👨🏿‍❤‍👨🏽' => 'pèr cun cor: um, um, pel stgira, pel media',
    '👨🏿‍❤‍👨🏾' => 'pèr cun cor: um, um, pel stgira, pel mez stgira',
    '👨🏿‍❤‍👨🏿' => 'pèr cun cor: um, um, pel stgira',
    '👨🏻‍🐰‍👨🏼' => 'umens cun ureglias da lieur: pel clera, pel mez clera',
    '👨🏻‍🐰‍👨🏽' => 'umens cun ureglias da lieur: pel clera, pel media',
    '👨🏻‍🐰‍👨🏾' => 'umens cun ureglias da lieur: pel clera, pel mez stgira',
    '👨🏻‍🐰‍👨🏿' => 'umens cun ureglias da lieur: pel clera, pel stgira',
    '👨🏼‍🐰‍👨🏻' => 'umens cun ureglias da lieur: pel mez clera, pel clera',
    '👨🏼‍🐰‍👨🏽' => 'umens cun ureglias da lieur: pel mez clera, pel media',
    '👨🏼‍🐰‍👨🏾' => 'umens cun ureglias da lieur: pel mez clera, pel mez stgira',
    '👨🏼‍🐰‍👨🏿' => 'umens cun ureglias da lieur: pel mez clera, pel stgira',
    '👨🏽‍🐰‍👨🏻' => 'umens cun ureglias da lieur: pel media, pel clera',
    '👨🏽‍🐰‍👨🏼' => 'umens cun ureglias da lieur: pel media, pel mez clera',
    '👨🏽‍🐰‍👨🏾' => 'umens cun ureglias da lieur: pel media, pel mez stgira',
    '👨🏽‍🐰‍👨🏿' => 'umens cun ureglias da lieur: pel media, pel stgira',
    '👨🏾‍🐰‍👨🏻' => 'umens cun ureglias da lieur: pel mez stgira, pel clera',
    '👨🏾‍🐰‍👨🏼' => 'umens cun ureglias da lieur: pel mez stgira, pel mez clera',
    '👨🏾‍🐰‍👨🏽' => 'umens cun ureglias da lieur: pel mez stgira, pel media',
    '👨🏾‍🐰‍👨🏿' => 'umens cun ureglias da lieur: pel mez stgira, pel stgira',
    '👨🏿‍🐰‍👨🏻' => 'umens cun ureglias da lieur: pel stgira, pel clera',
    '👨🏿‍🐰‍👨🏼' => 'umens cun ureglias da lieur: pel stgira, pel mez clera',
    '👨🏿‍🐰‍👨🏽' => 'umens cun ureglias da lieur: pel stgira, pel media',
    '👨🏿‍🐰‍👨🏾' => 'umens cun ureglias da lieur: pel stgira, pel mez stgira',
    '👩🏻‍🫯‍👩🏼' => 'dunnas che lutgan: pel clera, pel mez clera',
    '👩🏻‍🫯‍👩🏽' => 'dunnas che lutgan: pel clera, pel media',
    '👩🏻‍🫯‍👩🏾' => 'dunnas che lutgan: pel clera, pel mez stgira',
    '👩🏻‍🫯‍👩🏿' => 'dunnas che lutgan: pel clera, pel stgira',
    '👩🏼‍🫯‍👩🏻' => 'dunnas che lutgan: pel mez clera, pel clera',
    '👩🏼‍🫯‍👩🏽' => 'dunnas che lutgan: pel mez clera, pel media',
    '👩🏼‍🫯‍👩🏾' => 'dunnas che lutgan: pel mez clera, pel mez stgira',
    '👩🏼‍🫯‍👩🏿' => 'dunnas che lutgan: pel mez clera, pel stgira',
    '👩🏽‍🫯‍👩🏻' => 'dunnas che lutgan: pel media, pel clera',
    '👩🏽‍🫯‍👩🏼' => 'dunnas che lutgan: pel media, pel mez clera',
    '👩🏽‍🫯‍👩🏾' => 'dunnas che lutgan: pel media, pel mez stgira',
    '👩🏽‍🫯‍👩🏿' => 'dunnas che lutgan: pel media, pel stgira',
    '👩🏾‍🫯‍👩🏻' => 'dunnas che lutgan: pel mez stgira, pel clera',
    '👩🏾‍🫯‍👩🏼' => 'dunnas che lutgan: pel mez stgira, pel mez clera',
    '👩🏾‍🫯‍👩🏽' => 'dunnas che lutgan: pel mez stgira, pel media',
    '👩🏾‍🫯‍👩🏿' => 'dunnas che lutgan: pel mez stgira, pel stgira',
    '👩🏿‍🫯‍👩🏻' => 'dunnas che lutgan: pel stgira, pel clera',
    '👩🏿‍🫯‍👩🏼' => 'dunnas che lutgan: pel stgira, pel mez clera',
    '👩🏿‍🫯‍👩🏽' => 'dunnas che lutgan: pel stgira, pel media',
    '👩🏿‍🫯‍👩🏾' => 'dunnas che lutgan: pel stgira, pel mez stgira',
    '👩🏻‍❤‍👨🏻' => 'pèr cun cor: dunna, um, pel clera',
    '👩🏻‍❤‍👨🏼' => 'pèr cun cor: dunna, um, pel clera, pel mez clera',
    '👩🏻‍❤‍👨🏽' => 'pèr cun cor: dunna, um, pel clera, pel media',
    '👩🏻‍❤‍👨🏾' => 'pèr cun cor: dunna, um, pel clera, pel mez stgira',
    '👩🏻‍❤‍👨🏿' => 'pèr cun cor: dunna, um, pel clera, pel stgira',
    '👩🏼‍❤‍👨🏻' => 'pèr cun cor: dunna, um, pel mez clera, pel clera',
    '👩🏼‍❤‍👨🏼' => 'pèr cun cor: dunna, um, pel mez clera',
    '👩🏼‍❤‍👨🏽' => 'pèr cun cor: dunna, um, pel mez clera, pel media',
    '👩🏼‍❤‍👨🏾' => 'pèr cun cor: dunna, um, pel mez clera, pel mez stgira',
    '👩🏼‍❤‍👨🏿' => 'pèr cun cor: dunna, um, pel mez clera, pel stgira',
    '👩🏽‍❤‍👨🏻' => 'pèr cun cor: dunna, um, pel media, pel clera',
    '👩🏽‍❤‍👨🏼' => 'pèr cun cor: dunna, um, pel media, pel mez clera',
    '👩🏽‍❤‍👨🏽' => 'pèr cun cor: dunna, um, pel media',
    '👩🏽‍❤‍👨🏾' => 'pèr cun cor: dunna, um, pel media, pel mez stgira',
    '👩🏽‍❤‍👨🏿' => 'pèr cun cor: dunna, um, pel media, pel stgira',
    '👩🏾‍❤‍👨🏻' => 'pèr cun cor: dunna, um, pel mez stgira, pel clera',
    '👩🏾‍❤‍👨🏼' => 'pèr cun cor: dunna, um, pel mez stgira, pel mez clera',
    '👩🏾‍❤‍👨🏽' => 'pèr cun cor: dunna, um, pel mez stgira, pel media',
    '👩🏾‍❤‍👨🏾' => 'pèr cun cor: dunna, um, pel mez stgira',
    '👩🏾‍❤‍👨🏿' => 'pèr cun cor: dunna, um, pel mez stgira, pel stgira',
    '👩🏿‍❤‍👨🏻' => 'pèr cun cor: dunna, um, pel stgira, pel clera',
    '👩🏿‍❤‍👨🏼' => 'pèr cun cor: dunna, um, pel stgira, pel mez clera',
    '👩🏿‍❤‍👨🏽' => 'pèr cun cor: dunna, um, pel stgira, pel media',
    '👩🏿‍❤‍👨🏾' => 'pèr cun cor: dunna, um, pel stgira, pel mez stgira',
    '👩🏿‍❤‍👨🏿' => 'pèr cun cor: dunna, um, pel stgira',
    '👩🏻‍❤‍👩🏻' => 'pèr cun cor: dunna, dunna, pel clera',
    '👩🏻‍❤‍👩🏼' => 'pèr cun cor: dunna, dunna, pel clera, pel mez clera',
    '👩🏻‍❤‍👩🏽' => 'pèr cun cor: dunna, dunna, pel clera, pel media',
    '👩🏻‍❤‍👩🏾' => 'pèr cun cor: dunna, dunna, pel clera, pel mez stgira',
    '👩🏻‍❤‍👩🏿' => 'pèr cun cor: dunna, dunna, pel clera, pel stgira',
    '👩🏼‍❤‍👩🏻' => 'pèr cun cor: dunna, dunna, pel mez clera, pel clera',
    '👩🏼‍❤‍👩🏼' => 'pèr cun cor: dunna, dunna, pel mez clera',
    '👩🏼‍❤‍👩🏽' => 'pèr cun cor: dunna, dunna, pel mez clera, pel media',
    '👩🏼‍❤‍👩🏾' => 'pèr cun cor: dunna, dunna, pel mez clera, pel mez stgira',
    '👩🏼‍❤‍👩🏿' => 'pèr cun cor: dunna, dunna, pel mez clera, pel stgira',
    '👩🏽‍❤‍👩🏻' => 'pèr cun cor: dunna, dunna, pel media, pel clera',
    '👩🏽‍❤‍👩🏼' => 'pèr cun cor: dunna, dunna, pel media, pel mez clera',
    '👩🏽‍❤‍👩🏽' => 'pèr cun cor: dunna, dunna, pel media',
    '👩🏽‍❤‍👩🏾' => 'pèr cun cor: dunna, dunna, pel media, pel mez stgira',
    '👩🏽‍❤‍👩🏿' => 'pèr cun cor: dunna, dunna, pel media, pel stgira',
    '👩🏾‍❤‍👩🏻' => 'pèr cun cor: dunna, dunna, pel mez stgira, pel clera',
    '👩🏾‍❤‍👩🏼' => 'pèr cun cor: dunna, dunna, pel mez stgira, pel mez clera',
    '👩🏾‍❤‍👩🏽' => 'pèr cun cor: dunna, dunna, pel mez stgira, pel media',
    '👩🏾‍❤‍👩🏾' => 'pèr cun cor: dunna, dunna, pel mez stgira',
    '👩🏾‍❤‍👩🏿' => 'pèr cun cor: dunna, dunna, pel mez stgira, pel stgira',
    '👩🏿‍❤‍👩🏻' => 'pèr cun cor: dunna, dunna, pel stgira, pel clera',
    '👩🏿‍❤‍👩🏼' => 'pèr cun cor: dunna, dunna, pel stgira, pel mez clera',
    '👩🏿‍❤‍👩🏽' => 'pèr cun cor: dunna, dunna, pel stgira, pel media',
    '👩🏿‍❤‍👩🏾' => 'pèr cun cor: dunna, dunna, pel stgira, pel mez stgira',
    '👩🏿‍❤‍👩🏿' => 'pèr cun cor: dunna, dunna, pel stgira',
    '👩🏻‍🐰‍👩🏼' => 'dunnas cun ureglias da lieur: pel clera, pel mez clera',
    '👩🏻‍🐰‍👩🏽' => 'dunnas cun ureglias da lieur: pel clera, pel media',
    '👩🏻‍🐰‍👩🏾' => 'dunnas cun ureglias da lieur: pel clera, pel mez stgira',
    '👩🏻‍🐰‍👩🏿' => 'dunnas cun ureglias da lieur: pel clera, pel stgira',
    '👩🏼‍🐰‍👩🏻' => 'dunnas cun ureglias da lieur: pel mez clera, pel clera',
    '👩🏼‍🐰‍👩🏽' => 'dunnas cun ureglias da lieur: pel mez clera, pel media',
    '👩🏼‍🐰‍👩🏾' => 'dunnas cun ureglias da lieur: pel mez clera, pel mez stgira',
    '👩🏼‍🐰‍👩🏿' => 'dunnas cun ureglias da lieur: pel mez clera, pel stgira',
    '👩🏽‍🐰‍👩🏻' => 'dunnas cun ureglias da lieur: pel media, pel clera',
    '👩🏽‍🐰‍👩🏼' => 'dunnas cun ureglias da lieur: pel media, pel mez clera',
    '👩🏽‍🐰‍👩🏾' => 'dunnas cun ureglias da lieur: pel media, pel mez stgira',
    '👩🏽‍🐰‍👩🏿' => 'dunnas cun ureglias da lieur: pel media, pel stgira',
    '👩🏾‍🐰‍👩🏻' => 'dunnas cun ureglias da lieur: pel mez stgira, pel clera',
    '👩🏾‍🐰‍👩🏼' => 'dunnas cun ureglias da lieur: pel mez stgira, pel mez clera',
    '👩🏾‍🐰‍👩🏽' => 'dunnas cun ureglias da lieur: pel mez stgira, pel media',
    '👩🏾‍🐰‍👩🏿' => 'dunnas cun ureglias da lieur: pel mez stgira, pel stgira',
    '👩🏿‍🐰‍👩🏻' => 'dunnas cun ureglias da lieur: pel stgira, pel clera',
    '👩🏿‍🐰‍👩🏼' => 'dunnas cun ureglias da lieur: pel stgira, pel mez clera',
    '👩🏿‍🐰‍👩🏽' => 'dunnas cun ureglias da lieur: pel stgira, pel media',
    '👩🏿‍🐰‍👩🏾' => 'dunnas cun ureglias da lieur: pel stgira, pel mez stgira',
    '🧑🏻‍🤝‍🧑🏻' => 'persunas che tegnan il maun: pel clera',
    '🧑🏻‍🤝‍🧑🏼' => 'persunas che tegnan il maun: pel clera, pel mez clera',
    '🧑🏻‍🤝‍🧑🏽' => 'persunas che tegnan il maun: pel clera, pel media',
    '🧑🏻‍🤝‍🧑🏾' => 'persunas che tegnan il maun: pel clera, pel mez stgira',
    '🧑🏻‍🤝‍🧑🏿' => 'persunas che tegnan il maun: pel clera, pel stgira',
    '🧑🏼‍🤝‍🧑🏻' => 'persunas che tegnan il maun: pel mez clera, pel clera',
    '🧑🏼‍🤝‍🧑🏼' => 'persunas che tegnan il maun: pel mez clera',
    '🧑🏼‍🤝‍🧑🏽' => 'persunas che tegnan il maun: pel mez clera, pel media',
    '🧑🏼‍🤝‍🧑🏾' => 'persunas che tegnan il maun: pel mez clera, pel mez stgira',
    '🧑🏼‍🤝‍🧑🏿' => 'persunas che tegnan il maun: pel mez clera, pel stgira',
    '🧑🏽‍🤝‍🧑🏻' => 'persunas che tegnan il maun: pel media, pel clera',
    '🧑🏽‍🤝‍🧑🏼' => 'persunas che tegnan il maun: pel media, pel mez clera',
    '🧑🏽‍🤝‍🧑🏽' => 'persunas che tegnan il maun: pel media',
    '🧑🏽‍🤝‍🧑🏾' => 'persunas che tegnan il maun: pel media, pel mez stgira',
    '🧑🏽‍🤝‍🧑🏿' => 'persunas che tegnan il maun: pel media, pel stgira',
    '🧑🏾‍🤝‍🧑🏻' => 'persunas che tegnan il maun: pel mez stgira, pel clera',
    '🧑🏾‍🤝‍🧑🏼' => 'persunas che tegnan il maun: pel mez stgira, pel mez clera',
    '🧑🏾‍🤝‍🧑🏽' => 'persunas che tegnan il maun: pel mez stgira, pel media',
    '🧑🏾‍🤝‍🧑🏾' => 'persunas che tegnan il maun: pel mez stgira',
    '🧑🏾‍🤝‍🧑🏿' => 'persunas che tegnan il maun: pel mez stgira, pel stgira',
    '🧑🏿‍🤝‍🧑🏻' => 'persunas che tegnan il maun: pel stgira, pel clera',
    '🧑🏿‍🤝‍🧑🏼' => 'persunas che tegnan il maun: pel stgira, pel mez clera',
    '🧑🏿‍🤝‍🧑🏽' => 'persunas che tegnan il maun: pel stgira, pel media',
    '🧑🏿‍🤝‍🧑🏾' => 'persunas che tegnan il maun: pel stgira, pel mez stgira',
    '🧑🏿‍🤝‍🧑🏿' => 'persunas che tegnan il maun: pel stgira',
    '👩🏻‍🤝‍👩🏼' => 'dunnas che tegnan il maun: pel clera, pel mez clera',
    '👩🏻‍🤝‍👩🏽' => 'dunnas che tegnan il maun: pel clera, pel media',
    '👩🏻‍🤝‍👩🏾' => 'dunnas che tegnan il maun: pel clera, pel mez stgira',
    '👩🏻‍🤝‍👩🏿' => 'dunnas che tegnan il maun: pel clera, pel stgira',
    '👩🏼‍🤝‍👩🏻' => 'dunnas che tegnan il maun: pel mez clera, pel clera',
    '👩🏼‍🤝‍👩🏽' => 'dunnas che tegnan il maun: pel mez clera, pel media',
    '👩🏼‍🤝‍👩🏾' => 'dunnas che tegnan il maun: pel mez clera, pel mez stgira',
    '👩🏼‍🤝‍👩🏿' => 'dunnas che tegnan il maun: pel mez clera, pel stgira',
    '👩🏽‍🤝‍👩🏻' => 'dunnas che tegnan il maun: pel media, pel clera',
    '👩🏽‍🤝‍👩🏼' => 'dunnas che tegnan il maun: pel media, pel mez clera',
    '👩🏽‍🤝‍👩🏾' => 'dunnas che tegnan il maun: pel media, pel mez stgira',
    '👩🏽‍🤝‍👩🏿' => 'dunnas che tegnan il maun: pel media, pel stgira',
    '👩🏾‍🤝‍👩🏻' => 'dunnas che tegnan il maun: pel mez stgira, pel clera',
    '👩🏾‍🤝‍👩🏼' => 'dunnas che tegnan il maun: pel mez stgira, pel mez clera',
    '👩🏾‍🤝‍👩🏽' => 'dunnas che tegnan il maun: pel mez stgira, pel media',
    '👩🏾‍🤝‍👩🏿' => 'dunnas che tegnan il maun: pel mez stgira, pel stgira',
    '👩🏿‍🤝‍👩🏻' => 'dunnas che tegnan il maun: pel stgira, pel clera',
    '👩🏿‍🤝‍👩🏼' => 'dunnas che tegnan il maun: pel stgira, pel mez clera',
    '👩🏿‍🤝‍👩🏽' => 'dunnas che tegnan il maun: pel stgira, pel media',
    '👩🏿‍🤝‍👩🏾' => 'dunnas che tegnan il maun: pel stgira, pel mez stgira',
    '👩🏻‍🤝‍👨🏼' => 'dunna ed um che tegnan ils mauns: pel clera, pel mez clera',
    '👩🏻‍🤝‍👨🏽' => 'dunna ed um che tegnan ils mauns: pel clera, pel media',
    '👩🏻‍🤝‍👨🏾' => 'dunna ed um che tegnan ils mauns: pel clera, pel mez stgira',
    '👩🏻‍🤝‍👨🏿' => 'dunna ed um che tegnan ils mauns: pel clera, pel stgira',
    '👩🏼‍🤝‍👨🏻' => 'dunna ed um che tegnan ils mauns: pel mez clera, pel clera',
    '👩🏼‍🤝‍👨🏽' => 'dunna ed um che tegnan ils mauns: pel mez clera, pel media',
    '👩🏼‍🤝‍👨🏾' => 'dunna ed um che tegnan ils mauns: pel mez clera, pel mez stgira',
    '👩🏼‍🤝‍👨🏿' => 'dunna ed um che tegnan ils mauns: pel mez clera, pel stgira',
    '👩🏽‍🤝‍👨🏻' => 'dunna ed um che tegnan ils mauns: pel media, pel clera',
    '👩🏽‍🤝‍👨🏼' => 'dunna ed um che tegnan ils mauns: pel media, pel mez clera',
    '👩🏽‍🤝‍👨🏾' => 'dunna ed um che tegnan ils mauns: pel media, pel mez stgira',
    '👩🏽‍🤝‍👨🏿' => 'dunna ed um che tegnan ils mauns: pel media, pel stgira',
    '👩🏾‍🤝‍👨🏻' => 'dunna ed um che tegnan ils mauns: pel mez stgira, pel clera',
    '👩🏾‍🤝‍👨🏼' => 'dunna ed um che tegnan ils mauns: pel mez stgira, pel mez clera',
    '👩🏾‍🤝‍👨🏽' => 'dunna ed um che tegnan ils mauns: pel mez stgira, pel media',
    '👩🏾‍🤝‍👨🏿' => 'dunna ed um che tegnan ils mauns: pel mez stgira, pel stgira',
    '👩🏿‍🤝‍👨🏻' => 'dunna ed um che tegnan ils mauns: pel stgira, pel clera',
    '👩🏿‍🤝‍👨🏼' => 'dunna ed um che tegnan ils mauns: pel stgira, pel mez clera',
    '👩🏿‍🤝‍👨🏽' => 'dunna ed um che tegnan ils mauns: pel stgira, pel media',
    '👩🏿‍🤝‍👨🏾' => 'dunna ed um che tegnan ils mauns: pel stgira, pel mez stgira',
    '👨🏻‍🤝‍👨🏼' => 'umens che tegnan il maun: pel clera, pel mez clera',
    '👨🏻‍🤝‍👨🏽' => 'umens che tegnan il maun: pel clera, pel media',
    '👨🏻‍🤝‍👨🏾' => 'umens che tegnan il maun: pel clera, pel mez stgira',
    '👨🏻‍🤝‍👨🏿' => 'umens che tegnan il maun: pel clera, pel stgira',
    '👨🏼‍🤝‍👨🏻' => 'umens che tegnan il maun: pel mez clera, pel clera',
    '👨🏼‍🤝‍👨🏽' => 'umens che tegnan il maun: pel mez clera, pel media',
    '👨🏼‍🤝‍👨🏾' => 'umens che tegnan il maun: pel mez clera, pel mez stgira',
    '👨🏼‍🤝‍👨🏿' => 'umens che tegnan il maun: pel mez clera, pel stgira',
    '👨🏽‍🤝‍👨🏻' => 'umens che tegnan il maun: pel media, pel clera',
    '👨🏽‍🤝‍👨🏼' => 'umens che tegnan il maun: pel media, pel mez clera',
    '👨🏽‍🤝‍👨🏾' => 'umens che tegnan il maun: pel media, pel mez stgira',
    '👨🏽‍🤝‍👨🏿' => 'umens che tegnan il maun: pel media, pel stgira',
    '👨🏾‍🤝‍👨🏻' => 'umens che tegnan il maun: pel mez stgira, pel clera',
    '👨🏾‍🤝‍👨🏼' => 'umens che tegnan il maun: pel mez stgira, pel mez clera',
    '👨🏾‍🤝‍👨🏽' => 'umens che tegnan il maun: pel mez stgira, pel media',
    '👨🏾‍🤝‍👨🏿' => 'umens che tegnan il maun: pel mez stgira, pel stgira',
    '👨🏿‍🤝‍👨🏻' => 'umens che tegnan il maun: pel stgira, pel clera',
    '👨🏿‍🤝‍👨🏼' => 'umens che tegnan il maun: pel stgira, pel mez clera',
    '👨🏿‍🤝‍👨🏽' => 'umens che tegnan il maun: pel stgira, pel media',
    '👨🏿‍🤝‍👨🏾' => 'umens che tegnan il maun: pel stgira, pel mez stgira',
    '👩‍❤‍💋‍👨' => 'bitsch: dunna, um',
    '👨‍❤‍💋‍👨' => 'bitsch: um, um',
    '👩‍❤‍💋‍👩' => 'bitsch: dunna, dunna',
    '👨‍👩‍👧‍👦' => 'famiglia: um, dunna, mattetta, mattet',
    '👨‍👩‍👦‍👦' => 'famiglia: um, dunna, mattet, mattet',
    '👨‍👩‍👧‍👧' => 'famiglia: um, dunna, mattetta, mattetta',
    '👨‍👨‍👧‍👦' => 'famiglia: um, um, mattetta, mattet',
    '👨‍👨‍👦‍👦' => 'famiglia: um, um, mattet, mattet',
    '👨‍👨‍👧‍👧' => 'famiglia: um, um, mattetta, mattetta',
    '👩‍👩‍👧‍👦' => 'famiglia: dunna, dunna, mattetta, mattet',
    '👩‍👩‍👦‍👦' => 'famiglia: dunna, dunna, mattet, mattet',
    '👩‍👩‍👧‍👧' => 'famiglia: dunna, dunna, mattetta, mattetta',
    '🧑‍🧑‍🧒‍🧒' => 'famiglia: persuna creschida, persuna creschida, uffant, uffant',
    '🚶🏻‍♀‍➡' => 'dunna che va a pe: pel clera, a dretga',
    '🚶🏼‍♀‍➡' => 'dunna che va a pe: pel mez clera, a dretga',
    '🚶🏽‍♀‍➡' => 'dunna che va a pe: pel media, a dretga',
    '🚶🏾‍♀‍➡' => 'dunna che va a pe: pel mez stgira, a dretga',
    '🚶🏿‍♀‍➡' => 'dunna che va a pe: pel stgira, a dretga',
    '🚶🏻‍♂‍➡' => 'um che va a pe: pel clera, a dretga',
    '🚶🏼‍♂‍➡' => 'um che va a pe: pel mez clera, a dretga',
    '🚶🏽‍♂‍➡' => 'um che va a pe: pel media, a dretga',
    '🚶🏾‍♂‍➡' => 'um che va a pe: pel mez stgira, a dretga',
    '🚶🏿‍♂‍➡' => 'um che va a pe: pel stgira, a dretga',
    '🧎🏻‍♀‍➡' => 'dunna en schanuglias: pel clera, a dretga',
    '🧎🏼‍♀‍➡' => 'dunna en schanuglias: pel mez clera, a dretga',
    '🧎🏽‍♀‍➡' => 'dunna en schanuglias: pel media, a dretga',
    '🧎🏾‍♀‍➡' => 'dunna en schanuglias: pel mez stgira, a dretga',
    '🧎🏿‍♀‍➡' => 'dunna en schanuglias: pel stgira, a dretga',
    '🧎🏻‍♂‍➡' => 'um en schanuglias: pel clera, a dretga',
    '🧎🏼‍♂‍➡' => 'um en schanuglias: pel mez clera, a dretga',
    '🧎🏽‍♂‍➡' => 'um en schanuglias: pel media, a dretga',
    '🧎🏾‍♂‍➡' => 'um en schanuglias: pel mez stgira, a dretga',
    '🧎🏿‍♂‍➡' => 'um en schanuglias: pel stgira, a dretga',
    '🧑🏻‍🦯‍➡' => 'persuna cun ina channa da tschorvs: pel clera, a dretga',
    '🧑🏼‍🦯‍➡' => 'persuna cun ina channa da tschorvs: pel mez clera, a dretga',
    '🧑🏽‍🦯‍➡' => 'persuna cun ina channa da tschorvs: pel media, a dretga',
    '🧑🏾‍🦯‍➡' => 'persuna cun ina channa da tschorvs: pel mez stgira, a dretga',
    '🧑🏿‍🦯‍➡' => 'persuna cun ina channa da tschorvs: pel stgira, a dretga',
    '👨🏻‍🦯‍➡' => 'um cun channa: pel clera, a dretga',
    '👨🏼‍🦯‍➡' => 'um cun channa: pel mez clera, a dretga',
    '👨🏽‍🦯‍➡' => 'um cun channa: pel media, a dretga',
    '👨🏾‍🦯‍➡' => 'um cun channa: pel mez stgira, a dretga',
    '👨🏿‍🦯‍➡' => 'um cun channa: pel stgira, a dretga',
    '👩🏻‍🦯‍➡' => 'dunna cun channa: pel clera, a dretga',
    '👩🏼‍🦯‍➡' => 'dunna cun channa: pel mez clera, a dretga',
    '👩🏽‍🦯‍➡' => 'dunna cun channa: pel media, a dretga',
    '👩🏾‍🦯‍➡' => 'dunna cun channa: pel mez stgira, a dretga',
    '👩🏿‍🦯‍➡' => 'dunna cun channa: pel stgira, a dretga',
    '🧑🏻‍🦼‍➡' => 'persuna en ina sutga cun rodas electrica: pel clera, a dretga',
    '🧑🏼‍🦼‍➡' => 'persuna en ina sutga cun rodas electrica: pel mez clera, a dretga',
    '🧑🏽‍🦼‍➡' => 'persuna en ina sutga cun rodas electrica: pel media, a dretga',
    '🧑🏾‍🦼‍➡' => 'persuna en ina sutga cun rodas electrica: pel mez stgira, a dretga',
    '🧑🏿‍🦼‍➡' => 'persuna en ina sutga cun rodas electrica: pel stgira, a dretga',
    '👨🏻‍🦼‍➡' => 'um en ina sutga cun rodas electrica: pel clera, a dretga',
    '👨🏼‍🦼‍➡' => 'um en ina sutga cun rodas electrica: pel mez clera, a dretga',
    '👨🏽‍🦼‍➡' => 'um en ina sutga cun rodas electrica: pel media, a dretga',
    '👨🏾‍🦼‍➡' => 'um en ina sutga cun rodas electrica: pel mez stgira, a dretga',
    '👨🏿‍🦼‍➡' => 'um en ina sutga cun rodas electrica: pel stgira, a dretga',
    '👩🏻‍🦼‍➡' => 'dunna en ina sutga cun rodas electrica: pel clera, a dretga',
    '👩🏼‍🦼‍➡' => 'dunna en ina sutga cun rodas electrica: pel mez clera, a dretga',
    '👩🏽‍🦼‍➡' => 'dunna en ina sutga cun rodas electrica: pel media, a dretga',
    '👩🏾‍🦼‍➡' => 'dunna en ina sutga cun rodas electrica: pel mez stgira, a dretga',
    '👩🏿‍🦼‍➡' => 'dunna en ina sutga cun rodas electrica: pel stgira, a dretga',
    '🧑🏻‍🦽‍➡' => 'persuna en ina sutga cun rodas manuala: pel clera, a dretga',
    '🧑🏼‍🦽‍➡' => 'persuna en ina sutga cun rodas manuala: pel mez clera, a dretga',
    '🧑🏽‍🦽‍➡' => 'persuna en ina sutga cun rodas manuala: pel media, a dretga',
    '🧑🏾‍🦽‍➡' => 'persuna en ina sutga cun rodas manuala: pel mez stgira, a dretga',
    '🧑🏿‍🦽‍➡' => 'persuna en ina sutga cun rodas manuala: pel stgira, a dretga',
    '👨🏻‍🦽‍➡' => 'um en ina sutga cun rodas manuala: pel clera, a dretga',
    '👨🏼‍🦽‍➡' => 'um en ina sutga cun rodas manuala: pel mez clera, a dretga',
    '👨🏽‍🦽‍➡' => 'um en ina sutga cun rodas manuala: pel media, a dretga',
    '👨🏾‍🦽‍➡' => 'um en ina sutga cun rodas manuala: pel mez stgira, a dretga',
    '👨🏿‍🦽‍➡' => 'um en ina sutga cun rodas manuala: pel stgira, a dretga',
    '👩🏻‍🦽‍➡' => 'dunna en ina sutga cun rodas manuala: pel clera, a dretga',
    '👩🏼‍🦽‍➡' => 'dunna en ina sutga cun rodas manuala: pel mez clera, a dretga',
    '👩🏽‍🦽‍➡' => 'dunna en ina sutga cun rodas manuala: pel media, a dretga',
    '👩🏾‍🦽‍➡' => 'dunna en ina sutga cun rodas manuala: pel mez stgira, a dretga',
    '👩🏿‍🦽‍➡' => 'dunna en ina sutga cun rodas manuala: pel stgira, a dretga',
    '🏃🏻‍♀‍➡' => 'dunna che curra: pel clera, a dretga',
    '🏃🏼‍♀‍➡' => 'dunna che curra: pel mez clera, a dretga',
    '🏃🏽‍♀‍➡' => 'dunna che curra: pel media, a dretga',
    '🏃🏾‍♀‍➡' => 'dunna che curra: pel mez stgira, a dretga',
    '🏃🏿‍♀‍➡' => 'dunna che curra: pel stgira, a dretga',
    '🏃🏻‍♂‍➡' => 'um che curra: pel clera, a dretga',
    '🏃🏼‍♂‍➡' => 'um che curra: pel mez clera, a dretga',
    '🏃🏽‍♂‍➡' => 'um che curra: pel media, a dretga',
    '🏃🏾‍♂‍➡' => 'um che curra: pel mez stgira, a dretga',
    '🏃🏿‍♂‍➡' => 'um che curra: pel stgira, a dretga',
    '🫱🏻‍🫲🏼' => 'dar il maun: pel clera, pel mez clera',
    '🫱🏻‍🫲🏽' => 'dar il maun: pel clera, pel media',
    '🫱🏻‍🫲🏾' => 'dar il maun: pel clera, pel mez stgira',
    '🫱🏻‍🫲🏿' => 'dar il maun: pel clera, pel stgira',
    '🫱🏼‍🫲🏻' => 'dar il maun: pel mez clera, pel clera',
    '🫱🏼‍🫲🏽' => 'dar il maun: pel mez clera, pel media',
    '🫱🏼‍🫲🏾' => 'dar il maun: pel mez clera, pel mez stgira',
    '🫱🏼‍🫲🏿' => 'dar il maun: pel mez clera, pel stgira',
    '🫱🏽‍🫲🏻' => 'dar il maun: pel media, pel clera',
    '🫱🏽‍🫲🏼' => 'dar il maun: pel media, pel mez clera',
    '🫱🏽‍🫲🏾' => 'dar il maun: pel media, pel mez stgira',
    '🫱🏽‍🫲🏿' => 'dar il maun: pel media, pel stgira',
    '🫱🏾‍🫲🏻' => 'dar il maun: pel mez stgira, pel clera',
    '🫱🏾‍🫲🏼' => 'dar il maun: pel mez stgira, pel mez clera',
    '🫱🏾‍🫲🏽' => 'dar il maun: pel mez stgira, pel media',
    '🫱🏾‍🫲🏿' => 'dar il maun: pel mez stgira, pel stgira',
    '🫱🏿‍🫲🏻' => 'dar il maun: pel stgira, pel clera',
    '🫱🏿‍🫲🏼' => 'dar il maun: pel stgira, pel mez clera',
    '🫱🏿‍🫲🏽' => 'dar il maun: pel stgira, pel media',
    '🫱🏿‍🫲🏾' => 'dar il maun: pel stgira, pel mez stgira',
    '🚶‍♀‍➡' => 'dunna che va a pe: a dretga',
    '🚶‍♂‍➡' => 'um che va a pe: a dretga',
    '🧎‍♀‍➡' => 'dunna en schanuglias: a dretga',
    '🧎‍♂‍➡' => 'um en schanuglias: a dretga',
    '🧑‍🦯‍➡' => 'persuna cun ina channa da tschorvs: a dretga',
    '👨‍🦯‍➡' => 'um cun channa: a dretga',
    '👩‍🦯‍➡' => 'dunna cun channa: a dretga',
    '🧑‍🦼‍➡' => 'persuna en ina sutga cun rodas electrica: a dretga',
    '👨‍🦼‍➡' => 'um en ina sutga cun rodas electrica: a dretga',
    '👩‍🦼‍➡' => 'dunna en ina sutga cun rodas electrica: a dretga',
    '🧑‍🦽‍➡' => 'persuna en ina sutga cun rodas manuala: a dretga',
    '👨‍🦽‍➡' => 'um en ina sutga cun rodas manuala: a dretga',
    '👩‍🦽‍➡' => 'dunna en ina sutga cun rodas manuala: a dretga',
    '🏃‍♀‍➡' => 'dunna che curra: a dretga',
    '🏃‍♂‍➡' => 'um che curra: a dretga',
    '👩‍❤‍👨' => 'pèr cun cor: dunna, um',
    '👨‍❤‍👨' => 'pèr cun cor: um, um',
    '👩‍❤‍👩' => 'pèr cun cor: dunna, dunna',
    '👨‍👩‍👦' => 'famiglia: um, dunna, mattet',
    '👨‍👩‍👧' => 'famiglia: um, dunna, mattetta',
    '👨‍👨‍👦' => 'famiglia: um, um, mattet',
    '👨‍👨‍👧' => 'famiglia: um, um, mattetta',
    '👩‍👩‍👦' => 'famiglia: dunna, dunna, mattet',
    '👩‍👩‍👧' => 'famiglia: dunna, dunna, mattetta',
    '👨‍👦‍👦' => 'famiglia: um, mattet, mattet',
    '👨‍👧‍👦' => 'famiglia: um, mattetta, mattet',
    '👨‍👧‍👧' => 'famiglia: um, mattetta, mattetta',
    '👩‍👦‍👦' => 'famiglia: dunna, mattet, mattet',
    '👩‍👧‍👦' => 'famiglia: dunna, mattetta, mattet',
    '👩‍👧‍👧' => 'famiglia: dunna, mattetta, mattetta',
    '🧑‍🤝‍🧑' => 'persunas che tegnan il maun',
    '🧑‍🧑‍🧒' => 'famiglia: persuna creschida, persuna creschida, uffant',
    '🧑‍🧒‍🧒' => 'famiglia: persuna creschida, uffant, uffant',
    '🧑🏻‍🦰' => 'persuna: pel clera, chavels cotschens',
    '🧑🏼‍🦰' => 'persuna: pel mez clera, chavels cotschens',
    '🧑🏽‍🦰' => 'persuna: pel media, chavels cotschens',
    '🧑🏾‍🦰' => 'persuna: pel mez stgira, chavels cotschens',
    '🧑🏿‍🦰' => 'persuna: pel stgira, chavels cotschens',
    '🧑🏻‍🦱' => 'persuna: pel clera, chavels ritschads',
    '🧑🏼‍🦱' => 'persuna: pel mez clera, chavels ritschads',
    '🧑🏽‍🦱' => 'persuna: pel media, chavels ritschads',
    '🧑🏾‍🦱' => 'persuna: pel mez stgira, chavels ritschads',
    '🧑🏿‍🦱' => 'persuna: pel stgira, chavels ritschads',
    '🧑🏻‍🦳' => 'persuna: pel clera, chavels alvs',
    '🧑🏼‍🦳' => 'persuna: pel mez clera, chavels alvs',
    '🧑🏽‍🦳' => 'persuna: pel media, chavels alvs',
    '🧑🏾‍🦳' => 'persuna: pel mez stgira, chavels alvs',
    '🧑🏿‍🦳' => 'persuna: pel stgira, chavels alvs',
    '🧑🏻‍🦲' => 'persuna: pel clera, chau blut',
    '🧑🏼‍🦲' => 'persuna: pel mez clera, chau blut',
    '🧑🏽‍🦲' => 'persuna: pel media, chau blut',
    '🧑🏾‍🦲' => 'persuna: pel mez stgira, chau blut',
    '🧑🏿‍🦲' => 'persuna: pel stgira, chau blut',
    '🧑🏻‍🩰' => 'ballarin:a: pel clera',
    '🧑🏼‍🩰' => 'ballarin:a: pel mez clera',
    '🧑🏽‍🩰' => 'ballarin:a: pel media',
    '🧑🏾‍🩰' => 'ballarin:a: pel mez stgira',
    '🧑🏿‍🩰' => 'ballarin:a: pel stgira',
    '🧔🏻‍♂' => 'um: pel clera, barba',
    '🧔🏼‍♂' => 'um: pel mez clera, barba',
    '🧔🏽‍♂' => 'um: pel media, barba',
    '🧔🏾‍♂' => 'um: pel mez stgira, barba',
    '🧔🏿‍♂' => 'um: pel stgira, barba',
    '👱🏻‍♂' => 'um: pel clera, chavels blonds',
    '👱🏼‍♂' => 'um: pel mez clera, chavels blonds',
    '👱🏽‍♂' => 'um: pel media, chavels blonds',
    '👱🏾‍♂' => 'um: pel mez stgira, chavels blonds',
    '👱🏿‍♂' => 'um: pel stgira, chavels blonds',
    '👨🏻‍🦰' => 'um: pel clera, chavels cotschens',
    '👨🏼‍🦰' => 'um: pel mez clera, chavels cotschens',
    '👨🏽‍🦰' => 'um: pel media, chavels cotschens',
    '👨🏾‍🦰' => 'um: pel mez stgira, chavels cotschens',
    '👨🏿‍🦰' => 'um: pel stgira, chavels cotschens',
    '👨🏻‍🦱' => 'um: pel clera, chavels ritschads',
    '👨🏼‍🦱' => 'um: pel mez clera, chavels ritschads',
    '👨🏽‍🦱' => 'um: pel media, chavels ritschads',
    '👨🏾‍🦱' => 'um: pel mez stgira, chavels ritschads',
    '👨🏿‍🦱' => 'um: pel stgira, chavels ritschads',
    '👨🏻‍🦳' => 'um: pel clera, chavels alvs',
    '👨🏼‍🦳' => 'um: pel mez clera, chavels alvs',
    '👨🏽‍🦳' => 'um: pel media, chavels alvs',
    '👨🏾‍🦳' => 'um: pel mez stgira, chavels alvs',
    '👨🏿‍🦳' => 'um: pel stgira, chavels alvs',
    '👨🏻‍🦲' => 'um: pel clera, chau blut',
    '👨🏼‍🦲' => 'um: pel mez clera, chau blut',
    '👨🏽‍🦲' => 'um: pel media, chau blut',
    '👨🏾‍🦲' => 'um: pel mez stgira, chau blut',
    '👨🏿‍🦲' => 'um: pel stgira, chau blut',
    '🧔🏻‍♀' => 'dunna: pel clera, barba',
    '🧔🏼‍♀' => 'dunna: pel mez clera, barba',
    '🧔🏽‍♀' => 'dunna: pel media, barba',
    '🧔🏾‍♀' => 'dunna: pel mez stgira, barba',
    '🧔🏿‍♀' => 'dunna: pel stgira, barba',
    '👱🏻‍♀' => 'dunna: pel clera, chavels blonds',
    '👱🏼‍♀' => 'dunna: pel mez clera, chavels blonds',
    '👱🏽‍♀' => 'dunna: pel media, chavels blonds',
    '👱🏾‍♀' => 'dunna: pel mez stgira, chavels blonds',
    '👱🏿‍♀' => 'dunna: pel stgira, chavels blonds',
    '👩🏻‍🦰' => 'dunna: pel clera, chavels cotschens',
    '👩🏼‍🦰' => 'dunna: pel mez clera, chavels cotschens',
    '👩🏽‍🦰' => 'dunna: pel media, chavels cotschens',
    '👩🏾‍🦰' => 'dunna: pel mez stgira, chavels cotschens',
    '👩🏿‍🦰' => 'dunna: pel stgira, chavels cotschens',
    '👩🏻‍🦱' => 'dunna: pel clera, chavels ritschads',
    '👩🏼‍🦱' => 'dunna: pel mez clera, chavels ritschads',
    '👩🏽‍🦱' => 'dunna: pel media, chavels ritschads',
    '👩🏾‍🦱' => 'dunna: pel mez stgira, chavels ritschads',
    '👩🏿‍🦱' => 'dunna: pel stgira, chavels ritschads',
    '👩🏻‍🦳' => 'dunna: pel clera, chavels alvs',
    '👩🏼‍🦳' => 'dunna: pel mez clera, chavels alvs',
    '👩🏽‍🦳' => 'dunna: pel media, chavels alvs',
    '👩🏾‍🦳' => 'dunna: pel mez stgira, chavels alvs',
    '👩🏿‍🦳' => 'dunna: pel stgira, chavels alvs',
    '👩🏻‍🦲' => 'dunna: pel clera, chau blut',
    '👩🏼‍🦲' => 'dunna: pel mez clera, chau blut',
    '👩🏽‍🦲' => 'dunna: pel media, chau blut',
    '👩🏾‍🦲' => 'dunna: pel mez stgira, chau blut',
    '👩🏿‍🦲' => 'dunna: pel stgira, chau blut',
    '🙍🏻‍♂' => 'um malcuntent: pel clera',
    '🙍🏼‍♂' => 'um malcuntent: pel mez clera',
    '🙍🏽‍♂' => 'um malcuntent: pel media',
    '🙍🏾‍♂' => 'um malcuntent: pel mez stgira',
    '🙍🏿‍♂' => 'um malcuntent: pel stgira',
    '🙍🏻‍♀' => 'dunna malcuntenta: pel clera',
    '🙍🏼‍♀' => 'dunna malcuntenta: pel mez clera',
    '🙍🏽‍♀' => 'dunna malcuntenta: pel media',
    '🙍🏾‍♀' => 'dunna malcuntenta: pel mez stgira',
    '🙍🏿‍♀' => 'dunna malcuntenta: pel stgira',
    '🙎🏻‍♂' => 'um permalà: pel clera',
    '🙎🏼‍♂' => 'um permalà: pel mez clera',
    '🙎🏽‍♂' => 'um permalà: pel media',
    '🙎🏾‍♂' => 'um permalà: pel mez stgira',
    '🙎🏿‍♂' => 'um permalà: pel stgira',
    '🙎🏻‍♀' => 'dunna permalada: pel clera',
    '🙎🏼‍♀' => 'dunna permalada: pel mez clera',
    '🙎🏽‍♀' => 'dunna permalada: pel media',
    '🙎🏾‍♀' => 'dunna permalada: pel mez stgira',
    '🙎🏿‍♀' => 'dunna permalada: pel stgira',
    '🙅🏻‍♂' => 'um cun bratscha cruschada: pel clera',
    '🙅🏼‍♂' => 'um cun bratscha cruschada: pel mez clera',
    '🙅🏽‍♂' => 'um cun bratscha cruschada: pel media',
    '🙅🏾‍♂' => 'um cun bratscha cruschada: pel mez stgira',
    '🙅🏿‍♂' => 'um cun bratscha cruschada: pel stgira',
    '🙅🏻‍♀' => 'dunna cun bratscha cruschada: pel clera',
    '🙅🏼‍♀' => 'dunna cun bratscha cruschada: pel mez clera',
    '🙅🏽‍♀' => 'dunna cun bratscha cruschada: pel media',
    '🙅🏾‍♀' => 'dunna cun bratscha cruschada: pel mez stgira',
    '🙅🏿‍♀' => 'dunna cun bratscha cruschada: pel stgira',
    '🙆🏻‍♂' => 'um che tegna ils mauns sin il chau: pel clera',
    '🙆🏼‍♂' => 'um che tegna ils mauns sin il chau: pel mez clera',
    '🙆🏽‍♂' => 'um che tegna ils mauns sin il chau: pel media',
    '🙆🏾‍♂' => 'um che tegna ils mauns sin il chau: pel mez stgira',
    '🙆🏿‍♂' => 'um che tegna ils mauns sin il chau: pel stgira',
    '🙆🏻‍♀' => 'dunna che tegna ils mauns sin il chau: pel clera',
    '🙆🏼‍♀' => 'dunna che tegna ils mauns sin il chau: pel mez clera',
    '🙆🏽‍♀' => 'dunna che tegna ils mauns sin il chau: pel media',
    '🙆🏾‍♀' => 'dunna che tegna ils mauns sin il chau: pel mez stgira',
    '🙆🏿‍♀' => 'dunna che tegna ils mauns sin il chau: pel stgira',
    '💁🏻‍♂' => 'um che tegna la palma-maun vers ensi: pel clera',
    '💁🏼‍♂' => 'um che tegna la palma-maun vers ensi: pel mez clera',
    '💁🏽‍♂' => 'um che tegna la palma-maun vers ensi: pel media',
    '💁🏾‍♂' => 'um che tegna la palma-maun vers ensi: pel mez stgira',
    '💁🏿‍♂' => 'um che tegna la palma-maun vers ensi: pel stgira',
    '💁🏻‍♀' => 'dunna che tegna la palma-maun vers ensi: pel clera',
    '💁🏼‍♀' => 'dunna che tegna la palma-maun vers ensi: pel mez clera',
    '💁🏽‍♀' => 'dunna che tegna la palma-maun vers ensi: pel media',
    '💁🏾‍♀' => 'dunna che tegna la palma-maun vers ensi: pel mez stgira',
    '💁🏿‍♀' => 'dunna che tegna la palma-maun vers ensi: pel stgira',
    '🙋🏻‍♂' => 'um che auza il maun: pel clera',
    '🙋🏼‍♂' => 'um che auza il maun: pel mez clera',
    '🙋🏽‍♂' => 'um che auza il maun: pel media',
    '🙋🏾‍♂' => 'um che auza il maun: pel mez stgira',
    '🙋🏿‍♂' => 'um che auza il maun: pel stgira',
    '🙋🏻‍♀' => 'dunna che auza il maun: pel clera',
    '🙋🏼‍♀' => 'dunna che auza il maun: pel mez clera',
    '🙋🏽‍♀' => 'dunna che auza il maun: pel media',
    '🙋🏾‍♀' => 'dunna che auza il maun: pel mez stgira',
    '🙋🏿‍♀' => 'dunna che auza il maun: pel stgira',
    '🧏🏻‍♂' => 'um surd: pel clera',
    '🧏🏼‍♂' => 'um surd: pel mez clera',
    '🧏🏽‍♂' => 'um surd: pel media',
    '🧏🏾‍♂' => 'um surd: pel mez stgira',
    '🧏🏿‍♂' => 'um surd: pel stgira',
    '🧏🏻‍♀' => 'dunna surda: pel clera',
    '🧏🏼‍♀' => 'dunna surda: pel mez clera',
    '🧏🏽‍♀' => 'dunna surda: pel media',
    '🧏🏾‍♀' => 'dunna surda: pel mez stgira',
    '🧏🏿‍♀' => 'dunna surda: pel stgira',
    '🙇🏻‍♂' => 'um che s’enclina: pel clera',
    '🙇🏼‍♂' => 'um che s’enclina: pel mez clera',
    '🙇🏽‍♂' => 'um che s’enclina: pel media',
    '🙇🏾‍♂' => 'um che s’enclina: pel mez stgira',
    '🙇🏿‍♂' => 'um che s’enclina: pel stgira',
    '🙇🏻‍♀' => 'dunna che s’enclina: pel clera',
    '🙇🏼‍♀' => 'dunna che s’enclina: pel mez clera',
    '🙇🏽‍♀' => 'dunna che s’enclina: pel media',
    '🙇🏾‍♀' => 'dunna che s’enclina: pel mez stgira',
    '🙇🏿‍♀' => 'dunna che s’enclina: pel stgira',
    '🤦🏻‍♂' => 'um cun la palma-maun sin la fatscha: pel clera',
    '🤦🏼‍♂' => 'um cun la palma-maun sin la fatscha: pel mez clera',
    '🤦🏽‍♂' => 'um cun la palma-maun sin la fatscha: pel media',
    '🤦🏾‍♂' => 'um cun la palma-maun sin la fatscha: pel mez stgira',
    '🤦🏿‍♂' => 'um cun la palma-maun sin la fatscha: pel stgira',
    '🤦🏻‍♀' => 'dunna cun la palma-maun sin la fatscha: pel clera',
    '🤦🏼‍♀' => 'dunna cun la palma-maun sin la fatscha: pel mez clera',
    '🤦🏽‍♀' => 'dunna cun la palma-maun sin la fatscha: pel media',
    '🤦🏾‍♀' => 'dunna cun la palma-maun sin la fatscha: pel mez stgira',
    '🤦🏿‍♀' => 'dunna cun la palma-maun sin la fatscha: pel stgira',
    '🤷🏻‍♂' => 'um che auza las spatlas: pel clera',
    '🤷🏼‍♂' => 'um che auza las spatlas: pel mez clera',
    '🤷🏽‍♂' => 'um che auza las spatlas: pel media',
    '🤷🏾‍♂' => 'um che auza las spatlas: pel mez stgira',
    '🤷🏿‍♂' => 'um che auza las spatlas: pel stgira',
    '🤷🏻‍♀' => 'dunna che auza las spatlas: pel clera',
    '🤷🏼‍♀' => 'dunna che auza las spatlas: pel mez clera',
    '🤷🏽‍♀' => 'dunna che auza las spatlas: pel media',
    '🤷🏾‍♀' => 'dunna che auza las spatlas: pel mez stgira',
    '🤷🏿‍♀' => 'dunna che auza las spatlas: pel stgira',
    '🧑🏻‍⚕' => 'persuna che lavura en il sectur da la sanadad: pel clera',
    '🧑🏼‍⚕' => 'persuna che lavura en il sectur da la sanadad: pel mez clera',
    '🧑🏽‍⚕' => 'persuna che lavura en il sectur da la sanadad: pel media',
    '🧑🏾‍⚕' => 'persuna che lavura en il sectur da la sanadad: pel mez stgira',
    '🧑🏿‍⚕' => 'persuna che lavura en il sectur da la sanadad: pel stgira',
    '👨🏻‍⚕' => 'um che lavura en il sectur da la sanadad: pel clera',
    '👨🏼‍⚕' => 'um che lavura en il sectur da la sanadad: pel mez clera',
    '👨🏽‍⚕' => 'um che lavura en il sectur da la sanadad: pel media',
    '👨🏾‍⚕' => 'um che lavura en il sectur da la sanadad: pel mez stgira',
    '👨🏿‍⚕' => 'um che lavura en il sectur da la sanadad: pel stgira',
    '👩🏻‍⚕' => 'dunna che lavura en il sectur da la sanadad: pel clera',
    '👩🏼‍⚕' => 'dunna che lavura en il sectur da la sanadad: pel mez clera',
    '👩🏽‍⚕' => 'dunna che lavura en il sectur da la sanadad: pel media',
    '👩🏾‍⚕' => 'dunna che lavura en il sectur da la sanadad: pel mez stgira',
    '👩🏿‍⚕' => 'dunna che lavura en il sectur da la sanadad: pel stgira',
    '🧑🏻‍🎓' => 'student:a: pel clera',
    '🧑🏼‍🎓' => 'student:a: pel mez clera',
    '🧑🏽‍🎓' => 'student:a: pel media',
    '🧑🏾‍🎓' => 'student:a: pel mez stgira',
    '🧑🏿‍🎓' => 'student:a: pel stgira',
    '👨🏻‍🎓' => 'student: pel clera',
    '👨🏼‍🎓' => 'student: pel mez clera',
    '👨🏽‍🎓' => 'student: pel media',
    '👨🏾‍🎓' => 'student: pel mez stgira',
    '👨🏿‍🎓' => 'student: pel stgira',
    '👩🏻‍🎓' => 'studenta: pel clera',
    '👩🏼‍🎓' => 'studenta: pel mez clera',
    '👩🏽‍🎓' => 'studenta: pel media',
    '👩🏾‍🎓' => 'studenta: pel mez stgira',
    '👩🏿‍🎓' => 'studenta: pel stgira',
    '🧑🏻‍🏫' => 'scolast:a: pel clera',
    '🧑🏼‍🏫' => 'scolast:a: pel mez clera',
    '🧑🏽‍🏫' => 'scolast:a: pel media',
    '🧑🏾‍🏫' => 'scolast:a: pel mez stgira',
    '🧑🏿‍🏫' => 'scolast:a: pel stgira',
    '👨🏻‍🏫' => 'scolast: pel clera',
    '👨🏼‍🏫' => 'scolast: pel mez clera',
    '👨🏽‍🏫' => 'scolast: pel media',
    '👨🏾‍🏫' => 'scolast: pel mez stgira',
    '👨🏿‍🏫' => 'scolast: pel stgira',
    '👩🏻‍🏫' => 'scolasta: pel clera',
    '👩🏼‍🏫' => 'scolasta: pel mez clera',
    '👩🏽‍🏫' => 'scolasta: pel media',
    '👩🏾‍🏫' => 'scolasta: pel mez stgira',
    '👩🏿‍🏫' => 'scolasta: pel stgira',
    '🧑🏻‍⚖' => 'derschad:ra: pel clera',
    '🧑🏼‍⚖' => 'derschad:ra: pel mez clera',
    '🧑🏽‍⚖' => 'derschad:ra: pel media',
    '🧑🏾‍⚖' => 'derschad:ra: pel mez stgira',
    '🧑🏿‍⚖' => 'derschad:ra: pel stgira',
    '👨🏻‍⚖' => 'derschader: pel clera',
    '👨🏼‍⚖' => 'derschader: pel mez clera',
    '👨🏽‍⚖' => 'derschader: pel media',
    '👨🏾‍⚖' => 'derschader: pel mez stgira',
    '👨🏿‍⚖' => 'derschader: pel stgira',
    '👩🏻‍⚖' => 'derschadra: pel clera',
    '👩🏼‍⚖' => 'derschadra: pel mez clera',
    '👩🏽‍⚖' => 'derschadra: pel media',
    '👩🏾‍⚖' => 'derschadra: pel mez stgira',
    '👩🏿‍⚖' => 'derschadra: pel stgira',
    '🧑🏻‍🌾' => 'pur:a: pel clera',
    '🧑🏼‍🌾' => 'pur:a: pel mez clera',
    '🧑🏽‍🌾' => 'pur:a: pel media',
    '🧑🏾‍🌾' => 'pur:a: pel mez stgira',
    '🧑🏿‍🌾' => 'pur:a: pel stgira',
    '👨🏻‍🌾' => 'pur: pel clera',
    '👨🏼‍🌾' => 'pur: pel mez clera',
    '👨🏽‍🌾' => 'pur: pel media',
    '👨🏾‍🌾' => 'pur: pel mez stgira',
    '👨🏿‍🌾' => 'pur: pel stgira',
    '👩🏻‍🌾' => 'pura: pel clera',
    '👩🏼‍🌾' => 'pura: pel mez clera',
    '👩🏽‍🌾' => 'pura: pel media',
    '👩🏾‍🌾' => 'pura: pel mez stgira',
    '👩🏿‍🌾' => 'pura: pel stgira',
    '🧑🏻‍🍳' => 'cuschinier:a: pel clera',
    '🧑🏼‍🍳' => 'cuschinier:a: pel mez clera',
    '🧑🏽‍🍳' => 'cuschinier:a: pel media',
    '🧑🏾‍🍳' => 'cuschinier:a: pel mez stgira',
    '🧑🏿‍🍳' => 'cuschinier:a: pel stgira',
    '👨🏻‍🍳' => 'cuschinier: pel clera',
    '👨🏼‍🍳' => 'cuschinier: pel mez clera',
    '👨🏽‍🍳' => 'cuschinier: pel media',
    '👨🏾‍🍳' => 'cuschinier: pel mez stgira',
    '👨🏿‍🍳' => 'cuschinier: pel stgira',
    '👩🏻‍🍳' => 'cuschiniera: pel clera',
    '👩🏼‍🍳' => 'cuschiniera: pel mez clera',
    '👩🏽‍🍳' => 'cuschiniera: pel media',
    '👩🏾‍🍳' => 'cuschiniera: pel mez stgira',
    '👩🏿‍🍳' => 'cuschiniera: pel stgira',
    '🧑🏻‍🔧' => 'mecanist:a: pel clera',
    '🧑🏼‍🔧' => 'mecanist:a: pel mez clera',
    '🧑🏽‍🔧' => 'mecanist:a: pel media',
    '🧑🏾‍🔧' => 'mecanist:a: pel mez stgira',
    '🧑🏿‍🔧' => 'mecanist:a: pel stgira',
    '👨🏻‍🔧' => 'mecanist: pel clera',
    '👨🏼‍🔧' => 'mecanist: pel mez clera',
    '👨🏽‍🔧' => 'mecanist: pel media',
    '👨🏾‍🔧' => 'mecanist: pel mez stgira',
    '👨🏿‍🔧' => 'mecanist: pel stgira',
    '👩🏻‍🔧' => 'mecanista: pel clera',
    '👩🏼‍🔧' => 'mecanista: pel mez clera',
    '👩🏽‍🔧' => 'mecanista: pel media',
    '👩🏾‍🔧' => 'mecanista: pel mez stgira',
    '👩🏿‍🔧' => 'mecanista: pel stgira',
    '🧑🏻‍🏭' => 'persuna che lavura en fabrica: pel clera',
    '🧑🏼‍🏭' => 'persuna che lavura en fabrica: pel mez clera',
    '🧑🏽‍🏭' => 'persuna che lavura en fabrica: pel media',
    '🧑🏾‍🏭' => 'persuna che lavura en fabrica: pel mez stgira',
    '🧑🏿‍🏭' => 'persuna che lavura en fabrica: pel stgira',
    '👨🏻‍🏭' => 'um che lavura en fabrica: pel clera',
    '👨🏼‍🏭' => 'um che lavura en fabrica: pel mez clera',
    '👨🏽‍🏭' => 'um che lavura en fabrica: pel media',
    '👨🏾‍🏭' => 'um che lavura en fabrica: pel mez stgira',
    '👨🏿‍🏭' => 'um che lavura en fabrica: pel stgira',
    '👩🏻‍🏭' => 'dunna che lavura en fabrica: pel clera',
    '👩🏼‍🏭' => 'dunna che lavura en fabrica: pel mez clera',
    '👩🏽‍🏭' => 'dunna che lavura en fabrica: pel media',
    '👩🏾‍🏭' => 'dunna che lavura en fabrica: pel mez stgira',
    '👩🏿‍🏭' => 'dunna che lavura en fabrica: pel stgira',
    '🧑🏻‍💼' => 'birolist:a: pel clera',
    '🧑🏼‍💼' => 'birolist:a: pel mez clera',
    '🧑🏽‍💼' => 'birolist:a: pel media',
    '🧑🏾‍💼' => 'birolist:a: pel mez stgira',
    '🧑🏿‍💼' => 'birolist:a: pel stgira',
    '👨🏻‍💼' => 'birolist: pel clera',
    '👨🏼‍💼' => 'birolist: pel mez clera',
    '👨🏽‍💼' => 'birolist: pel media',
    '👨🏾‍💼' => 'birolist: pel mez stgira',
    '👨🏿‍💼' => 'birolist: pel stgira',
    '👩🏻‍💼' => 'birolista: pel clera',
    '👩🏼‍💼' => 'birolista: pel mez clera',
    '👩🏽‍💼' => 'birolista: pel media',
    '👩🏾‍💼' => 'birolista: pel mez stgira',
    '👩🏿‍💼' => 'birolista: pel stgira',
    '🧑🏻‍🔬' => 'scienzia:da: pel clera',
    '🧑🏼‍🔬' => 'scienzia:da: pel mez clera',
    '🧑🏽‍🔬' => 'scienzia:da: pel media',
    '🧑🏾‍🔬' => 'scienzia:da: pel mez stgira',
    '🧑🏿‍🔬' => 'scienzia:da: pel stgira',
    '👨🏻‍🔬' => 'scienzià: pel clera',
    '👨🏼‍🔬' => 'scienzià: pel mez clera',
    '👨🏽‍🔬' => 'scienzià: pel media',
    '👨🏾‍🔬' => 'scienzià: pel mez stgira',
    '👨🏿‍🔬' => 'scienzià: pel stgira',
    '👩🏻‍🔬' => 'scienziada: pel clera',
    '👩🏼‍🔬' => 'scienziada: pel mez clera',
    '👩🏽‍🔬' => 'scienziada: pel media',
    '👩🏾‍🔬' => 'scienziada: pel mez stgira',
    '👩🏿‍🔬' => 'scienziada: pel stgira',
    '🧑🏻‍💻' => 'tecnolog:a: pel clera',
    '🧑🏼‍💻' => 'tecnolog:a: pel mez clera',
    '🧑🏽‍💻' => 'tecnolog:a: pel media',
    '🧑🏾‍💻' => 'tecnolog:a: pel mez stgira',
    '🧑🏿‍💻' => 'tecnolog:a: pel stgira',
    '👨🏻‍💻' => 'tecnolog: pel clera',
    '👨🏼‍💻' => 'tecnolog: pel mez clera',
    '👨🏽‍💻' => 'tecnolog: pel media',
    '👨🏾‍💻' => 'tecnolog: pel mez stgira',
    '👨🏿‍💻' => 'tecnolog: pel stgira',
    '👩🏻‍💻' => 'tecnologa: pel clera',
    '👩🏼‍💻' => 'tecnologa: pel mez clera',
    '👩🏽‍💻' => 'tecnologa: pel media',
    '👩🏾‍💻' => 'tecnologa: pel mez stgira',
    '👩🏿‍💻' => 'tecnologa: pel stgira',
    '🧑🏻‍🎤' => 'chantadur:a: pel clera',
    '🧑🏼‍🎤' => 'chantadur:a: pel mez clera',
    '🧑🏽‍🎤' => 'chantadur:a: pel media',
    '🧑🏾‍🎤' => 'chantadur:a: pel mez stgira',
    '🧑🏿‍🎤' => 'chantadur:a: pel stgira',
    '👨🏻‍🎤' => 'chantadur: pel clera',
    '👨🏼‍🎤' => 'chantadur: pel mez clera',
    '👨🏽‍🎤' => 'chantadur: pel media',
    '👨🏾‍🎤' => 'chantadur: pel mez stgira',
    '👨🏿‍🎤' => 'chantadur: pel stgira',
    '👩🏻‍🎤' => 'chantadura: pel clera',
    '👩🏼‍🎤' => 'chantadura: pel mez clera',
    '👩🏽‍🎤' => 'chantadura: pel media',
    '👩🏾‍🎤' => 'chantadura: pel mez stgira',
    '👩🏿‍🎤' => 'chantadura: pel stgira',
    '🧑🏻‍🎨' => 'pictur:a artist:a: pel clera',
    '🧑🏼‍🎨' => 'pictur:a artist:a: pel mez clera',
    '🧑🏽‍🎨' => 'pictur:a artist:a: pel media',
    '🧑🏾‍🎨' => 'pictur:a artist:a: pel mez stgira',
    '🧑🏿‍🎨' => 'pictur:a artist:a: pel stgira',
    '👨🏻‍🎨' => 'pictur artist: pel clera',
    '👨🏼‍🎨' => 'pictur artist: pel mez clera',
    '👨🏽‍🎨' => 'pictur artist: pel media',
    '👨🏾‍🎨' => 'pictur artist: pel mez stgira',
    '👨🏿‍🎨' => 'pictur artist: pel stgira',
    '👩🏻‍🎨' => 'pictura artista: pel clera',
    '👩🏼‍🎨' => 'pictura artista: pel mez clera',
    '👩🏽‍🎨' => 'pictura artista: pel media',
    '👩🏾‍🎨' => 'pictura artista: pel mez stgira',
    '👩🏿‍🎨' => 'pictura artista: pel stgira',
    '🧑🏻‍✈' => 'pilot:a: pel clera',
    '🧑🏼‍✈' => 'pilot:a: pel mez clera',
    '🧑🏽‍✈' => 'pilot:a: pel media',
    '🧑🏾‍✈' => 'pilot:a: pel mez stgira',
    '🧑🏿‍✈' => 'pilot:a: pel stgira',
    '👨🏻‍✈' => 'pilot: pel clera',
    '👨🏼‍✈' => 'pilot: pel mez clera',
    '👨🏽‍✈' => 'pilot: pel media',
    '👨🏾‍✈' => 'pilot: pel mez stgira',
    '👨🏿‍✈' => 'pilot: pel stgira',
    '👩🏻‍✈' => 'pilota: pel clera',
    '👩🏼‍✈' => 'pilota: pel mez clera',
    '👩🏽‍✈' => 'pilota: pel media',
    '👩🏾‍✈' => 'pilota: pel mez stgira',
    '👩🏿‍✈' => 'pilota: pel stgira',
    '🧑🏻‍🚀' => 'astronaut:a: pel clera',
    '🧑🏼‍🚀' => 'astronaut:a: pel mez clera',
    '🧑🏽‍🚀' => 'astronaut:a: pel media',
    '🧑🏾‍🚀' => 'astronaut:a: pel mez stgira',
    '🧑🏿‍🚀' => 'astronaut:a: pel stgira',
    '👨🏻‍🚀' => 'astronaut: pel clera',
    '👨🏼‍🚀' => 'astronaut: pel mez clera',
    '👨🏽‍🚀' => 'astronaut: pel media',
    '👨🏾‍🚀' => 'astronaut: pel mez stgira',
    '👨🏿‍🚀' => 'astronaut: pel stgira',
    '👩🏻‍🚀' => 'astronauta: pel clera',
    '👩🏼‍🚀' => 'astronauta: pel mez clera',
    '👩🏽‍🚀' => 'astronauta: pel media',
    '👩🏾‍🚀' => 'astronauta: pel mez stgira',
    '👩🏿‍🚀' => 'astronauta: pel stgira',
    '🧑🏻‍🚒' => 'pumpier:a: pel clera',
    '🧑🏼‍🚒' => 'pumpier:a: pel mez clera',
    '🧑🏽‍🚒' => 'pumpier:a: pel media',
    '🧑🏾‍🚒' => 'pumpier:a: pel mez stgira',
    '🧑🏿‍🚒' => 'pumpier:a: pel stgira',
    '👨🏻‍🚒' => 'pumpier: pel clera',
    '👨🏼‍🚒' => 'pumpier: pel mez clera',
    '👨🏽‍🚒' => 'pumpier: pel media',
    '👨🏾‍🚒' => 'pumpier: pel mez stgira',
    '👨🏿‍🚒' => 'pumpier: pel stgira',
    '👩🏻‍🚒' => 'pumpiera: pel clera',
    '👩🏼‍🚒' => 'pumpiera: pel mez clera',
    '👩🏽‍🚒' => 'pumpiera: pel media',
    '👩🏾‍🚒' => 'pumpiera: pel mez stgira',
    '👩🏿‍🚒' => 'pumpiera: pel stgira',
    '👮🏻‍♂' => 'policist: pel clera',
    '👮🏼‍♂' => 'policist: pel mez clera',
    '👮🏽‍♂' => 'policist: pel media',
    '👮🏾‍♂' => 'policist: pel mez stgira',
    '👮🏿‍♂' => 'policist: pel stgira',
    '👮🏻‍♀' => 'policista: pel clera',
    '👮🏼‍♀' => 'policista: pel mez clera',
    '👮🏽‍♀' => 'policista: pel media',
    '👮🏾‍♀' => 'policista: pel mez stgira',
    '👮🏿‍♀' => 'policista: pel stgira',
    '🕵🏻‍♂' => 'detectiv: pel clera',
    '🕵🏼‍♂' => 'detectiv: pel mez clera',
    '🕵🏽‍♂' => 'detectiv: pel media',
    '🕵🏾‍♂' => 'detectiv: pel mez stgira',
    '🕵🏿‍♂' => 'detectiv: pel stgira',
    '🕵🏻‍♀' => 'detectiva: pel clera',
    '🕵🏼‍♀' => 'detectiva: pel mez clera',
    '🕵🏽‍♀' => 'detectiva: pel media',
    '🕵🏾‍♀' => 'detectiva: pel mez stgira',
    '🕵🏿‍♀' => 'detectiva: pel stgira',
    '👷🏻‍♂' => 'lavurer da construcziun: pel clera',
    '👷🏼‍♂' => 'lavurer da construcziun: pel mez clera',
    '👷🏽‍♂' => 'lavurer da construcziun: pel media',
    '👷🏾‍♂' => 'lavurer da construcziun: pel mez stgira',
    '👷🏿‍♂' => 'lavurer da construcziun: pel stgira',
    '👷🏻‍♀' => 'lavurera da construcziun: pel clera',
    '👷🏼‍♀' => 'lavurera da construcziun: pel mez clera',
    '👷🏽‍♀' => 'lavurera da construcziun: pel media',
    '👷🏾‍♀' => 'lavurera da construcziun: pel mez stgira',
    '👷🏿‍♀' => 'lavurera da construcziun: pel stgira',
    '👳🏻‍♂' => 'um cun in turban: pel clera',
    '👳🏼‍♂' => 'um cun in turban: pel mez clera',
    '👳🏽‍♂' => 'um cun in turban: pel media',
    '👳🏾‍♂' => 'um cun in turban: pel mez stgira',
    '👳🏿‍♂' => 'um cun in turban: pel stgira',
    '👳🏻‍♀' => 'dunna cun in turban: pel clera',
    '👳🏼‍♀' => 'dunna cun in turban: pel mez clera',
    '👳🏽‍♀' => 'dunna cun in turban: pel media',
    '👳🏾‍♀' => 'dunna cun in turban: pel mez stgira',
    '👳🏿‍♀' => 'dunna cun in turban: pel stgira',
    '🤵🏻‍♂' => 'um cun smoking: pel clera',
    '🤵🏼‍♂' => 'um cun smoking: pel mez clera',
    '🤵🏽‍♂' => 'um cun smoking: pel media',
    '🤵🏾‍♂' => 'um cun smoking: pel mez stgira',
    '🤵🏿‍♂' => 'um cun smoking: pel stgira',
    '🤵🏻‍♀' => 'dunna cun smoking: pel clera',
    '🤵🏼‍♀' => 'dunna cun smoking: pel mez clera',
    '🤵🏽‍♀' => 'dunna cun smoking: pel media',
    '🤵🏾‍♀' => 'dunna cun smoking: pel mez stgira',
    '🤵🏿‍♀' => 'dunna cun smoking: pel stgira',
    '👰🏻‍♂' => 'um cun vel: pel clera',
    '👰🏼‍♂' => 'um cun vel: pel mez clera',
    '👰🏽‍♂' => 'um cun vel: pel media',
    '👰🏾‍♂' => 'um cun vel: pel mez stgira',
    '👰🏿‍♂' => 'um cun vel: pel stgira',
    '👰🏻‍♀' => 'dunna cun vel: pel clera',
    '👰🏼‍♀' => 'dunna cun vel: pel mez clera',
    '👰🏽‍♀' => 'dunna cun vel: pel media',
    '👰🏾‍♀' => 'dunna cun vel: pel mez stgira',
    '👰🏿‍♀' => 'dunna cun vel: pel stgira',
    '👩🏻‍🍼' => 'dunna che dat latg: pel clera',
    '👩🏼‍🍼' => 'dunna che dat latg: pel mez clera',
    '👩🏽‍🍼' => 'dunna che dat latg: pel media',
    '👩🏾‍🍼' => 'dunna che dat latg: pel mez stgira',
    '👩🏿‍🍼' => 'dunna che dat latg: pel stgira',
    '👨🏻‍🍼' => 'um che dat latg: pel clera',
    '👨🏼‍🍼' => 'um che dat latg: pel mez clera',
    '👨🏽‍🍼' => 'um che dat latg: pel media',
    '👨🏾‍🍼' => 'um che dat latg: pel mez stgira',
    '👨🏿‍🍼' => 'um che dat latg: pel stgira',
    '🧑🏻‍🍼' => 'persuna che dat la clocca ad in pop: pel clera',
    '🧑🏼‍🍼' => 'persuna che dat la clocca ad in pop: pel mez clera',
    '🧑🏽‍🍼' => 'persuna che dat la clocca ad in pop: pel media',
    '🧑🏾‍🍼' => 'persuna che dat la clocca ad in pop: pel mez stgira',
    '🧑🏿‍🍼' => 'persuna che dat la clocca ad in pop: pel stgira',
    '🧑🏻‍🎄' => 'Santa Claus: pel clera',
    '🧑🏼‍🎄' => 'Santa Claus: pel mez clera',
    '🧑🏽‍🎄' => 'Santa Claus: pel media',
    '🧑🏾‍🎄' => 'Santa Claus: pel mez stgira',
    '🧑🏿‍🎄' => 'Santa Claus: pel stgira',
    '🦸🏻‍♂' => 'supererox: pel clera',
    '🦸🏼‍♂' => 'supererox: pel mez clera',
    '🦸🏽‍♂' => 'supererox: pel media',
    '🦸🏾‍♂' => 'supererox: pel mez stgira',
    '🦸🏿‍♂' => 'supererox: pel stgira',
    '🦸🏻‍♀' => 'supereroxa: pel clera',
    '🦸🏼‍♀' => 'supereroxa: pel mez clera',
    '🦸🏽‍♀' => 'supereroxa: pel media',
    '🦸🏾‍♀' => 'supereroxa: pel mez stgira',
    '🦸🏿‍♀' => 'supereroxa: pel stgira',
    '🦹🏻‍♂' => 'supernausch: pel clera',
    '🦹🏼‍♂' => 'supernausch: pel mez clera',
    '🦹🏽‍♂' => 'supernausch: pel media',
    '🦹🏾‍♂' => 'supernausch: pel mez stgira',
    '🦹🏿‍♂' => 'supernausch: pel stgira',
    '🦹🏻‍♀' => 'supernauscha: pel clera',
    '🦹🏼‍♀' => 'supernauscha: pel mez clera',
    '🦹🏽‍♀' => 'supernauscha: pel media',
    '🦹🏾‍♀' => 'supernauscha: pel mez stgira',
    '🦹🏿‍♀' => 'supernauscha: pel stgira',
    '🧙🏻‍♂' => 'striun: pel clera',
    '🧙🏼‍♂' => 'striun: pel mez clera',
    '🧙🏽‍♂' => 'striun: pel media',
    '🧙🏾‍♂' => 'striun: pel mez stgira',
    '🧙🏿‍♂' => 'striun: pel stgira',
    '🧙🏻‍♀' => 'striuna: pel clera',
    '🧙🏼‍♀' => 'striuna: pel mez clera',
    '🧙🏽‍♀' => 'striuna: pel media',
    '🧙🏾‍♀' => 'striuna: pel mez stgira',
    '🧙🏿‍♀' => 'striuna: pel stgira',
    '🧚🏻‍♂' => 'dial: pel clera',
    '🧚🏼‍♂' => 'dial: pel mez clera',
    '🧚🏽‍♂' => 'dial: pel media',
    '🧚🏾‍♂' => 'dial: pel mez stgira',
    '🧚🏿‍♂' => 'dial: pel stgira',
    '🧚🏻‍♀' => 'diala: pel clera',
    '🧚🏼‍♀' => 'diala: pel mez clera',
    '🧚🏽‍♀' => 'diala: pel media',
    '🧚🏾‍♀' => 'diala: pel mez stgira',
    '🧚🏿‍♀' => 'diala: pel stgira',
    '🧛🏻‍♂' => 'vampir: pel clera',
    '🧛🏼‍♂' => 'vampir: pel mez clera',
    '🧛🏽‍♂' => 'vampir: pel media',
    '🧛🏾‍♂' => 'vampir: pel mez stgira',
    '🧛🏿‍♂' => 'vampir: pel stgira',
    '🧛🏻‍♀' => 'vamipra: pel clera',
    '🧛🏼‍♀' => 'vamipra: pel mez clera',
    '🧛🏽‍♀' => 'vamipra: pel media',
    '🧛🏾‍♀' => 'vamipra: pel mez stgira',
    '🧛🏿‍♀' => 'vamipra: pel stgira',
    '🧜🏻‍♂' => 'um da l’aua: pel clera',
    '🧜🏼‍♂' => 'um da l’aua: pel mez clera',
    '🧜🏽‍♂' => 'um da l’aua: pel media',
    '🧜🏾‍♂' => 'um da l’aua: pel mez stgira',
    '🧜🏿‍♂' => 'um da l’aua: pel stgira',
    '🧜🏻‍♀' => 'sirena: pel clera',
    '🧜🏼‍♀' => 'sirena: pel mez clera',
    '🧜🏽‍♀' => 'sirena: pel media',
    '🧜🏾‍♀' => 'sirena: pel mez stgira',
    '🧜🏿‍♀' => 'sirena: pel stgira',
    '🧝🏻‍♂' => 'elf: pel clera',
    '🧝🏼‍♂' => 'elf: pel mez clera',
    '🧝🏽‍♂' => 'elf: pel media',
    '🧝🏾‍♂' => 'elf: pel mez stgira',
    '🧝🏿‍♂' => 'elf: pel stgira',
    '🧝🏻‍♀' => 'elfa: pel clera',
    '🧝🏼‍♀' => 'elfa: pel mez clera',
    '🧝🏽‍♀' => 'elfa: pel media',
    '🧝🏾‍♀' => 'elfa: pel mez stgira',
    '🧝🏿‍♀' => 'elfa: pel stgira',
    '💆🏻‍♂' => 'um che vegn massà: pel clera',
    '💆🏼‍♂' => 'um che vegn massà: pel mez clera',
    '💆🏽‍♂' => 'um che vegn massà: pel media',
    '💆🏾‍♂' => 'um che vegn massà: pel mez stgira',
    '💆🏿‍♂' => 'um che vegn massà: pel stgira',
    '💆🏻‍♀' => 'dunna che vegn massada: pel clera',
    '💆🏼‍♀' => 'dunna che vegn massada: pel mez clera',
    '💆🏽‍♀' => 'dunna che vegn massada: pel media',
    '💆🏾‍♀' => 'dunna che vegn massada: pel mez stgira',
    '💆🏿‍♀' => 'dunna che vegn massada: pel stgira',
    '💇🏻‍♂' => 'um che sa lascha tagliar ils chavels: pel clera',
    '💇🏼‍♂' => 'um che sa lascha tagliar ils chavels: pel mez clera',
    '💇🏽‍♂' => 'um che sa lascha tagliar ils chavels: pel media',
    '💇🏾‍♂' => 'um che sa lascha tagliar ils chavels: pel mez stgira',
    '💇🏿‍♂' => 'um che sa lascha tagliar ils chavels: pel stgira',
    '💇🏻‍♀' => 'dunna che sa lascha tagliar ils chavels: pel clera',
    '💇🏼‍♀' => 'dunna che sa lascha tagliar ils chavels: pel mez clera',
    '💇🏽‍♀' => 'dunna che sa lascha tagliar ils chavels: pel media',
    '💇🏾‍♀' => 'dunna che sa lascha tagliar ils chavels: pel mez stgira',
    '💇🏿‍♀' => 'dunna che sa lascha tagliar ils chavels: pel stgira',
    '🚶🏻‍♂' => 'um che va a pe: pel clera',
    '🚶🏼‍♂' => 'um che va a pe: pel mez clera',
    '🚶🏽‍♂' => 'um che va a pe: pel media',
    '🚶🏾‍♂' => 'um che va a pe: pel mez stgira',
    '🚶🏿‍♂' => 'um che va a pe: pel stgira',
    '🚶🏻‍♀' => 'dunna che va a pe: pel clera',
    '🚶🏼‍♀' => 'dunna che va a pe: pel mez clera',
    '🚶🏽‍♀' => 'dunna che va a pe: pel media',
    '🚶🏾‍♀' => 'dunna che va a pe: pel mez stgira',
    '🚶🏿‍♀' => 'dunna che va a pe: pel stgira',
    '🚶🏻‍➡' => 'persuna che va a pe: pel clera, a dretga',
    '🚶🏼‍➡' => 'persuna che va a pe: pel mez clera, a dretga',
    '🚶🏽‍➡' => 'persuna che va a pe: pel media, a dretga',
    '🚶🏾‍➡' => 'persuna che va a pe: pel mez stgira, a dretga',
    '🚶🏿‍➡' => 'persuna che va a pe: pel stgira, a dretga',
    '🧍🏻‍♂' => 'um en pe: pel clera',
    '🧍🏼‍♂' => 'um en pe: pel mez clera',
    '🧍🏽‍♂' => 'um en pe: pel media',
    '🧍🏾‍♂' => 'um en pe: pel mez stgira',
    '🧍🏿‍♂' => 'um en pe: pel stgira',
    '🧍🏻‍♀' => 'dunna en pe: pel clera',
    '🧍🏼‍♀' => 'dunna en pe: pel mez clera',
    '🧍🏽‍♀' => 'dunna en pe: pel media',
    '🧍🏾‍♀' => 'dunna en pe: pel mez stgira',
    '🧍🏿‍♀' => 'dunna en pe: pel stgira',
    '🧎🏻‍♂' => 'um en schanuglias: pel clera',
    '🧎🏼‍♂' => 'um en schanuglias: pel mez clera',
    '🧎🏽‍♂' => 'um en schanuglias: pel media',
    '🧎🏾‍♂' => 'um en schanuglias: pel mez stgira',
    '🧎🏿‍♂' => 'um en schanuglias: pel stgira',
    '🧎🏻‍♀' => 'dunna en schanuglias: pel clera',
    '🧎🏼‍♀' => 'dunna en schanuglias: pel mez clera',
    '🧎🏽‍♀' => 'dunna en schanuglias: pel media',
    '🧎🏾‍♀' => 'dunna en schanuglias: pel mez stgira',
    '🧎🏿‍♀' => 'dunna en schanuglias: pel stgira',
    '🧎🏻‍➡' => 'persuna en schanuglias: pel clera, a dretga',
    '🧎🏼‍➡' => 'persuna en schanuglias: pel mez clera, a dretga',
    '🧎🏽‍➡' => 'persuna en schanuglias: pel media, a dretga',
    '🧎🏾‍➡' => 'persuna en schanuglias: pel mez stgira, a dretga',
    '🧎🏿‍➡' => 'persuna en schanuglias: pel stgira, a dretga',
    '🧑🏻‍🦯' => 'persuna cun ina channa da tschorvs: pel clera',
    '🧑🏼‍🦯' => 'persuna cun ina channa da tschorvs: pel mez clera',
    '🧑🏽‍🦯' => 'persuna cun ina channa da tschorvs: pel media',
    '🧑🏾‍🦯' => 'persuna cun ina channa da tschorvs: pel mez stgira',
    '🧑🏿‍🦯' => 'persuna cun ina channa da tschorvs: pel stgira',
    '👨🏻‍🦯' => 'um cun channa: pel clera',
    '👨🏼‍🦯' => 'um cun channa: pel mez clera',
    '👨🏽‍🦯' => 'um cun channa: pel media',
    '👨🏾‍🦯' => 'um cun channa: pel mez stgira',
    '👨🏿‍🦯' => 'um cun channa: pel stgira',
    '👩🏻‍🦯' => 'dunna cun channa: pel clera',
    '👩🏼‍🦯' => 'dunna cun channa: pel mez clera',
    '👩🏽‍🦯' => 'dunna cun channa: pel media',
    '👩🏾‍🦯' => 'dunna cun channa: pel mez stgira',
    '👩🏿‍🦯' => 'dunna cun channa: pel stgira',
    '🧑🏻‍🦼' => 'persuna en ina sutga cun rodas electrica: pel clera',
    '🧑🏼‍🦼' => 'persuna en ina sutga cun rodas electrica: pel mez clera',
    '🧑🏽‍🦼' => 'persuna en ina sutga cun rodas electrica: pel media',
    '🧑🏾‍🦼' => 'persuna en ina sutga cun rodas electrica: pel mez stgira',
    '🧑🏿‍🦼' => 'persuna en ina sutga cun rodas electrica: pel stgira',
    '👨🏻‍🦼' => 'um en ina sutga cun rodas electrica: pel clera',
    '👨🏼‍🦼' => 'um en ina sutga cun rodas electrica: pel mez clera',
    '👨🏽‍🦼' => 'um en ina sutga cun rodas electrica: pel media',
    '👨🏾‍🦼' => 'um en ina sutga cun rodas electrica: pel mez stgira',
    '👨🏿‍🦼' => 'um en ina sutga cun rodas electrica: pel stgira',
    '👩🏻‍🦼' => 'dunna en ina sutga cun rodas electrica: pel clera',
    '👩🏼‍🦼' => 'dunna en ina sutga cun rodas electrica: pel mez clera',
    '👩🏽‍🦼' => 'dunna en ina sutga cun rodas electrica: pel media',
    '👩🏾‍🦼' => 'dunna en ina sutga cun rodas electrica: pel mez stgira',
    '👩🏿‍🦼' => 'dunna en ina sutga cun rodas electrica: pel stgira',
    '🧑🏻‍🦽' => 'persuna en ina sutga cun rodas manuala: pel clera',
    '🧑🏼‍🦽' => 'persuna en ina sutga cun rodas manuala: pel mez clera',
    '🧑🏽‍🦽' => 'persuna en ina sutga cun rodas manuala: pel media',
    '🧑🏾‍🦽' => 'persuna en ina sutga cun rodas manuala: pel mez stgira',
    '🧑🏿‍🦽' => 'persuna en ina sutga cun rodas manuala: pel stgira',
    '👨🏻‍🦽' => 'um en ina sutga cun rodas manuala: pel clera',
    '👨🏼‍🦽' => 'um en ina sutga cun rodas manuala: pel mez clera',
    '👨🏽‍🦽' => 'um en ina sutga cun rodas manuala: pel media',
    '👨🏾‍🦽' => 'um en ina sutga cun rodas manuala: pel mez stgira',
    '👨🏿‍🦽' => 'um en ina sutga cun rodas manuala: pel stgira',
    '👩🏻‍🦽' => 'dunna en ina sutga cun rodas manuala: pel clera',
    '👩🏼‍🦽' => 'dunna en ina sutga cun rodas manuala: pel mez clera',
    '👩🏽‍🦽' => 'dunna en ina sutga cun rodas manuala: pel media',
    '👩🏾‍🦽' => 'dunna en ina sutga cun rodas manuala: pel mez stgira',
    '👩🏿‍🦽' => 'dunna en ina sutga cun rodas manuala: pel stgira',
    '🏃🏻‍♂' => 'um che curra: pel clera',
    '🏃🏼‍♂' => 'um che curra: pel mez clera',
    '🏃🏽‍♂' => 'um che curra: pel media',
    '🏃🏾‍♂' => 'um che curra: pel mez stgira',
    '🏃🏿‍♂' => 'um che curra: pel stgira',
    '🏃🏻‍♀' => 'dunna che curra: pel clera',
    '🏃🏼‍♀' => 'dunna che curra: pel mez clera',
    '🏃🏽‍♀' => 'dunna che curra: pel media',
    '🏃🏾‍♀' => 'dunna che curra: pel mez stgira',
    '🏃🏿‍♀' => 'dunna che curra: pel stgira',
    '🏃🏻‍➡' => 'persuna che curra: pel clera, a dretga',
    '🏃🏼‍➡' => 'persuna che curra: pel mez clera, a dretga',
    '🏃🏽‍➡' => 'persuna che curra: pel media, a dretga',
    '🏃🏾‍➡' => 'persuna che curra: pel mez stgira, a dretga',
    '🏃🏿‍➡' => 'persuna che curra: pel stgira, a dretga',
    '👯🏻‍♀' => 'dunnas cun ureglias da lieur: pel clera',
    '👯🏼‍♀' => 'dunnas cun ureglias da lieur: pel mez clera',
    '👯🏽‍♀' => 'dunnas cun ureglias da lieur: pel media',
    '👯🏾‍♀' => 'dunnas cun ureglias da lieur: pel mez stgira',
    '👯🏿‍♀' => 'dunnas cun ureglias da lieur: pel stgira',
    '👯🏻‍♂' => 'umens cun ureglias da lieur: pel clera',
    '👯🏼‍♂' => 'umens cun ureglias da lieur: pel mez clera',
    '👯🏽‍♂' => 'umens cun ureglias da lieur: pel media',
    '👯🏾‍♂' => 'umens cun ureglias da lieur: pel mez stgira',
    '👯🏿‍♂' => 'umens cun ureglias da lieur: pel stgira',
    '🧖🏻‍♂' => 'um en ina stanza cun vapur: pel clera',
    '🧖🏼‍♂' => 'um en ina stanza cun vapur: pel mez clera',
    '🧖🏽‍♂' => 'um en ina stanza cun vapur: pel media',
    '🧖🏾‍♂' => 'um en ina stanza cun vapur: pel mez stgira',
    '🧖🏿‍♂' => 'um en ina stanza cun vapur: pel stgira',
    '🧖🏻‍♀' => 'dunna en ina stanza cun vapur: pel clera',
    '🧖🏼‍♀' => 'dunna en ina stanza cun vapur: pel mez clera',
    '🧖🏽‍♀' => 'dunna en ina stanza cun vapur: pel media',
    '🧖🏾‍♀' => 'dunna en ina stanza cun vapur: pel mez stgira',
    '🧖🏿‍♀' => 'dunna en ina stanza cun vapur: pel stgira',
    '🧗🏻‍♂' => 'um che raiva: pel clera',
    '🧗🏼‍♂' => 'um che raiva: pel mez clera',
    '🧗🏽‍♂' => 'um che raiva: pel media',
    '🧗🏾‍♂' => 'um che raiva: pel mez stgira',
    '🧗🏿‍♂' => 'um che raiva: pel stgira',
    '🧗🏻‍♀' => 'dunna che raiva: pel clera',
    '🧗🏼‍♀' => 'dunna che raiva: pel mez clera',
    '🧗🏽‍♀' => 'dunna che raiva: pel media',
    '🧗🏾‍♀' => 'dunna che raiva: pel mez stgira',
    '🧗🏿‍♀' => 'dunna che raiva: pel stgira',
    '🏌🏻‍♂' => 'um che dat golf: pel clera',
    '🏌🏼‍♂' => 'um che dat golf: pel mez clera',
    '🏌🏽‍♂' => 'um che dat golf: pel media',
    '🏌🏾‍♂' => 'um che dat golf: pel mez stgira',
    '🏌🏿‍♂' => 'um che dat golf: pel stgira',
    '🏌🏻‍♀' => 'dunna che dat golf: pel clera',
    '🏌🏼‍♀' => 'dunna che dat golf: pel mez clera',
    '🏌🏽‍♀' => 'dunna che dat golf: pel media',
    '🏌🏾‍♀' => 'dunna che dat golf: pel mez stgira',
    '🏌🏿‍♀' => 'dunna che dat golf: pel stgira',
    '🏄🏻‍♂' => 'um che fa surfing: pel clera',
    '🏄🏼‍♂' => 'um che fa surfing: pel mez clera',
    '🏄🏽‍♂' => 'um che fa surfing: pel media',
    '🏄🏾‍♂' => 'um che fa surfing: pel mez stgira',
    '🏄🏿‍♂' => 'um che fa surfing: pel stgira',
    '🏄🏻‍♀' => 'dunna che fa surfing: pel clera',
    '🏄🏼‍♀' => 'dunna che fa surfing: pel mez clera',
    '🏄🏽‍♀' => 'dunna che fa surfing: pel media',
    '🏄🏾‍♀' => 'dunna che fa surfing: pel mez stgira',
    '🏄🏿‍♀' => 'dunna che fa surfing: pel stgira',
    '🚣🏻‍♂' => 'um che rembla: pel clera',
    '🚣🏼‍♂' => 'um che rembla: pel mez clera',
    '🚣🏽‍♂' => 'um che rembla: pel media',
    '🚣🏾‍♂' => 'um che rembla: pel mez stgira',
    '🚣🏿‍♂' => 'um che rembla: pel stgira',
    '🚣🏻‍♀' => 'dunna che rembla: pel clera',
    '🚣🏼‍♀' => 'dunna che rembla: pel mez clera',
    '🚣🏽‍♀' => 'dunna che rembla: pel media',
    '🚣🏾‍♀' => 'dunna che rembla: pel mez stgira',
    '🚣🏿‍♀' => 'dunna che rembla: pel stgira',
    '🏊🏻‍♂' => 'um che noda: pel clera',
    '🏊🏼‍♂' => 'um che noda: pel mez clera',
    '🏊🏽‍♂' => 'um che noda: pel media',
    '🏊🏾‍♂' => 'um che noda: pel mez stgira',
    '🏊🏿‍♂' => 'um che noda: pel stgira',
    '🏊🏻‍♀' => 'dunna che noda: pel clera',
    '🏊🏼‍♀' => 'dunna che noda: pel mez clera',
    '🏊🏽‍♀' => 'dunna che noda: pel media',
    '🏊🏾‍♀' => 'dunna che noda: pel mez stgira',
    '🏊🏿‍♀' => 'dunna che noda: pel stgira',
    '⛹🏻‍♂' => 'um cun balla: pel clera',
    '⛹🏼‍♂' => 'um cun balla: pel mez clera',
    '⛹🏽‍♂' => 'um cun balla: pel media',
    '⛹🏾‍♂' => 'um cun balla: pel mez stgira',
    '⛹🏿‍♂' => 'um cun balla: pel stgira',
    '⛹🏻‍♀' => 'dunna cun balla: pel clera',
    '⛹🏼‍♀' => 'dunna cun balla: pel mez clera',
    '⛹🏽‍♀' => 'dunna cun balla: pel media',
    '⛹🏾‍♀' => 'dunna cun balla: pel mez stgira',
    '⛹🏿‍♀' => 'dunna cun balla: pel stgira',
    '🏋🏻‍♂' => 'um che auza pais: pel clera',
    '🏋🏼‍♂' => 'um che auza pais: pel mez clera',
    '🏋🏽‍♂' => 'um che auza pais: pel media',
    '🏋🏾‍♂' => 'um che auza pais: pel mez stgira',
    '🏋🏿‍♂' => 'um che auza pais: pel stgira',
    '🏋🏻‍♀' => 'dunna che auza pais: pel clera',
    '🏋🏼‍♀' => 'dunna che auza pais: pel mez clera',
    '🏋🏽‍♀' => 'dunna che auza pais: pel media',
    '🏋🏾‍♀' => 'dunna che auza pais: pel mez stgira',
    '🏋🏿‍♀' => 'dunna che auza pais: pel stgira',
    '🚴🏻‍♂' => 'um che va cun velo: pel clera',
    '🚴🏼‍♂' => 'um che va cun velo: pel mez clera',
    '🚴🏽‍♂' => 'um che va cun velo: pel media',
    '🚴🏾‍♂' => 'um che va cun velo: pel mez stgira',
    '🚴🏿‍♂' => 'um che va cun velo: pel stgira',
    '🚴🏻‍♀' => 'dunna che va cun velo: pel clera',
    '🚴🏼‍♀' => 'dunna che va cun velo: pel mez clera',
    '🚴🏽‍♀' => 'dunna che va cun velo: pel media',
    '🚴🏾‍♀' => 'dunna che va cun velo: pel mez stgira',
    '🚴🏿‍♀' => 'dunna che va cun velo: pel stgira',
    '🚵🏻‍♂' => 'um che va cun mountainbike: pel clera',
    '🚵🏼‍♂' => 'um che va cun mountainbike: pel mez clera',
    '🚵🏽‍♂' => 'um che va cun mountainbike: pel media',
    '🚵🏾‍♂' => 'um che va cun mountainbike: pel mez stgira',
    '🚵🏿‍♂' => 'um che va cun mountainbike: pel stgira',
    '🚵🏻‍♀' => 'dunna che va cun mountainbike: pel clera',
    '🚵🏼‍♀' => 'dunna che va cun mountainbike: pel mez clera',
    '🚵🏽‍♀' => 'dunna che va cun mountainbike: pel media',
    '🚵🏾‍♀' => 'dunna che va cun mountainbike: pel mez stgira',
    '🚵🏿‍♀' => 'dunna che va cun mountainbike: pel stgira',
    '🤸🏻‍♂' => 'um che fa la roda: pel clera',
    '🤸🏼‍♂' => 'um che fa la roda: pel mez clera',
    '🤸🏽‍♂' => 'um che fa la roda: pel media',
    '🤸🏾‍♂' => 'um che fa la roda: pel mez stgira',
    '🤸🏿‍♂' => 'um che fa la roda: pel stgira',
    '🤸🏻‍♀' => 'dunna che fa la roda: pel clera',
    '🤸🏼‍♀' => 'dunna che fa la roda: pel mez clera',
    '🤸🏽‍♀' => 'dunna che fa la roda: pel media',
    '🤸🏾‍♀' => 'dunna che fa la roda: pel mez stgira',
    '🤸🏿‍♀' => 'dunna che fa la roda: pel stgira',
    '🤼🏻‍♀' => 'dunnas che lutgan: pel clera',
    '🤼🏼‍♀' => 'dunnas che lutgan: pel mez clera',
    '🤼🏽‍♀' => 'dunnas che lutgan: pel media',
    '🤼🏾‍♀' => 'dunnas che lutgan: pel mez stgira',
    '🤼🏿‍♀' => 'dunnas che lutgan: pel stgira',
    '🤼🏻‍♂' => 'umens che lutgan: pel clera',
    '🤼🏼‍♂' => 'umens che lutgan: pel mez clera',
    '🤼🏽‍♂' => 'umens che lutgan: pel media',
    '🤼🏾‍♂' => 'umens che lutgan: pel mez stgira',
    '🤼🏿‍♂' => 'umens che lutgan: pel stgira',
    '🤽🏻‍♂' => 'um che gioga ballanataziun: pel clera',
    '🤽🏼‍♂' => 'um che gioga ballanataziun: pel mez clera',
    '🤽🏽‍♂' => 'um che gioga ballanataziun: pel media',
    '🤽🏾‍♂' => 'um che gioga ballanataziun: pel mez stgira',
    '🤽🏿‍♂' => 'um che gioga ballanataziun: pel stgira',
    '🤽🏻‍♀' => 'dunna che gioga ballanataziun: pel clera',
    '🤽🏼‍♀' => 'dunna che gioga ballanataziun: pel mez clera',
    '🤽🏽‍♀' => 'dunna che gioga ballanataziun: pel media',
    '🤽🏾‍♀' => 'dunna che gioga ballanataziun: pel mez stgira',
    '🤽🏿‍♀' => 'dunna che gioga ballanataziun: pel stgira',
    '🤾🏻‍♂' => 'um che gioga ballamaun: pel clera',
    '🤾🏼‍♂' => 'um che gioga ballamaun: pel mez clera',
    '🤾🏽‍♂' => 'um che gioga ballamaun: pel media',
    '🤾🏾‍♂' => 'um che gioga ballamaun: pel mez stgira',
    '🤾🏿‍♂' => 'um che gioga ballamaun: pel stgira',
    '🤾🏻‍♀' => 'dunna che gioga ballamaun: pel clera',
    '🤾🏼‍♀' => 'dunna che gioga ballamaun: pel mez clera',
    '🤾🏽‍♀' => 'dunna che gioga ballamaun: pel media',
    '🤾🏾‍♀' => 'dunna che gioga ballamaun: pel mez stgira',
    '🤾🏿‍♀' => 'dunna che gioga ballamaun: pel stgira',
    '🤹🏻‍♂' => 'um che schonglescha: pel clera',
    '🤹🏼‍♂' => 'um che schonglescha: pel mez clera',
    '🤹🏽‍♂' => 'um che schonglescha: pel media',
    '🤹🏾‍♂' => 'um che schonglescha: pel mez stgira',
    '🤹🏿‍♂' => 'um che schonglescha: pel stgira',
    '🤹🏻‍♀' => 'dunna che schonglescha: pel clera',
    '🤹🏼‍♀' => 'dunna che schonglescha: pel mez clera',
    '🤹🏽‍♀' => 'dunna che schonglescha: pel media',
    '🤹🏾‍♀' => 'dunna che schonglescha: pel mez stgira',
    '🤹🏿‍♀' => 'dunna che schonglescha: pel stgira',
    '🧘🏻‍♂' => 'um en la posiziun da lotos: pel clera',
    '🧘🏼‍♂' => 'um en la posiziun da lotos: pel mez clera',
    '🧘🏽‍♂' => 'um en la posiziun da lotos: pel media',
    '🧘🏾‍♂' => 'um en la posiziun da lotos: pel mez stgira',
    '🧘🏿‍♂' => 'um en la posiziun da lotos: pel stgira',
    '🧘🏻‍♀' => 'dunna en la posiziun da lotos: pel clera',
    '🧘🏼‍♀' => 'dunna en la posiziun da lotos: pel mez clera',
    '🧘🏽‍♀' => 'dunna en la posiziun da lotos: pel media',
    '🧘🏾‍♀' => 'dunna en la posiziun da lotos: pel mez stgira',
    '🧘🏿‍♀' => 'dunna en la posiziun da lotos: pel stgira',
    '🧑‍🦰' => 'persuna: chavels cotschens',
    '🧑‍🦱' => 'persuna: chavels ritschads',
    '🧑‍🦳' => 'persuna: chavels alvs',
    '🧑‍🦲' => 'persuna: chau blut',
    '👨‍🦰' => 'um: chavels cotschens',
    '👨‍🦱' => 'um: chavels ritschads',
    '👨‍🦳' => 'um: chavels alvs',
    '👨‍🦲' => 'um: chau blut',
    '👩‍🦰' => 'dunna: chavels cotschens',
    '👩‍🦱' => 'dunna: chavels ritschads',
    '👩‍🦳' => 'dunna: chavels alvs',
    '👩‍🦲' => 'dunna: chau blut',
    '🚶‍➡' => 'persuna che va a pe: a dretga',
    '🧎‍➡' => 'persuna en schanuglias: a dretga',
    '🏃‍➡' => 'persuna che curra: a dretga',
    '👨‍👦' => 'famiglia: um, mattet',
    '👨‍👧' => 'famiglia: um, mattetta',
    '👩‍👦' => 'famiglia: dunna, mattet',
    '👩‍👧' => 'famiglia: dunna, mattetta',
    '😶‍🌫' => 'fatscha en nivels',
    '😮‍💨' => 'fatscha che expira',
    '🙂‍↕' => 'dar dal chau',
    '😵‍💫' => 'fatscha cun egls en furma da spirala',
    '❤‍🔥' => 'cor che arda',
    '❤‍🩹' => 'cor cun bandascha',
    '👁‍🗨' => 'egl en ina nivletta',
    '🧔‍♂' => 'um: barba',
    '👱‍♂' => 'um: chavels blonds',
    '🧔‍♀' => 'dunna: barba',
    '👱‍♀' => 'dunna: chavels blonds',
    '🙍‍♂' => 'um malcuntent',
    '🙍‍♀' => 'dunna malcuntenta',
    '🙎‍♂' => 'um permalà',
    '🙎‍♀' => 'dunna permalada',
    '🙅‍♂' => 'um cun bratscha cruschada',
    '🙅‍♀' => 'dunna cun bratscha cruschada',
    '🙆‍♂' => 'um che tegna ils mauns sin il chau',
    '🙆‍♀' => 'dunna che tegna ils mauns sin il chau',
    '💁‍♂' => 'um che tegna la palma-maun vers ensi',
    '💁‍♀' => 'dunna che tegna la palma-maun vers ensi',
    '🙋‍♂' => 'um che auza il maun',
    '🙋‍♀' => 'dunna che auza il maun',
    '🧏‍♂' => 'um surd',
    '🧏‍♀' => 'dunna surda',
    '🙇‍♂' => 'um che s’enclina',
    '🙇‍♀' => 'dunna che s’enclina',
    '🤦‍♂' => 'um cun la palma-maun sin la fatscha',
    '🤦‍♀' => 'dunna cun la palma-maun sin la fatscha',
    '🤷‍♂' => 'um che auza las spatlas',
    '🤷‍♀' => 'dunna che auza las spatlas',
    '🧑‍⚕' => 'persuna che lavura en il sectur da la sanadad',
    '👨‍⚕' => 'um che lavura en il sectur da la sanadad',
    '👩‍⚕' => 'dunna che lavura en il sectur da la sanadad',
    '🧑‍🎓' => 'student:a',
    '👨‍🎓' => 'student',
    '👩‍🎓' => 'studenta',
    '🧑‍🏫' => 'scolast:a',
    '👨‍🏫' => 'scolast',
    '👩‍🏫' => 'scolasta',
    '🧑‍⚖' => 'derschad:ra',
    '👨‍⚖' => 'derschader',
    '👩‍⚖' => 'derschadra',
    '🧑‍🌾' => 'pur:a',
    '👨‍🌾' => 'pur',
    '👩‍🌾' => 'pura',
    '🧑‍🍳' => 'cuschinier:a',
    '👨‍🍳' => 'cuschinier',
    '👩‍🍳' => 'cuschiniera',
    '🧑‍🔧' => 'mecanist:a',
    '👨‍🔧' => 'mecanist',
    '👩‍🔧' => 'mecanista',
    '🧑‍🏭' => 'persuna che lavura en fabrica',
    '👨‍🏭' => 'um che lavura en fabrica',
    '👩‍🏭' => 'dunna che lavura en fabrica',
    '🧑‍💼' => 'birolist:a',
    '👨‍💼' => 'birolist',
    '👩‍💼' => 'birolista',
    '🧑‍🔬' => 'scienzia:da',
    '👨‍🔬' => 'scienzià',
    '👩‍🔬' => 'scienziada',
    '🧑‍💻' => 'tecnolog:a',
    '👨‍💻' => 'tecnolog',
    '👩‍💻' => 'tecnologa',
    '🧑‍🎤' => 'chantadur:a',
    '👨‍🎤' => 'chantadur',
    '👩‍🎤' => 'chantadura',
    '🧑‍🎨' => 'pictur:a artist:a',
    '👨‍🎨' => 'pictur artist',
    '👩‍🎨' => 'pictura artista',
    '🧑‍✈' => 'pilot:a',
    '👨‍✈' => 'pilot',
    '👩‍✈' => 'pilota',
    '🧑‍🚀' => 'astronaut:a',
    '👨‍🚀' => 'astronaut',
    '👩‍🚀' => 'astronauta',
    '🧑‍🚒' => 'pumpier:a',
    '👨‍🚒' => 'pumpier',
    '👩‍🚒' => 'pumpiera',
    '👮‍♂' => 'policist',
    '👮‍♀' => 'policista',
    '🕵‍♂' => 'detectiv',
    '🕵‍♀' => 'detectiva',
    '👷‍♂' => 'lavurer da construcziun',
    '👷‍♀' => 'lavurera da construcziun',
    '👳‍♂' => 'um cun in turban',
    '👳‍♀' => 'dunna cun in turban',
    '🤵‍♂' => 'um cun smoking',
    '🤵‍♀' => 'dunna cun smoking',
    '👰‍♂' => 'um cun vel',
    '👰‍♀' => 'dunna cun vel',
    '👩‍🍼' => 'dunna che dat latg',
    '👨‍🍼' => 'um che dat latg',
    '🧑‍🍼' => 'persuna che dat la clocca ad in pop',
    '🧑‍🎄' => 'Santa Claus',
    '🦸‍♂' => 'supererox',
    '🦸‍♀' => 'supereroxa',
    '🦹‍♂' => 'supernausch',
    '🦹‍♀' => 'supernauscha',
    '🧙‍♂' => 'striun',
    '🧙‍♀' => 'striuna',
    '🧚‍♂' => 'dial',
    '🧚‍♀' => 'diala',
    '🧛‍♂' => 'vampir',
    '🧛‍♀' => 'vamipra',
    '🧜‍♂' => 'um da l’aua',
    '🧜‍♀' => 'sirena',
    '🧝‍♂' => 'elf',
    '🧝‍♀' => 'elfa',
    '🧞‍♂' => 'spiert da buttiglia masculin',
    '🧞‍♀' => 'spiert da buttiglia feminin',
    '🧟‍♂' => 'um zombi',
    '🧟‍♀' => 'dunna zombi',
    '💆‍♂' => 'um che vegn massà',
    '💆‍♀' => 'dunna che vegn massada',
    '💇‍♂' => 'um che sa lascha tagliar ils chavels',
    '💇‍♀' => 'dunna che sa lascha tagliar ils chavels',
    '🚶‍♂' => 'um che va a pe',
    '🚶‍♀' => 'dunna che va a pe',
    '🧍‍♂' => 'um en pe',
    '🧍‍♀' => 'dunna en pe',
    '🧎‍♂' => 'um en schanuglias',
    '🧎‍♀' => 'dunna en schanuglias',
    '🧑‍🦯' => 'persuna cun ina channa da tschorvs',
    '👨‍🦯' => 'um cun channa',
    '👩‍🦯' => 'dunna cun channa',
    '🧑‍🦼' => 'persuna en ina sutga cun rodas electrica',
    '👨‍🦼' => 'um en ina sutga cun rodas electrica',
    '👩‍🦼' => 'dunna en ina sutga cun rodas electrica',
    '🧑‍🦽' => 'persuna en ina sutga cun rodas manuala',
    '👨‍🦽' => 'um en ina sutga cun rodas manuala',
    '👩‍🦽' => 'dunna en ina sutga cun rodas manuala',
    '🏃‍♂' => 'um che curra',
    '🏃‍♀' => 'dunna che curra',
    '🧑‍🩰' => 'ballarin:a',
    '👯‍♂' => 'umens cun ureglias da lieur',
    '👯‍♀' => 'dunnas cun ureglias da lieur',
    '🧖‍♂' => 'um en ina stanza cun vapur',
    '🧖‍♀' => 'dunna en ina stanza cun vapur',
    '🧗‍♂' => 'um che raiva',
    '🧗‍♀' => 'dunna che raiva',
    '🏌‍♂' => 'um che dat golf',
    '🏌‍♀' => 'dunna che dat golf',
    '🏄‍♂' => 'um che fa surfing',
    '🏄‍♀' => 'dunna che fa surfing',
    '🚣‍♂' => 'um che rembla',
    '🚣‍♀' => 'dunna che rembla',
    '🏊‍♂' => 'um che noda',
    '🏊‍♀' => 'dunna che noda',
    '⛹‍♂' => 'um cun balla',
    '⛹‍♀' => 'dunna cun balla',
    '🏋‍♂' => 'um che auza pais',
    '🏋‍♀' => 'dunna che auza pais',
    '🚴‍♂' => 'um che va cun velo',
    '🚴‍♀' => 'dunna che va cun velo',
    '🚵‍♂' => 'um che va cun mountainbike',
    '🚵‍♀' => 'dunna che va cun mountainbike',
    '🤸‍♂' => 'um che fa la roda',
    '🤸‍♀' => 'dunna che fa la roda',
    '🤼‍♂' => 'umens che lutgan',
    '🤼‍♀' => 'dunnas che lutgan',
    '🤽‍♂' => 'um che gioga ballanataziun',
    '🤽‍♀' => 'dunna che gioga ballanataziun',
    '🤾‍♂' => 'um che gioga ballamaun',
    '🤾‍♀' => 'dunna che gioga ballamaun',
    '🤹‍♂' => 'um che schonglescha',
    '🤹‍♀' => 'dunna che schonglescha',
    '🧘‍♂' => 'um en la posiziun da lotos',
    '🧘‍♀' => 'dunna en la posiziun da lotos',
    '🧑‍🧒' => 'famiglia: persuna creschida, uffant',
    '🐕‍🦺' => 'chaun d’assistenza',
    '🐈‍⬛' => 'giat nair',
    '🐻‍❄' => 'urs polar',
    '🐦‍⬛' => 'utschè nair',
    '🐦‍🔥' => 'fenix',
    '🍋‍🟩' => 'limetta',
    '🍄‍🟫' => 'bulieu brin',
    '⛓‍💥' => 'chadaina rutta',
    '🏳‍🌈' => 'bandiera da l’artg',
    '🏳‍⚧' => 'bandiera transgender',
    '🏴‍☠' => 'bandiera da pirats',
    '👋🏻' => 'dar dal maun: pel clera',
    '👋🏼' => 'dar dal maun: pel mez clera',
    '👋🏽' => 'dar dal maun: pel media',
    '👋🏾' => 'dar dal maun: pel mez stgira',
    '👋🏿' => 'dar dal maun: pel stgira',
    '🤚🏻' => 'dies dal maun auzà: pel clera',
    '🤚🏼' => 'dies dal maun auzà: pel mez clera',
    '🤚🏽' => 'dies dal maun auzà: pel media',
    '🤚🏾' => 'dies dal maun auzà: pel mez stgira',
    '🤚🏿' => 'dies dal maun auzà: pel stgira',
    '🖐🏻' => 'maun avert: pel clera',
    '🖐🏼' => 'maun avert: pel mez clera',
    '🖐🏽' => 'maun avert: pel media',
    '🖐🏾' => 'maun avert: pel mez stgira',
    '🖐🏿' => 'maun avert: pel stgira',
    '✋🏻' => 'maun auzà: pel clera',
    '✋🏼' => 'maun auzà: pel mez clera',
    '✋🏽' => 'maun auzà: pel media',
    '✋🏾' => 'maun auzà: pel mez stgira',
    '✋🏿' => 'maun auzà: pel stgira',
    '🖖🏻' => 'salid vulcanic: pel clera',
    '🖖🏼' => 'salid vulcanic: pel mez clera',
    '🖖🏽' => 'salid vulcanic: pel media',
    '🖖🏾' => 'salid vulcanic: pel mez stgira',
    '🖖🏿' => 'salid vulcanic: pel stgira',
    '🫱🏻' => 'maun che mussa a dretga: pel clera',
    '🫱🏼' => 'maun che mussa a dretga: pel mez clera',
    '🫱🏽' => 'maun che mussa a dretga: pel media',
    '🫱🏾' => 'maun che mussa a dretga: pel mez stgira',
    '🫱🏿' => 'maun che mussa a dretga: pel stgira',
    '🫲🏻' => 'maun che mussa a sanestra: pel clera',
    '🫲🏼' => 'maun che mussa a sanestra: pel mez clera',
    '🫲🏽' => 'maun che mussa a sanestra: pel media',
    '🫲🏾' => 'maun che mussa a sanestra: pel mez stgira',
    '🫲🏿' => 'maun che mussa a sanestra: pel stgira',
    '🫳🏻' => 'maun cun la palma engiu: pel clera',
    '🫳🏼' => 'maun cun la palma engiu: pel mez clera',
    '🫳🏽' => 'maun cun la palma engiu: pel media',
    '🫳🏾' => 'maun cun la palma engiu: pel mez stgira',
    '🫳🏿' => 'maun cun la palma engiu: pel stgira',
    '🫴🏻' => 'maun cun la palma maun ensi: pel clera',
    '🫴🏼' => 'maun cun la palma maun ensi: pel mez clera',
    '🫴🏽' => 'maun cun la palma maun ensi: pel media',
    '🫴🏾' => 'maun cun la palma maun ensi: pel mez stgira',
    '🫴🏿' => 'maun cun la palma maun ensi: pel stgira',
    '🫷🏻' => 'maun che stauscha a sanestra: pel clera',
    '🫷🏼' => 'maun che stauscha a sanestra: pel mez clera',
    '🫷🏽' => 'maun che stauscha a sanestra: pel media',
    '🫷🏾' => 'maun che stauscha a sanestra: pel mez stgira',
    '🫷🏿' => 'maun che stauscha a sanestra: pel stgira',
    '🫸🏻' => 'maun che stauscha a dretga: pel clera',
    '🫸🏼' => 'maun che stauscha a dretga: pel mez clera',
    '🫸🏽' => 'maun che stauscha a dretga: pel media',
    '🫸🏾' => 'maun che stauscha a dretga: pel mez stgira',
    '🫸🏿' => 'maun che stauscha a dretga: pel stgira',
    '👌🏻' => 'maun che mussa ok: pel clera',
    '👌🏼' => 'maun che mussa ok: pel mez clera',
    '👌🏽' => 'maun che mussa ok: pel media',
    '👌🏾' => 'maun che mussa ok: pel mez stgira',
    '👌🏿' => 'maun che mussa ok: pel stgira',
    '🤌🏻' => 'maun cun pizza da la detta che sa tutga: pel clera',
    '🤌🏼' => 'maun cun pizza da la detta che sa tutga: pel mez clera',
    '🤌🏽' => 'maun cun pizza da la detta che sa tutga: pel media',
    '🤌🏾' => 'maun cun pizza da la detta che sa tutga: pel mez stgira',
    '🤌🏿' => 'maun cun pizza da la detta che sa tutga: pel stgira',
    '🤏🏻' => 'maun che mussa pitschen: pel clera',
    '🤏🏼' => 'maun che mussa pitschen: pel mez clera',
    '🤏🏽' => 'maun che mussa pitschen: pel media',
    '🤏🏾' => 'maun che mussa pitschen: pel mez stgira',
    '🤏🏿' => 'maun che mussa pitschen: pel stgira',
    '✌🏻' => 'gest victory: pel clera',
    '✌🏼' => 'gest victory: pel mez clera',
    '✌🏽' => 'gest victory: pel media',
    '✌🏾' => 'gest victory: pel mez stgira',
    '✌🏿' => 'gest victory: pel stgira',
    '🤞🏻' => 'dus dets cruschads: pel clera',
    '🤞🏼' => 'dus dets cruschads: pel mez clera',
    '🤞🏽' => 'dus dets cruschads: pel media',
    '🤞🏾' => 'dus dets cruschads: pel mez stgira',
    '🤞🏿' => 'dus dets cruschads: pel stgira',
    '🫰🏻' => 'gest per char: pel clera',
    '🫰🏼' => 'gest per char: pel mez clera',
    '🫰🏽' => 'gest per char: pel media',
    '🫰🏾' => 'gest per char: pel mez stgira',
    '🫰🏿' => 'gest per char: pel stgira',
    '🤟🏻' => 'gest «jau t’am»: pel clera',
    '🤟🏼' => 'gest «jau t’am»: pel mez clera',
    '🤟🏽' => 'gest «jau t’am»: pel media',
    '🤟🏾' => 'gest «jau t’am»: pel mez stgira',
    '🤟🏿' => 'gest «jau t’am»: pel stgira',
    '🤘🏻' => 'gest da cornas: pel clera',
    '🤘🏼' => 'gest da cornas: pel mez clera',
    '🤘🏽' => 'gest da cornas: pel media',
    '🤘🏾' => 'gest da cornas: pel mez stgira',
    '🤘🏿' => 'gest da cornas: pel stgira',
    '🤙🏻' => 'gest da telefonar: pel clera',
    '🤙🏼' => 'gest da telefonar: pel mez clera',
    '🤙🏽' => 'gest da telefonar: pel media',
    '🤙🏾' => 'gest da telefonar: pel mez stgira',
    '🤙🏿' => 'gest da telefonar: pel stgira',
    '👈🏻' => 'dies dal maun cun det che mussa a sanestra: pel clera',
    '👈🏼' => 'dies dal maun cun det che mussa a sanestra: pel mez clera',
    '👈🏽' => 'dies dal maun cun det che mussa a sanestra: pel media',
    '👈🏾' => 'dies dal maun cun det che mussa a sanestra: pel mez stgira',
    '👈🏿' => 'dies dal maun cun det che mussa a sanestra: pel stgira',
    '👉🏻' => 'dies dal maun cun det che mussa a dretga: pel clera',
    '👉🏼' => 'dies dal maun cun det che mussa a dretga: pel mez clera',
    '👉🏽' => 'dies dal maun cun det che mussa a dretga: pel media',
    '👉🏾' => 'dies dal maun cun det che mussa a dretga: pel mez stgira',
    '👉🏿' => 'dies dal maun cun det che mussa a dretga: pel stgira',
    '👆🏻' => 'dies dal maun cun det mussader vers ensi: pel clera',
    '👆🏼' => 'dies dal maun cun det mussader vers ensi: pel mez clera',
    '👆🏽' => 'dies dal maun cun det mussader vers ensi: pel media',
    '👆🏾' => 'dies dal maun cun det mussader vers ensi: pel mez stgira',
    '👆🏿' => 'dies dal maun cun det mussader vers ensi: pel stgira',
    '🖕🏻' => 'det d’amez stendì: pel clera',
    '🖕🏼' => 'det d’amez stendì: pel mez clera',
    '🖕🏽' => 'det d’amez stendì: pel media',
    '🖕🏾' => 'det d’amez stendì: pel mez stgira',
    '🖕🏿' => 'det d’amez stendì: pel stgira',
    '👇🏻' => 'dies dal maun cun det mussader vers engiu: pel clera',
    '👇🏼' => 'dies dal maun cun det mussader vers engiu: pel mez clera',
    '👇🏽' => 'dies dal maun cun det mussader vers engiu: pel media',
    '👇🏾' => 'dies dal maun cun det mussader vers engiu: pel mez stgira',
    '👇🏿' => 'dies dal maun cun det mussader vers engiu: pel stgira',
    '☝🏻' => 'det mussader che mussa ensi: pel clera',
    '☝🏼' => 'det mussader che mussa ensi: pel mez clera',
    '☝🏽' => 'det mussader che mussa ensi: pel media',
    '☝🏾' => 'det mussader che mussa ensi: pel mez stgira',
    '☝🏿' => 'det mussader che mussa ensi: pel stgira',
    '🫵🏻' => 'det mussader che mussa sin mai: pel clera',
    '🫵🏼' => 'det mussader che mussa sin mai: pel mez clera',
    '🫵🏽' => 'det mussader che mussa sin mai: pel media',
    '🫵🏾' => 'det mussader che mussa sin mai: pel mez stgira',
    '🫵🏿' => 'det mussader che mussa sin mai: pel stgira',
    '👍🏻' => 'polesch che mussa ensi: pel clera',
    '👍🏼' => 'polesch che mussa ensi: pel mez clera',
    '👍🏽' => 'polesch che mussa ensi: pel media',
    '👍🏾' => 'polesch che mussa ensi: pel mez stgira',
    '👍🏿' => 'polesch che mussa ensi: pel stgira',
    '👎🏻' => 'polesch che mussa engiu: pel clera',
    '👎🏼' => 'polesch che mussa engiu: pel mez clera',
    '👎🏽' => 'polesch che mussa engiu: pel media',
    '👎🏾' => 'polesch che mussa engiu: pel mez stgira',
    '👎🏿' => 'polesch che mussa engiu: pel stgira',
    '✊🏻' => 'pugn ad aut: pel clera',
    '✊🏼' => 'pugn ad aut: pel mez clera',
    '✊🏽' => 'pugn ad aut: pel media',
    '✊🏾' => 'pugn ad aut: pel mez stgira',
    '✊🏿' => 'pugn ad aut: pel stgira',
    '👊🏻' => 'pugn vers mai: pel clera',
    '👊🏼' => 'pugn vers mai: pel mez clera',
    '👊🏽' => 'pugn vers mai: pel media',
    '👊🏾' => 'pugn vers mai: pel mez stgira',
    '👊🏿' => 'pugn vers mai: pel stgira',
    '🤛🏻' => 'pugn che mussa a sanestra: pel clera',
    '🤛🏼' => 'pugn che mussa a sanestra: pel mez clera',
    '🤛🏽' => 'pugn che mussa a sanestra: pel media',
    '🤛🏾' => 'pugn che mussa a sanestra: pel mez stgira',
    '🤛🏿' => 'pugn che mussa a sanestra: pel stgira',
    '🤜🏻' => 'pugn che mussa a dretga: pel clera',
    '🤜🏼' => 'pugn che mussa a dretga: pel mez clera',
    '🤜🏽' => 'pugn che mussa a dretga: pel media',
    '🤜🏾' => 'pugn che mussa a dretga: pel mez stgira',
    '🤜🏿' => 'pugn che mussa a dretga: pel stgira',
    '👏🏻' => 'mauns che applaudeschan: pel clera',
    '👏🏼' => 'mauns che applaudeschan: pel mez clera',
    '👏🏽' => 'mauns che applaudeschan: pel media',
    '👏🏾' => 'mauns che applaudeschan: pel mez stgira',
    '👏🏿' => 'mauns che applaudeschan: pel stgira',
    '🙌🏻' => 'mauns auzads: pel clera',
    '🙌🏼' => 'mauns auzads: pel mez clera',
    '🙌🏽' => 'mauns auzads: pel media',
    '🙌🏾' => 'mauns auzads: pel mez stgira',
    '🙌🏿' => 'mauns auzads: pel stgira',
    '🫶🏻' => 'mauns che furman in cor: pel clera',
    '🫶🏼' => 'mauns che furman in cor: pel mez clera',
    '🫶🏽' => 'mauns che furman in cor: pel media',
    '🫶🏾' => 'mauns che furman in cor: pel mez stgira',
    '🫶🏿' => 'mauns che furman in cor: pel stgira',
    '👐🏻' => 'mauns averts: pel clera',
    '👐🏼' => 'mauns averts: pel mez clera',
    '👐🏽' => 'mauns averts: pel media',
    '👐🏾' => 'mauns averts: pel mez stgira',
    '👐🏿' => 'mauns averts: pel stgira',
    '🤲🏻' => 'omaduas palmas-maun ina sper l’autra: pel clera',
    '🤲🏼' => 'omaduas palmas-maun ina sper l’autra: pel mez clera',
    '🤲🏽' => 'omaduas palmas-maun ina sper l’autra: pel media',
    '🤲🏾' => 'omaduas palmas-maun ina sper l’autra: pel mez stgira',
    '🤲🏿' => 'omaduas palmas-maun ina sper l’autra: pel stgira',
    '🤝🏻' => 'dar il maun: pel clera',
    '🤝🏼' => 'dar il maun: pel mez clera',
    '🤝🏽' => 'dar il maun: pel media',
    '🤝🏾' => 'dar il maun: pel mez stgira',
    '🤝🏿' => 'dar il maun: pel stgira',
    '🙏🏻' => 'palmas-maun ina sin l‘autra: pel clera',
    '🙏🏼' => 'palmas-maun ina sin l‘autra: pel mez clera',
    '🙏🏽' => 'palmas-maun ina sin l‘autra: pel media',
    '🙏🏾' => 'palmas-maun ina sin l‘autra: pel mez stgira',
    '🙏🏿' => 'palmas-maun ina sin l‘autra: pel stgira',
    '✍🏻' => 'maun che scriva: pel clera',
    '✍🏼' => 'maun che scriva: pel mez clera',
    '✍🏽' => 'maun che scriva: pel media',
    '✍🏾' => 'maun che scriva: pel mez stgira',
    '✍🏿' => 'maun che scriva: pel stgira',
    '💅🏻' => 'vernisch dad unglas: pel clera',
    '💅🏼' => 'vernisch dad unglas: pel mez clera',
    '💅🏽' => 'vernisch dad unglas: pel media',
    '💅🏾' => 'vernisch dad unglas: pel mez stgira',
    '💅🏿' => 'vernisch dad unglas: pel stgira',
    '🤳🏻' => 'selfie: pel clera',
    '🤳🏼' => 'selfie: pel mez clera',
    '🤳🏽' => 'selfie: pel media',
    '🤳🏾' => 'selfie: pel mez stgira',
    '🤳🏿' => 'selfie: pel stgira',
    '💪🏻' => 'biceps tendì: pel clera',
    '💪🏼' => 'biceps tendì: pel mez clera',
    '💪🏽' => 'biceps tendì: pel media',
    '💪🏾' => 'biceps tendì: pel mez stgira',
    '💪🏿' => 'biceps tendì: pel stgira',
    '🦵🏻' => 'chomma: pel clera',
    '🦵🏼' => 'chomma: pel mez clera',
    '🦵🏽' => 'chomma: pel media',
    '🦵🏾' => 'chomma: pel mez stgira',
    '🦵🏿' => 'chomma: pel stgira',
    '🦶🏻' => 'pe: pel clera',
    '🦶🏼' => 'pe: pel mez clera',
    '🦶🏽' => 'pe: pel media',
    '🦶🏾' => 'pe: pel mez stgira',
    '🦶🏿' => 'pe: pel stgira',
    '👂🏻' => 'ureglia: pel clera',
    '👂🏼' => 'ureglia: pel mez clera',
    '👂🏽' => 'ureglia: pel media',
    '👂🏾' => 'ureglia: pel mez stgira',
    '👂🏿' => 'ureglia: pel stgira',
    '🦻🏻' => 'ureglia cun apparat d’udida: pel clera',
    '🦻🏼' => 'ureglia cun apparat d’udida: pel mez clera',
    '🦻🏽' => 'ureglia cun apparat d’udida: pel media',
    '🦻🏾' => 'ureglia cun apparat d’udida: pel mez stgira',
    '🦻🏿' => 'ureglia cun apparat d’udida: pel stgira',
    '👃🏻' => 'nas: pel clera',
    '👃🏼' => 'nas: pel mez clera',
    '👃🏽' => 'nas: pel media',
    '👃🏾' => 'nas: pel mez stgira',
    '👃🏿' => 'nas: pel stgira',
    '👶🏻' => 'uffantin: pel clera',
    '👶🏼' => 'uffantin: pel mez clera',
    '👶🏽' => 'uffantin: pel media',
    '👶🏾' => 'uffantin: pel mez stgira',
    '👶🏿' => 'uffantin: pel stgira',
    '🧒🏻' => 'uffant: pel clera',
    '🧒🏼' => 'uffant: pel mez clera',
    '🧒🏽' => 'uffant: pel media',
    '🧒🏾' => 'uffant: pel mez stgira',
    '🧒🏿' => 'uffant: pel stgira',
    '👦🏻' => 'mattet: pel clera',
    '👦🏼' => 'mattet: pel mez clera',
    '👦🏽' => 'mattet: pel media',
    '👦🏾' => 'mattet: pel mez stgira',
    '👦🏿' => 'mattet: pel stgira',
    '👧🏻' => 'mattetta: pel clera',
    '👧🏼' => 'mattetta: pel mez clera',
    '👧🏽' => 'mattetta: pel media',
    '👧🏾' => 'mattetta: pel mez stgira',
    '👧🏿' => 'mattetta: pel stgira',
    '🧑🏻' => 'persuna: pel clera',
    '🧑🏼' => 'persuna: pel mez clera',
    '🧑🏽' => 'persuna: pel media',
    '🧑🏾' => 'persuna: pel mez stgira',
    '🧑🏿' => 'persuna: pel stgira',
    '👱🏻' => 'persuna: pel clera, chavels blonds',
    '👱🏼' => 'persuna: pel mez clera, chavels blonds',
    '👱🏽' => 'persuna: pel media, chavels blonds',
    '👱🏾' => 'persuna: pel mez stgira, chavels blonds',
    '👱🏿' => 'persuna: pel stgira, chavels blonds',
    '👨🏻' => 'um: pel clera',
    '👨🏼' => 'um: pel mez clera',
    '👨🏽' => 'um: pel media',
    '👨🏾' => 'um: pel mez stgira',
    '👨🏿' => 'um: pel stgira',
    '🧔🏻' => 'persuna: pel clera, barba',
    '🧔🏼' => 'persuna: pel mez clera, barba',
    '🧔🏽' => 'persuna: pel media, barba',
    '🧔🏾' => 'persuna: pel mez stgira, barba',
    '🧔🏿' => 'persuna: pel stgira, barba',
    '👩🏻' => 'dunna: pel clera',
    '👩🏼' => 'dunna: pel mez clera',
    '👩🏽' => 'dunna: pel media',
    '👩🏾' => 'dunna: pel mez stgira',
    '👩🏿' => 'dunna: pel stgira',
    '🧓🏻' => 'persuna pli veglia: pel clera',
    '🧓🏼' => 'persuna pli veglia: pel mez clera',
    '🧓🏽' => 'persuna pli veglia: pel media',
    '🧓🏾' => 'persuna pli veglia: pel mez stgira',
    '🧓🏿' => 'persuna pli veglia: pel stgira',
    '👴🏻' => 'um vegl: pel clera',
    '👴🏼' => 'um vegl: pel mez clera',
    '👴🏽' => 'um vegl: pel media',
    '👴🏾' => 'um vegl: pel mez stgira',
    '👴🏿' => 'um vegl: pel stgira',
    '👵🏻' => 'dunna veglia: pel clera',
    '👵🏼' => 'dunna veglia: pel mez clera',
    '👵🏽' => 'dunna veglia: pel media',
    '👵🏾' => 'dunna veglia: pel mez stgira',
    '👵🏿' => 'dunna veglia: pel stgira',
    '🙍🏻' => 'persuna malcuntenta: pel clera',
    '🙍🏼' => 'persuna malcuntenta: pel mez clera',
    '🙍🏽' => 'persuna malcuntenta: pel media',
    '🙍🏾' => 'persuna malcuntenta: pel mez stgira',
    '🙍🏿' => 'persuna malcuntenta: pel stgira',
    '🙎🏻' => 'persuna permalada: pel clera',
    '🙎🏼' => 'persuna permalada: pel mez clera',
    '🙎🏽' => 'persuna permalada: pel media',
    '🙎🏾' => 'persuna permalada: pel mez stgira',
    '🙎🏿' => 'persuna permalada: pel stgira',
    '🙅🏻' => 'persuna cun bratscha cruschada: pel clera',
    '🙅🏼' => 'persuna cun bratscha cruschada: pel mez clera',
    '🙅🏽' => 'persuna cun bratscha cruschada: pel media',
    '🙅🏾' => 'persuna cun bratscha cruschada: pel mez stgira',
    '🙅🏿' => 'persuna cun bratscha cruschada: pel stgira',
    '🙆🏻' => 'persuna che tegna ils mauns sin il chau: pel clera',
    '🙆🏼' => 'persuna che tegna ils mauns sin il chau: pel mez clera',
    '🙆🏽' => 'persuna che tegna ils mauns sin il chau: pel media',
    '🙆🏾' => 'persuna che tegna ils mauns sin il chau: pel mez stgira',
    '🙆🏿' => 'persuna che tegna ils mauns sin il chau: pel stgira',
    '💁🏻' => 'persuna che tegna la palma-maun vers ensi: pel clera',
    '💁🏼' => 'persuna che tegna la palma-maun vers ensi: pel mez clera',
    '💁🏽' => 'persuna che tegna la palma-maun vers ensi: pel media',
    '💁🏾' => 'persuna che tegna la palma-maun vers ensi: pel mez stgira',
    '💁🏿' => 'persuna che tegna la palma-maun vers ensi: pel stgira',
    '🙋🏻' => 'persuna che auza il maun: pel clera',
    '🙋🏼' => 'persuna che auza il maun: pel mez clera',
    '🙋🏽' => 'persuna che auza il maun: pel media',
    '🙋🏾' => 'persuna che auza il maun: pel mez stgira',
    '🙋🏿' => 'persuna che auza il maun: pel stgira',
    '🧏🏻' => 'persuna surda: pel clera',
    '🧏🏼' => 'persuna surda: pel mez clera',
    '🧏🏽' => 'persuna surda: pel media',
    '🧏🏾' => 'persuna surda: pel mez stgira',
    '🧏🏿' => 'persuna surda: pel stgira',
    '🙇🏻' => 'persuna che s’enclina: pel clera',
    '🙇🏼' => 'persuna che s’enclina: pel mez clera',
    '🙇🏽' => 'persuna che s’enclina: pel media',
    '🙇🏾' => 'persuna che s’enclina: pel mez stgira',
    '🙇🏿' => 'persuna che s’enclina: pel stgira',
    '🤦🏻' => 'persuna cun la palma-maun sin la fatscha: pel clera',
    '🤦🏼' => 'persuna cun la palma-maun sin la fatscha: pel mez clera',
    '🤦🏽' => 'persuna cun la palma-maun sin la fatscha: pel media',
    '🤦🏾' => 'persuna cun la palma-maun sin la fatscha: pel mez stgira',
    '🤦🏿' => 'persuna cun la palma-maun sin la fatscha: pel stgira',
    '🤷🏻' => 'persuna che auza las spatlas: pel clera',
    '🤷🏼' => 'persuna che auza las spatlas: pel mez clera',
    '🤷🏽' => 'persuna che auza las spatlas: pel media',
    '🤷🏾' => 'persuna che auza las spatlas: pel mez stgira',
    '🤷🏿' => 'persuna che auza las spatlas: pel stgira',
    '👮🏻' => 'policist:a: pel clera',
    '👮🏼' => 'policist:a: pel mez clera',
    '👮🏽' => 'policist:a: pel media',
    '👮🏾' => 'policist:a: pel mez stgira',
    '👮🏿' => 'policist:a: pel stgira',
    '🕵🏻' => 'detectiv:a: pel clera',
    '🕵🏼' => 'detectiv:a: pel mez clera',
    '🕵🏽' => 'detectiv:a: pel media',
    '🕵🏾' => 'detectiv:a: pel mez stgira',
    '🕵🏿' => 'detectiv:a: pel stgira',
    '🥷🏻' => 'ninja: pel clera',
    '🥷🏼' => 'ninja: pel mez clera',
    '🥷🏽' => 'ninja: pel media',
    '🥷🏾' => 'ninja: pel mez stgira',
    '🥷🏿' => 'ninja: pel stgira',
    '👷🏻' => 'lavurer:a da construcziun: pel clera',
    '👷🏼' => 'lavurer:a da construcziun: pel mez clera',
    '👷🏽' => 'lavurer:a da construcziun: pel media',
    '👷🏾' => 'lavurer:a da construcziun: pel mez stgira',
    '👷🏿' => 'lavurer:a da construcziun: pel stgira',
    '🫅🏻' => 'persuna cun curuna: pel clera',
    '🫅🏼' => 'persuna cun curuna: pel mez clera',
    '🫅🏽' => 'persuna cun curuna: pel media',
    '🫅🏾' => 'persuna cun curuna: pel mez stgira',
    '🫅🏿' => 'persuna cun curuna: pel stgira',
    '🤴🏻' => 'prinzi: pel clera',
    '🤴🏼' => 'prinzi: pel mez clera',
    '🤴🏽' => 'prinzi: pel media',
    '🤴🏾' => 'prinzi: pel mez stgira',
    '🤴🏿' => 'prinzi: pel stgira',
    '👸🏻' => 'princessa: pel clera',
    '👸🏼' => 'princessa: pel mez clera',
    '👸🏽' => 'princessa: pel media',
    '👸🏾' => 'princessa: pel mez stgira',
    '👸🏿' => 'princessa: pel stgira',
    '👳🏻' => 'persuna cun in turban: pel clera',
    '👳🏼' => 'persuna cun in turban: pel mez clera',
    '👳🏽' => 'persuna cun in turban: pel media',
    '👳🏾' => 'persuna cun in turban: pel mez stgira',
    '👳🏿' => 'persuna cun in turban: pel stgira',
    '👲🏻' => 'persuna cun in chapè chinais: pel clera',
    '👲🏼' => 'persuna cun in chapè chinais: pel mez clera',
    '👲🏽' => 'persuna cun in chapè chinais: pel media',
    '👲🏾' => 'persuna cun in chapè chinais: pel mez stgira',
    '👲🏿' => 'persuna cun in chapè chinais: pel stgira',
    '🧕🏻' => 'dunna cun faziel da chau: pel clera',
    '🧕🏼' => 'dunna cun faziel da chau: pel mez clera',
    '🧕🏽' => 'dunna cun faziel da chau: pel media',
    '🧕🏾' => 'dunna cun faziel da chau: pel mez stgira',
    '🧕🏿' => 'dunna cun faziel da chau: pel stgira',
    '🤵🏻' => 'persuna cun smoking: pel clera',
    '🤵🏼' => 'persuna cun smoking: pel mez clera',
    '🤵🏽' => 'persuna cun smoking: pel media',
    '🤵🏾' => 'persuna cun smoking: pel mez stgira',
    '🤵🏿' => 'persuna cun smoking: pel stgira',
    '👰🏻' => 'persuna cun vel: pel clera',
    '👰🏼' => 'persuna cun vel: pel mez clera',
    '👰🏽' => 'persuna cun vel: pel media',
    '👰🏾' => 'persuna cun vel: pel mez stgira',
    '👰🏿' => 'persuna cun vel: pel stgira',
    '🤰🏻' => 'dunna en speranza: pel clera',
    '🤰🏼' => 'dunna en speranza: pel mez clera',
    '🤰🏽' => 'dunna en speranza: pel media',
    '🤰🏾' => 'dunna en speranza: pel mez stgira',
    '🤰🏿' => 'dunna en speranza: pel stgira',
    '🫃🏻' => 'um en speranza: pel clera',
    '🫃🏼' => 'um en speranza: pel mez clera',
    '🫃🏽' => 'um en speranza: pel media',
    '🫃🏾' => 'um en speranza: pel mez stgira',
    '🫃🏿' => 'um en speranza: pel stgira',
    '🫄🏻' => 'persuna en speranza: pel clera',
    '🫄🏼' => 'persuna en speranza: pel mez clera',
    '🫄🏽' => 'persuna en speranza: pel media',
    '🫄🏾' => 'persuna en speranza: pel mez stgira',
    '🫄🏿' => 'persuna en speranza: pel stgira',
    '🤱🏻' => 'dar latg: pel clera',
    '🤱🏼' => 'dar latg: pel mez clera',
    '🤱🏽' => 'dar latg: pel media',
    '🤱🏾' => 'dar latg: pel mez stgira',
    '🤱🏿' => 'dar latg: pel stgira',
    '👼🏻' => 'anghelin: pel clera',
    '👼🏼' => 'anghelin: pel mez clera',
    '👼🏽' => 'anghelin: pel media',
    '👼🏾' => 'anghelin: pel mez stgira',
    '👼🏿' => 'anghelin: pel stgira',
    '🎅🏻' => 'Son Niclà: pel clera',
    '🎅🏼' => 'Son Niclà: pel mez clera',
    '🎅🏽' => 'Son Niclà: pel media',
    '🎅🏾' => 'Son Niclà: pel mez stgira',
    '🎅🏿' => 'Son Niclà: pel stgira',
    '🤶🏻' => 'Sontga Nicoletta: pel clera',
    '🤶🏼' => 'Sontga Nicoletta: pel mez clera',
    '🤶🏽' => 'Sontga Nicoletta: pel media',
    '🤶🏾' => 'Sontga Nicoletta: pel mez stgira',
    '🤶🏿' => 'Sontga Nicoletta: pel stgira',
    '🦸🏻' => 'supererox:a: pel clera',
    '🦸🏼' => 'supererox:a: pel mez clera',
    '🦸🏽' => 'supererox:a: pel media',
    '🦸🏾' => 'supererox:a: pel mez stgira',
    '🦸🏿' => 'supererox:a: pel stgira',
    '🦹🏻' => 'supernausch:a: pel clera',
    '🦹🏼' => 'supernausch:a: pel mez clera',
    '🦹🏽' => 'supernausch:a: pel media',
    '🦹🏾' => 'supernausch:a: pel mez stgira',
    '🦹🏿' => 'supernausch:a: pel stgira',
    '🧙🏻' => 'striun:a: pel clera',
    '🧙🏼' => 'striun:a: pel mez clera',
    '🧙🏽' => 'striun:a: pel media',
    '🧙🏾' => 'striun:a: pel mez stgira',
    '🧙🏿' => 'striun:a: pel stgira',
    '🧚🏻' => 'dial:a: pel clera',
    '🧚🏼' => 'dial:a: pel mez clera',
    '🧚🏽' => 'dial:a: pel media',
    '🧚🏾' => 'dial:a: pel mez stgira',
    '🧚🏿' => 'dial:a: pel stgira',
    '🧛🏻' => 'vampir:a: pel clera',
    '🧛🏼' => 'vampir:a: pel mez clera',
    '🧛🏽' => 'vampir:a: pel media',
    '🧛🏾' => 'vampir:a: pel mez stgira',
    '🧛🏿' => 'vampir:a: pel stgira',
    '🧜🏻' => 'uman da l’aua: pel clera',
    '🧜🏼' => 'uman da l’aua: pel mez clera',
    '🧜🏽' => 'uman da l’aua: pel media',
    '🧜🏾' => 'uman da l’aua: pel mez stgira',
    '🧜🏿' => 'uman da l’aua: pel stgira',
    '🧝🏻' => 'elf:a: pel clera',
    '🧝🏼' => 'elf:a: pel mez clera',
    '🧝🏽' => 'elf:a: pel media',
    '🧝🏾' => 'elf:a: pel mez stgira',
    '🧝🏿' => 'elf:a: pel stgira',
    '💆🏻' => 'persuna che vegn massada: pel clera',
    '💆🏼' => 'persuna che vegn massada: pel mez clera',
    '💆🏽' => 'persuna che vegn massada: pel media',
    '💆🏾' => 'persuna che vegn massada: pel mez stgira',
    '💆🏿' => 'persuna che vegn massada: pel stgira',
    '💇🏻' => 'persuna che sa lascha tagliar ils chavels: pel clera',
    '💇🏼' => 'persuna che sa lascha tagliar ils chavels: pel mez clera',
    '💇🏽' => 'persuna che sa lascha tagliar ils chavels: pel media',
    '💇🏾' => 'persuna che sa lascha tagliar ils chavels: pel mez stgira',
    '💇🏿' => 'persuna che sa lascha tagliar ils chavels: pel stgira',
    '🚶🏻' => 'persuna che va a pe: pel clera',
    '🚶🏼' => 'persuna che va a pe: pel mez clera',
    '🚶🏽' => 'persuna che va a pe: pel media',
    '🚶🏾' => 'persuna che va a pe: pel mez stgira',
    '🚶🏿' => 'persuna che va a pe: pel stgira',
    '🧍🏻' => 'persuna en pe: pel clera',
    '🧍🏼' => 'persuna en pe: pel mez clera',
    '🧍🏽' => 'persuna en pe: pel media',
    '🧍🏾' => 'persuna en pe: pel mez stgira',
    '🧍🏿' => 'persuna en pe: pel stgira',
    '🧎🏻' => 'persuna en schanuglias: pel clera',
    '🧎🏼' => 'persuna en schanuglias: pel mez clera',
    '🧎🏽' => 'persuna en schanuglias: pel media',
    '🧎🏾' => 'persuna en schanuglias: pel mez stgira',
    '🧎🏿' => 'persuna en schanuglias: pel stgira',
    '🏃🏻' => 'persuna che curra: pel clera',
    '🏃🏼' => 'persuna che curra: pel mez clera',
    '🏃🏽' => 'persuna che curra: pel media',
    '🏃🏾' => 'persuna che curra: pel mez stgira',
    '🏃🏿' => 'persuna che curra: pel stgira',
    '💃🏻' => 'dunna che balla: pel clera',
    '💃🏼' => 'dunna che balla: pel mez clera',
    '💃🏽' => 'dunna che balla: pel media',
    '💃🏾' => 'dunna che balla: pel mez stgira',
    '💃🏿' => 'dunna che balla: pel stgira',
    '🕺🏻' => 'um che balla: pel clera',
    '🕺🏼' => 'um che balla: pel mez clera',
    '🕺🏽' => 'um che balla: pel media',
    '🕺🏾' => 'um che balla: pel mez stgira',
    '🕺🏿' => 'um che balla: pel stgira',
    '🕴🏻' => 'persuna en vestgì che levitescha: pel clera',
    '🕴🏼' => 'persuna en vestgì che levitescha: pel mez clera',
    '🕴🏽' => 'persuna en vestgì che levitescha: pel media',
    '🕴🏾' => 'persuna en vestgì che levitescha: pel mez stgira',
    '🕴🏿' => 'persuna en vestgì che levitescha: pel stgira',
    '👯🏻' => 'persunas cun ureglias da lieur: pel clera',
    '👯🏼' => 'persunas cun ureglias da lieur: pel mez clera',
    '👯🏽' => 'persunas cun ureglias da lieur: pel media',
    '👯🏾' => 'persunas cun ureglias da lieur: pel mez stgira',
    '👯🏿' => 'persunas cun ureglias da lieur: pel stgira',
    '🧖🏻' => 'persuna en ina stanza cun vapur: pel clera',
    '🧖🏼' => 'persuna en ina stanza cun vapur: pel mez clera',
    '🧖🏽' => 'persuna en ina stanza cun vapur: pel media',
    '🧖🏾' => 'persuna en ina stanza cun vapur: pel mez stgira',
    '🧖🏿' => 'persuna en ina stanza cun vapur: pel stgira',
    '🧗🏻' => 'persuna che raiva: pel clera',
    '🧗🏼' => 'persuna che raiva: pel mez clera',
    '🧗🏽' => 'persuna che raiva: pel media',
    '🧗🏾' => 'persuna che raiva: pel mez stgira',
    '🧗🏿' => 'persuna che raiva: pel stgira',
    '🏇🏻' => 'cursa da chavals: pel clera',
    '🏇🏼' => 'cursa da chavals: pel mez clera',
    '🏇🏽' => 'cursa da chavals: pel media',
    '🏇🏾' => 'cursa da chavals: pel mez stgira',
    '🏇🏿' => 'cursa da chavals: pel stgira',
    '🏂🏻' => 'snowboardist:a: pel clera',
    '🏂🏼' => 'snowboardist:a: pel mez clera',
    '🏂🏽' => 'snowboardist:a: pel media',
    '🏂🏾' => 'snowboardist:a: pel mez stgira',
    '🏂🏿' => 'snowboardist:a: pel stgira',
    '🏌🏻' => 'persuna che dat golf: pel clera',
    '🏌🏼' => 'persuna che dat golf: pel mez clera',
    '🏌🏽' => 'persuna che dat golf: pel media',
    '🏌🏾' => 'persuna che dat golf: pel mez stgira',
    '🏌🏿' => 'persuna che dat golf: pel stgira',
    '🏄🏻' => 'persuna che fa surfing: pel clera',
    '🏄🏼' => 'persuna che fa surfing: pel mez clera',
    '🏄🏽' => 'persuna che fa surfing: pel media',
    '🏄🏾' => 'persuna che fa surfing: pel mez stgira',
    '🏄🏿' => 'persuna che fa surfing: pel stgira',
    '🚣🏻' => 'persuna che rembla: pel clera',
    '🚣🏼' => 'persuna che rembla: pel mez clera',
    '🚣🏽' => 'persuna che rembla: pel media',
    '🚣🏾' => 'persuna che rembla: pel mez stgira',
    '🚣🏿' => 'persuna che rembla: pel stgira',
    '🏊🏻' => 'persuna che noda: pel clera',
    '🏊🏼' => 'persuna che noda: pel mez clera',
    '🏊🏽' => 'persuna che noda: pel media',
    '🏊🏾' => 'persuna che noda: pel mez stgira',
    '🏊🏿' => 'persuna che noda: pel stgira',
    '⛹🏻' => 'persuna cun balla: pel clera',
    '⛹🏼' => 'persuna cun balla: pel mez clera',
    '⛹🏽' => 'persuna cun balla: pel media',
    '⛹🏾' => 'persuna cun balla: pel mez stgira',
    '⛹🏿' => 'persuna cun balla: pel stgira',
    '🏋🏻' => 'persuna che auza pais: pel clera',
    '🏋🏼' => 'persuna che auza pais: pel mez clera',
    '🏋🏽' => 'persuna che auza pais: pel media',
    '🏋🏾' => 'persuna che auza pais: pel mez stgira',
    '🏋🏿' => 'persuna che auza pais: pel stgira',
    '🚴🏻' => 'persuna che va cun velo: pel clera',
    '🚴🏼' => 'persuna che va cun velo: pel mez clera',
    '🚴🏽' => 'persuna che va cun velo: pel media',
    '🚴🏾' => 'persuna che va cun velo: pel mez stgira',
    '🚴🏿' => 'persuna che va cun velo: pel stgira',
    '🚵🏻' => 'persuna che va cun mountainbike: pel clera',
    '🚵🏼' => 'persuna che va cun mountainbike: pel mez clera',
    '🚵🏽' => 'persuna che va cun mountainbike: pel media',
    '🚵🏾' => 'persuna che va cun mountainbike: pel mez stgira',
    '🚵🏿' => 'persuna che va cun mountainbike: pel stgira',
    '🤸🏻' => 'persuna che fa la roda: pel clera',
    '🤸🏼' => 'persuna che fa la roda: pel mez clera',
    '🤸🏽' => 'persuna che fa la roda: pel media',
    '🤸🏾' => 'persuna che fa la roda: pel mez stgira',
    '🤸🏿' => 'persuna che fa la roda: pel stgira',
    '🤼🏻' => 'persunas che lutgan: pel clera',
    '🤼🏼' => 'persunas che lutgan: pel mez clera',
    '🤼🏽' => 'persunas che lutgan: pel media',
    '🤼🏾' => 'persunas che lutgan: pel mez stgira',
    '🤼🏿' => 'persunas che lutgan: pel stgira',
    '🤽🏻' => 'persuna che gioga ballanataziun: pel clera',
    '🤽🏼' => 'persuna che gioga ballanataziun: pel mez clera',
    '🤽🏽' => 'persuna che gioga ballanataziun: pel media',
    '🤽🏾' => 'persuna che gioga ballanataziun: pel mez stgira',
    '🤽🏿' => 'persuna che gioga ballanataziun: pel stgira',
    '🤾🏻' => 'persuna che gioga ballamaun: pel clera',
    '🤾🏼' => 'persuna che gioga ballamaun: pel mez clera',
    '🤾🏽' => 'persuna che gioga ballamaun: pel media',
    '🤾🏾' => 'persuna che gioga ballamaun: pel mez stgira',
    '🤾🏿' => 'persuna che gioga ballamaun: pel stgira',
    '🤹🏻' => 'persuna che schonglescha: pel clera',
    '🤹🏼' => 'persuna che schonglescha: pel mez clera',
    '🤹🏽' => 'persuna che schonglescha: pel media',
    '🤹🏾' => 'persuna che schonglescha: pel mez stgira',
    '🤹🏿' => 'persuna che schonglescha: pel stgira',
    '🧘🏻' => 'persuna en la posiziun da lotos: pel clera',
    '🧘🏼' => 'persuna en la posiziun da lotos: pel mez clera',
    '🧘🏽' => 'persuna en la posiziun da lotos: pel media',
    '🧘🏾' => 'persuna en la posiziun da lotos: pel mez stgira',
    '🧘🏿' => 'persuna en la posiziun da lotos: pel stgira',
    '🛀🏻' => 'persuna che fa bogn: pel clera',
    '🛀🏼' => 'persuna che fa bogn: pel mez clera',
    '🛀🏽' => 'persuna che fa bogn: pel media',
    '🛀🏾' => 'persuna che fa bogn: pel mez stgira',
    '🛀🏿' => 'persuna che fa bogn: pel stgira',
    '🛌🏻' => 'persuna en letg: pel clera',
    '🛌🏼' => 'persuna en letg: pel mez clera',
    '🛌🏽' => 'persuna en letg: pel media',
    '🛌🏾' => 'persuna en letg: pel mez stgira',
    '🛌🏿' => 'persuna en letg: pel stgira',
    '👭🏻' => 'dunnas che tegnan il maun: pel clera',
    '👭🏼' => 'dunnas che tegnan il maun: pel mez clera',
    '👭🏽' => 'dunnas che tegnan il maun: pel media',
    '👭🏾' => 'dunnas che tegnan il maun: pel mez stgira',
    '👭🏿' => 'dunnas che tegnan il maun: pel stgira',
    '👫🏻' => 'dunna ed um che tegnan ils mauns: pel clera',
    '👫🏼' => 'dunna ed um che tegnan ils mauns: pel mez clera',
    '👫🏽' => 'dunna ed um che tegnan ils mauns: pel media',
    '👫🏾' => 'dunna ed um che tegnan ils mauns: pel mez stgira',
    '👫🏿' => 'dunna ed um che tegnan ils mauns: pel stgira',
    '👬🏻' => 'umens che tegnan il maun: pel clera',
    '👬🏼' => 'umens che tegnan il maun: pel mez clera',
    '👬🏽' => 'umens che tegnan il maun: pel media',
    '👬🏾' => 'umens che tegnan il maun: pel mez stgira',
    '👬🏿' => 'umens che tegnan il maun: pel stgira',
    '💏🏻' => 'bitsch: pel clera',
    '💏🏼' => 'bitsch: pel mez clera',
    '💏🏽' => 'bitsch: pel media',
    '💏🏾' => 'bitsch: pel mez stgira',
    '💏🏿' => 'bitsch: pel stgira',
    '💑🏻' => 'pèr cun cor: pel clera',
    '💑🏼' => 'pèr cun cor: pel mez clera',
    '💑🏽' => 'pèr cun cor: pel media',
    '💑🏾' => 'pèr cun cor: pel mez stgira',
    '💑🏿' => 'pèr cun cor: pel stgira',
    '🇦🇨' => 'bandiera: Insla da l’Ascensiun',
    '🇦🇩' => 'bandiera: Andorra',
    '🇦🇪' => 'bandiera: Emirats Arabs Unids',
    '🇦🇫' => 'bandiera: Afganistan',
    '🇦🇬' => 'bandiera: Antigua e Barbuda',
    '🇦🇮' => 'bandiera: Anguilla',
    '🇦🇱' => 'bandiera: Albania',
    '🇦🇲' => 'bandiera: Armenia',
    '🇦🇴' => 'bandiera: Angola',
    '🇦🇶' => 'bandiera: Antarctica',
    '🇦🇷' => 'bandiera: Argentina',
    '🇦🇸' => 'bandiera: Samoa Americana',
    '🇦🇹' => 'bandiera: Austria',
    '🇦🇺' => 'bandiera: Australia',
    '🇦🇼' => 'bandiera: Aruba',
    '🇦🇽' => 'bandiera: Inslas Aland',
    '🇦🇿' => 'bandiera: Aserbaidschan',
    '🇧🇦' => 'bandiera: Bosnia ed Erzegovina',
    '🇧🇧' => 'bandiera: Barbados',
    '🇧🇩' => 'bandiera: Bangladesch',
    '🇧🇪' => 'bandiera: Belgia',
    '🇧🇫' => 'bandiera: Burkina Faso',
    '🇧🇬' => 'bandiera: Bulgaria',
    '🇧🇭' => 'bandiera: Bahrain',
    '🇧🇮' => 'bandiera: Burundi',
    '🇧🇯' => 'bandiera: Benin',
    '🇧🇱' => 'bandiera: Son Barthélemy',
    '🇧🇲' => 'bandiera: Bermudas',
    '🇧🇳' => 'bandiera: Brunei',
    '🇧🇴' => 'bandiera: Bolivia',
    '🇧🇶' => 'bandiera: Pajais Bass caribics',
    '🇧🇷' => 'bandiera: Brasilia',
    '🇧🇸' => 'bandiera: Bahamas',
    '🇧🇹' => 'bandiera: Butan',
    '🇧🇻' => 'bandiera: Insla da Bouvet',
    '🇧🇼' => 'bandiera: Botsuana',
    '🇧🇾' => 'bandiera: Belarus',
    '🇧🇿' => 'bandiera: Belize',
    '🇨🇦' => 'bandiera: Canada',
    '🇨🇨' => 'bandiera: Inslas Cocos',
    '🇨🇩' => 'bandiera: Congo-Kinshasa',
    '🇨🇫' => 'bandiera: Republica Centralafricana',
    '🇨🇬' => 'bandiera: Congo-Brazzaville',
    '🇨🇭' => 'bandiera: Svizra',
    '🇨🇮' => 'bandiera: Costa d’Ivur',
    '🇨🇰' => 'bandiera: Inslas Cook',
    '🇨🇱' => 'bandiera: Chile',
    '🇨🇲' => 'bandiera: Camerun',
    '🇨🇳' => 'bandiera: China',
    '🇨🇴' => 'bandiera: Columbia',
    '🇨🇵' => 'bandiera: Insla Clipperton',
    '🇨🇶' => 'bandiera: Sark',
    '🇨🇷' => 'bandiera: Costa Rica',
    '🇨🇺' => 'bandiera: Cuba',
    '🇨🇻' => 'bandiera: Cap Verd',
    '🇨🇼' => 'bandiera: Curaçao',
    '🇨🇽' => 'bandiera: Insla da Nadal',
    '🇨🇾' => 'bandiera: Cipra',
    '🇨🇿' => 'bandiera: Tschechia',
    '🇩🇪' => 'bandiera: Germania',
    '🇩🇬' => 'bandiera: Diego Garcia',
    '🇩🇯' => 'bandiera: Dschibuti',
    '🇩🇰' => 'bandiera: Danemarc',
    '🇩🇲' => 'bandiera: Dominica',
    '🇩🇴' => 'bandiera: Republica Dominicana',
    '🇩🇿' => 'bandiera: Algeria',
    '🇪🇦' => 'bandiera: Ceuta e Melilla',
    '🇪🇨' => 'bandiera: Ecuador',
    '🇪🇪' => 'bandiera: Estonia',
    '🇪🇬' => 'bandiera: Egipta',
    '🇪🇭' => 'bandiera: Sahara Occidentala',
    '🇪🇷' => 'bandiera: Eritrea',
    '🇪🇸' => 'bandiera: Spagna',
    '🇪🇹' => 'bandiera: Etiopia',
    '🇪🇺' => 'bandiera: Uniun europeica',
    '🇫🇮' => 'bandiera: Finlanda',
    '🇫🇯' => 'bandiera: Fidschi',
    '🇫🇰' => 'bandiera: Inslas Falkland',
    '🇫🇲' => 'bandiera: Micronesia',
    '🇫🇴' => 'bandiera: Inslas Feroe',
    '🇫🇷' => 'bandiera: Frantscha',
    '🇬🇦' => 'bandiera: Gabun',
    '🇬🇧' => 'bandiera: Reginavel Unì',
    '🇬🇩' => 'bandiera: Grenada',
    '🇬🇪' => 'bandiera: Georgia',
    '🇬🇫' => 'bandiera: Guyana Franzosa',
    '🇬🇬' => 'bandiera: Guernsey',
    '🇬🇭' => 'bandiera: Ghana',
    '🇬🇮' => 'bandiera: Gibraltar',
    '🇬🇱' => 'bandiera: Grönlanda',
    '🇬🇲' => 'bandiera: Gambia',
    '🇬🇳' => 'bandiera: Guinea',
    '🇬🇵' => 'bandiera: Guadalupa',
    '🇬🇶' => 'bandiera: Guinea Equatoriala',
    '🇬🇷' => 'bandiera: Grezia',
    '🇬🇸' => 'bandiera: Georgia dal Sid e las Inslas Sandwich dal Sid',
    '🇬🇹' => 'bandiera: Guatemala',
    '🇬🇺' => 'bandiera: Guam',
    '🇬🇼' => 'bandiera: Guinea-Bissau',
    '🇬🇾' => 'bandiera: Guyana',
    '🇭🇰' => 'bandiera: Regiun d’administraziun speziala Hongkong, China',
    '🇭🇲' => 'bandiera: Inslas da Heard e McDonald',
    '🇭🇳' => 'bandiera: Honduras',
    '🇭🇷' => 'bandiera: Croazia',
    '🇭🇹' => 'bandiera: Haiti',
    '🇭🇺' => 'bandiera: Ungaria',
    '🇮🇨' => 'bandiera: Inslas Canarias',
    '🇮🇩' => 'bandiera: Indonesia',
    '🇮🇪' => 'bandiera: Irlanda',
    '🇮🇱' => 'bandiera: Israel',
    '🇮🇲' => 'bandiera: Insla da Man',
    '🇮🇳' => 'bandiera: India',
    '🇮🇴' => 'bandiera: Territori Britannic da l’Ocean Indic',
    '🇮🇶' => 'bandiera: Irac',
    '🇮🇷' => 'bandiera: Iran',
    '🇮🇸' => 'bandiera: Islanda',
    '🇮🇹' => 'bandiera: Italia',
    '🇯🇪' => 'bandiera: Jersey',
    '🇯🇲' => 'bandiera: Giamaica',
    '🇯🇴' => 'bandiera: Jordania',
    '🇯🇵' => 'bandiera: Giapun',
    '🇰🇪' => 'bandiera: Kenia',
    '🇰🇬' => 'bandiera: Kirghistan',
    '🇰🇭' => 'bandiera: Cambodscha',
    '🇰🇮' => 'bandiera: Kiribati',
    '🇰🇲' => 'bandiera: Comoras',
    '🇰🇳' => 'bandiera: Son Cristof e Nevis',
    '🇰🇵' => 'bandiera: Corea dal Nord',
    '🇰🇷' => 'bandiera: Corea dal Sid',
    '🇰🇼' => 'bandiera: Kuwait',
    '🇰🇾' => 'bandiera: Inslas Cayman',
    '🇰🇿' => 'bandiera: Kasachstan',
    '🇱🇦' => 'bandiera: Laos',
    '🇱🇧' => 'bandiera: Libanon',
    '🇱🇨' => 'bandiera: Sontga Lucia',
    '🇱🇮' => 'bandiera: Liechtenstein',
    '🇱🇰' => 'bandiera: Sri Lanka',
    '🇱🇷' => 'bandiera: Liberia',
    '🇱🇸' => 'bandiera: Lesotho',
    '🇱🇹' => 'bandiera: Lituania',
    '🇱🇺' => 'bandiera: Luxemburg',
    '🇱🇻' => 'bandiera: Lettonia',
    '🇱🇾' => 'bandiera: Libia',
    '🇲🇦' => 'bandiera: Maroc',
    '🇲🇨' => 'bandiera: Monaco',
    '🇲🇩' => 'bandiera: Moldavia',
    '🇲🇪' => 'bandiera: Montenegro',
    '🇲🇫' => 'bandiera: Saint Martin',
    '🇲🇬' => 'bandiera: Madagascar',
    '🇲🇭' => 'bandiera: Inslas da Marshall',
    '🇲🇰' => 'bandiera: Macedonia dal Nord',
    '🇲🇱' => 'bandiera: Mali',
    '🇲🇲' => 'bandiera: Myanmar (Burma)',
    '🇲🇳' => 'bandiera: Mongolia',
    '🇲🇴' => 'bandiera: Regiun d’administraziun speziala Macao, China',
    '🇲🇵' => 'bandiera: Inslas Mariannas dal Nord',
    '🇲🇶' => 'bandiera: Martinica',
    '🇲🇷' => 'bandiera: Mauretania',
    '🇲🇸' => 'bandiera: Montserrat',
    '🇲🇹' => 'bandiera: Malta',
    '🇲🇺' => 'bandiera: Mauritius',
    '🇲🇻' => 'bandiera: Maledivas',
    '🇲🇼' => 'bandiera: Malawi',
    '🇲🇽' => 'bandiera: Mexico',
    '🇲🇾' => 'bandiera: Malaisia',
    '🇲🇿' => 'bandiera: Mosambic',
    '🇳🇦' => 'bandiera: Namibia',
    '🇳🇨' => 'bandiera: Nova Caledonia',
    '🇳🇪' => 'bandiera: Niger',
    '🇳🇫' => 'bandiera: Insla Norfolk',
    '🇳🇬' => 'bandiera: Nigeria',
    '🇳🇮' => 'bandiera: Nicaragua',
    '🇳🇱' => 'bandiera: Pajais Bass',
    '🇳🇴' => 'bandiera: Norvegia',
    '🇳🇵' => 'bandiera: Nepal',
    '🇳🇷' => 'bandiera: Nauru',
    '🇳🇺' => 'bandiera: Niue',
    '🇳🇿' => 'bandiera: Nova Zelanda',
    '🇴🇲' => 'bandiera: Oman',
    '🇵🇦' => 'bandiera: Panama',
    '🇵🇪' => 'bandiera: Peru',
    '🇵🇫' => 'bandiera: Polinesia Franzosa',
    '🇵🇬' => 'bandiera: Papua Nova Guinea',
    '🇵🇭' => 'bandiera: Filippinas',
    '🇵🇰' => 'bandiera: Pakistan',
    '🇵🇱' => 'bandiera: Pologna',
    '🇵🇲' => 'bandiera: Saint Pierre e Miquelon',
    '🇵🇳' => 'bandiera: Pitcairn',
    '🇵🇷' => 'bandiera: Puerto Rico',
    '🇵🇸' => 'bandiera: Territori Palestinais',
    '🇵🇹' => 'bandiera: Portugal',
    '🇵🇼' => 'bandiera: Palau',
    '🇵🇾' => 'bandiera: Paraguai',
    '🇶🇦' => 'bandiera: Qatar',
    '🇷🇪' => 'bandiera: Réunion',
    '🇷🇴' => 'bandiera: Rumenia',
    '🇷🇸' => 'bandiera: Serbia',
    '🇷🇺' => 'bandiera: Russia',
    '🇷🇼' => 'bandiera: Ruanda',
    '🇸🇦' => 'bandiera: Arabia Saudita',
    '🇸🇧' => 'bandiera: Inslas da Salomon',
    '🇸🇨' => 'bandiera: Seychellas',
    '🇸🇩' => 'bandiera: Sudan',
    '🇸🇪' => 'bandiera: Svezia',
    '🇸🇬' => 'bandiera: Singapur',
    '🇸🇭' => 'bandiera: Sontg’Elena',
    '🇸🇮' => 'bandiera: Slovenia',
    '🇸🇯' => 'bandiera: Svalbard e Jan Mayen',
    '🇸🇰' => 'bandiera: Slovachia',
    '🇸🇱' => 'bandiera: Sierra Leone',
    '🇸🇲' => 'bandiera: Son Marin',
    '🇸🇳' => 'bandiera: Senegal',
    '🇸🇴' => 'bandiera: Somalia',
    '🇸🇷' => 'bandiera: Surinam',
    '🇸🇸' => 'bandiera: Sudan dal Sid',
    '🇸🇹' => 'bandiera: São Tomé e Príncipe',
    '🇸🇻' => 'bandiera: El Salvador',
    '🇸🇽' => 'bandiera: Sint Maarten',
    '🇸🇾' => 'bandiera: Siria',
    '🇸🇿' => 'bandiera: Eswatini',
    '🇹🇦' => 'bandiera: Tristan da Cunha',
    '🇹🇨' => 'bandiera: Inslas Turks e Caicos',
    '🇹🇩' => 'bandiera: Tschad',
    '🇹🇫' => 'bandiera: Territoris Franzos Meridiunals',
    '🇹🇬' => 'bandiera: Togo',
    '🇹🇭' => 'bandiera: Tailanda',
    '🇹🇯' => 'bandiera: Tadschikistan',
    '🇹🇰' => 'bandiera: Tokelau',
    '🇹🇱' => 'bandiera: Timor da l’Ost',
    '🇹🇲' => 'bandiera: Turkmenistan',
    '🇹🇳' => 'bandiera: Tunesia',
    '🇹🇴' => 'bandiera: Tonga',
    '🇹🇷' => 'bandiera: Tirchia',
    '🇹🇹' => 'bandiera: Trinidad e Tobago',
    '🇹🇻' => 'bandiera: Tuvalu',
    '🇹🇼' => 'bandiera: Taiwan',
    '🇹🇿' => 'bandiera: Tansania',
    '🇺🇦' => 'bandiera: Ucraina',
    '🇺🇬' => 'bandiera: Uganda',
    '🇺🇲' => 'bandiera: Inslas Pitschnas Perifericas dals Stadis Unids da l’America',
    '🇺🇳' => 'bandiera: Naziuns unidas',
    '🇺🇸' => 'bandiera: Stadis Unids da l’America',
    '🇺🇾' => 'bandiera: Uruguai',
    '🇺🇿' => 'bandiera: Usbekistan',
    '🇻🇦' => 'bandiera: Citad dal Vatican',
    '🇻🇨' => 'bandiera: Son Vincenz e las Grenadinas',
    '🇻🇪' => 'bandiera: Venezuela',
    '🇻🇬' => 'bandiera: Inslas Virginas Britannicas',
    '🇻🇮' => 'bandiera: Inslas Virginas Americanas',
    '🇻🇳' => 'bandiera: Vietnam',
    '🇻🇺' => 'bandiera: Vanuatu',
    '🇼🇫' => 'bandiera: Wallis e Futuna',
    '🇼🇸' => 'bandiera: Samoa',
    '🇽🇰' => 'bandiera: Cosovo',
    '🇾🇪' => 'bandiera: Jemen',
    '🇾🇹' => 'bandiera: Mayotte',
    '🇿🇦' => 'bandiera: Africa dal Sid',
    '🇿🇲' => 'bandiera: Sambia',
    '🇿🇼' => 'bandiera: Simbabwe',
    '🔟' => 'tasta: 10',
    '🏻' => 'pel clera',
    '🏼' => 'pel mez clera',
    '🏽' => 'pel media',
    '🏾' => 'pel mez stgira',
    '🏿' => 'pel stgira',
    '😀' => 'fatscha che ri',
    '😃' => 'fatscha che ri cun gronds egls',
    '😄' => 'fatscha che ri cun egls che surrin',
    '😁' => 'fatscha che ri cun dents',
    '😆' => 'fatscha che ri e tschegna',
    '😅' => 'fatscha che ri cun suaditsch',
    '🤣' => 'fatscha che sa storscha dal rir',
    '😂' => 'fatscha cun larmas da plaschair',
    '🙂' => 'fatscha che surri',
    '🙃' => 'fatscha sutsura',
    '🫠' => 'fatscha che lieua',
    '😉' => 'fatscha che tschegna',
    '😊' => 'fatscha cuntenta cun egls che rin',
    '😇' => 'fatscha che ri cun gloriola',
    '🥰' => 'fatscha che ri cun cors',
    '😍' => 'fatscha che ri cun cors sco egls',
    '🤩' => 'fatscha che ri cun stailas sco egls',
    '😘' => 'fatscha che sufla in cor',
    '😗' => 'fatscha che bitscha',
    '☺' => 'fatscha simpla che ri',
    '😚' => 'fatscha che bitscha cun egls serrads',
    '😙' => 'fatscha che bitscha cun egls che rin',
    '🥲' => 'fatscha che ri cun larma',
    '😋' => 'fatscha che litga ils lefs',
    '😛' => 'fatscha cun lieunga',
    '🤪' => 'fatscha narra',
    '😝' => 'fatscha che tschegna e mussa la lieunga',
    '🤑' => 'fatscha cun daners en bucca',
    '🤗' => 'fatscha che ri cun mauns averts',
    '🤭' => 'fatscha cun maun davant la bucca',
    '🫢' => 'fatscha cun egls averts e maun davant la bucca',
    '🫣' => 'fatscha cun egl che cuchegia',
    '🤫' => 'fatscha cun det che mussa da star airi',
    '🫡' => 'fatscha che salutescha',
    '🤐' => 'fatscha cun bucca da serranetga',
    '🤨' => 'fatscha cun survantscheglia auzada',
    '😐' => 'fatscha neutrala',
    '😑' => 'fatscha senza expressiun',
    '😶' => 'fatscha senza bucca',
    '🫥' => 'fatscha cun lingia da stritgins',
    '😏' => 'fatscha che sghigna',
    '😒' => 'fatscha malcuntenta',
    '🙄' => 'fatscha che volva ils egls',
    '😬' => 'fatscha cun grimassa',
    '🤥' => 'fatscha che di manzegnas',
    '🫨' => 'fatscha che trembla',
    '😌' => 'fatscha surlevgiada',
    '😔' => 'fatscha pensiva',
    '😪' => 'fatscha dormulenta',
    '🤤' => 'fatscha che sbava',
    '😴' => 'fatscha che dorma',
    '🫩' => 'fatscha cun rintgs sut ils egls',
    '😷' => 'fatscha cun mascrina d’igiena',
    '🤒' => 'fatscha cun termometer',
    '🤕' => 'fatscha cun bandascha',
    '🤢' => 'fatscha cun disgust',
    '🤮' => 'fatscha che vomitescha',
    '🤧' => 'fatscha che starnida',
    '🥵' => 'fatscha chauda',
    '🥶' => 'fatscha fraida',
    '🥴' => 'fatscha sturna',
    '😵' => 'fatscha cun egls en furma da crusch',
    '🤯' => 'chau ch’explodescha',
    '🤠' => 'fatscha cun chapè da cowboy',
    '🥳' => 'fatscha da festa',
    '🥸' => 'fatscha cun mascra',
    '😎' => 'fatscha che ri cun egliers da sulegl',
    '🤓' => 'fatscha da nerd',
    '🧐' => 'fatscha cun monochel',
    '🫤' => 'fatscha cun bucca guerscha',
    '😟' => 'fatscha preoccupada',
    '🙁' => 'fatscha deprimida',
    '☹' => 'fatscha deprimida simpla',
    '😮' => 'fatscha cun bucca averta',
    '😯' => 'fatscha surstada',
    '😲' => 'fatscha perplexa',
    '😳' => 'fatscha cun gronds egls e vistas cotschnas',
    '🫪' => 'fatscha defurmada',
    '🥺' => 'fatscha che roga',
    '🥹' => 'fatscha che retegn las larmas',
    '😦' => 'fatscha spaventada cun bucca averta',
    '😧' => 'fatscha plain anguscha',
    '😨' => 'fatscha che ha orrur',
    '😰' => 'fatscha che ha orrur e sua',
    '😥' => 'fatscha trista ma surlevgiada',
    '😢' => 'fatscha che crida',
    '😭' => 'fatscha che bragia dad aut',
    '😱' => 'fatscha che sbragia da la tema',
    '😖' => 'fatscha confusa',
    '😣' => 'fatscha resoluta',
    '😞' => 'fatscha dischillusiunada',
    '😓' => 'fatscha deprimida cun suaditsch',
    '😩' => 'fatscha stracca',
    '😫' => 'fatscha stancla',
    '🥱' => 'fatscha che susda',
    '😤' => 'fatscha cun vapur en il nas',
    '😡' => 'fatscha furiusa',
    '😠' => 'fatscha vilada',
    '🤬' => 'fatscha cun simbols sin la bucca',
    '😈' => 'fatscha cun cornas che ri',
    '👿' => 'fatscha gritta cun cornas',
    '💀' => 'chavazza da mort',
    '☠' => 'chavazza da mort simpla cun ossa en crusch',
    '💩' => 'cac',
    '🤡' => 'fatscha da clown',
    '👹' => 'monster',
    '👺' => 'cobold',
    '👻' => 'spiert',
    '👽' => 'extraterrester',
    '👾' => 'monster en pixels',
    '🤖' => 'roboter',
    '😺' => 'gat che ri',
    '😸' => 'giat che ri cun egls che surrin',
    '😹' => 'giat cun larmas da plaschair',
    '😻' => 'giat che ri cun cors sco egls',
    '😼' => 'giat che ri cun bucca guerscha',
    '😽' => 'giat che dat in bitsch',
    '🙀' => 'giat spaventà',
    '😿' => 'giat che crida',
    '😾' => 'giat che fa il botsch',
    '🙈' => 'schimgia cun mauns davant ils egls',
    '🙉' => 'schimgia cun mauns sin las ureglias',
    '🙊' => 'schimgia che tegna la bucca',
    '💌' => 'brev d’amur',
    '💘' => 'cor cun frizza',
    '💝' => 'cor cun mascha',
    '💖' => 'cor che sbrinzla',
    '💗' => 'cor che crescha',
    '💓' => 'cor che batta',
    '💞' => 'cors che giran',
    '💕' => 'dus cors',
    '💟' => 'cor decorativ',
    '❣' => 'cor sco segn d’exclamaziun',
    '💔' => 'cor rut',
    '❤' => 'cor cotschen',
    '🩷' => 'cor rosa',
    '🧡' => 'cor oransch',
    '💛' => 'cor mellen',
    '💚' => 'cor verd',
    '💙' => 'cor blau',
    '🩵' => 'cor blau cler',
    '💜' => 'cor violet',
    '🤎' => 'cor brin',
    '🖤' => 'cor nair',
    '🩶' => 'cor grisch',
    '🤍' => 'cor alv',
    '💋' => 'lefs cotschens',
    '💯' => '100 puncts',
    '💢' => 'simbol da ravgia',
    '🫯' => 'nivel da cumbat',
    '💥' => 'collisiun',
    '💫' => 'sturn',
    '💦' => 'daguts da suaditsch',
    '💨' => 'nivel da pulvra',
    '🕳' => 'rusna',
    '💬' => 'nivletta cun trais puncts',
    '🗨' => 'nivletta a sanestra',
    '🗯' => 'nivletta gritta a dretga',
    '💭' => 'nivletta cun patratgs',
    '💤' => 'sien',
    '👋' => 'dar dal maun',
    '🤚' => 'dies dal maun auzà',
    '🖐' => 'maun avert',
    '✋' => 'maun auzà',
    '🖖' => 'salid vulcanic',
    '🫱' => 'maun che mussa a dretga',
    '🫲' => 'maun che mussa a sanestra',
    '🫳' => 'maun cun la palma engiu',
    '🫴' => 'maun cun la palma maun ensi',
    '🫷' => 'maun che stauscha a sanestra',
    '🫸' => 'maun che stauscha a dretga',
    '👌' => 'maun che mussa ok',
    '🤌' => 'maun cun pizza da la detta che sa tutga',
    '🤏' => 'maun che mussa pitschen',
    '✌' => 'gest victory',
    '🤞' => 'dus dets cruschads',
    '🫰' => 'gest per char',
    '🤟' => 'gest «jau t’am»',
    '🤘' => 'gest da cornas',
    '🤙' => 'gest da telefonar',
    '👈' => 'dies dal maun cun det che mussa a sanestra',
    '👉' => 'dies dal maun cun det che mussa a dretga',
    '👆' => 'dies dal maun cun det mussader vers ensi',
    '🖕' => 'det d’amez stendì',
    '👇' => 'dies dal maun cun det mussader vers engiu',
    '☝' => 'det mussader che mussa ensi',
    '🫵' => 'det mussader che mussa sin mai',
    '👍' => 'polesch che mussa ensi',
    '👎' => 'polesch che mussa engiu',
    '✊' => 'pugn ad aut',
    '👊' => 'pugn vers mai',
    '🤛' => 'pugn che mussa a sanestra',
    '🤜' => 'pugn che mussa a dretga',
    '👏' => 'mauns che applaudeschan',
    '🙌' => 'mauns auzads',
    '🫶' => 'mauns che furman in cor',
    '👐' => 'mauns averts',
    '🤲' => 'omaduas palmas-maun ina sper l’autra',
    '🤝' => 'dar il maun',
    '🙏' => 'palmas-maun ina sin l‘autra',
    '✍' => 'maun che scriva',
    '💅' => 'vernisch dad unglas',
    '🤳' => 'selfie',
    '💪' => 'biceps tendì',
    '🦾' => 'protesa da bratsch',
    '🦿' => 'protesa da chomma',
    '🦵' => 'chomma',
    '🦶' => 'pe',
    '👂' => 'ureglia',
    '🦻' => 'ureglia cun apparat d’udida',
    '👃' => 'nas',
    '🧠' => 'tscharvè',
    '🫀' => 'cor sco organ',
    '🫁' => 'pulmun',
    '🦷' => 'dent',
    '🦴' => 'oss',
    '👀' => 'egls',
    '👁' => 'egl',
    '👅' => 'lieunga',
    '👄' => 'bucca',
    '🫦' => 'morder il lef',
    '👶' => 'uffantin',
    '🧒' => 'uffant',
    '👦' => 'mattet',
    '👧' => 'mattetta',
    '🧑' => 'persuna',
    '👱' => 'persuna: chavels blonds',
    '👨' => 'um',
    '🧔' => 'persuna: barba',
    '👩' => 'dunna',
    '🧓' => 'persuna pli veglia',
    '👴' => 'um vegl',
    '👵' => 'dunna veglia',
    '🙍' => 'persuna malcuntenta',
    '🙎' => 'persuna permalada',
    '🙅' => 'persuna cun bratscha cruschada',
    '🙆' => 'persuna che tegna ils mauns sin il chau',
    '💁' => 'persuna che tegna la palma-maun vers ensi',
    '🙋' => 'persuna che auza il maun',
    '🧏' => 'persuna surda',
    '🙇' => 'persuna che s’enclina',
    '🤦' => 'persuna cun la palma-maun sin la fatscha',
    '🤷' => 'persuna che auza las spatlas',
    '👮' => 'policist:a',
    '🕵' => 'detectiv:a',
    '🥷' => 'ninja',
    '👷' => 'lavurer:a da construcziun',
    '🫅' => 'persuna cun curuna',
    '🤴' => 'prinzi',
    '👸' => 'princessa',
    '👳' => 'persuna cun in turban',
    '👲' => 'persuna cun in chapè chinais',
    '🧕' => 'dunna cun faziel da chau',
    '🤵' => 'persuna cun smoking',
    '👰' => 'persuna cun vel',
    '🤰' => 'dunna en speranza',
    '🫃' => 'um en speranza',
    '🫄' => 'persuna en speranza',
    '🤱' => 'dar latg',
    '👼' => 'anghelin',
    '🎅' => 'Son Niclà',
    '🤶' => 'Sontga Nicoletta',
    '🦸' => 'supererox:a',
    '🦹' => 'supernausch:a',
    '🧙' => 'striun:a',
    '🧚' => 'dial:a',
    '🧛' => 'vampir:a',
    '🧜' => 'uman da l’aua',
    '🧝' => 'elf:a',
    '🧞' => 'spiert da buttiglia',
    '🧟' => 'zombi',
    '🧌' => 'trol',
    '🫈' => 'creatira pailusa',
    '💆' => 'persuna che vegn massada',
    '💇' => 'persuna che sa lascha tagliar ils chavels',
    '🚶' => 'persuna che va a pe',
    '🧍' => 'persuna en pe',
    '🧎' => 'persuna en schanuglias',
    '🏃' => 'persuna che curra',
    '💃' => 'dunna che balla',
    '🕺' => 'um che balla',
    '🕴' => 'persuna en vestgì che levitescha',
    '👯' => 'persunas cun ureglias da lieur',
    '🧖' => 'persuna en ina stanza cun vapur',
    '🧗' => 'persuna che raiva',
    '🤺' => 'persuna che scrima',
    '🏇' => 'cursa da chavals',
    '⛷' => 'ir cun skis',
    '🏂' => 'snowboardist:a',
    '🏌' => 'persuna che dat golf',
    '🏄' => 'persuna che fa surfing',
    '🚣' => 'persuna che rembla',
    '🏊' => 'persuna che noda',
    '⛹' => 'persuna cun balla',
    '🏋' => 'persuna che auza pais',
    '🚴' => 'persuna che va cun velo',
    '🚵' => 'persuna che va cun mountainbike',
    '🤸' => 'persuna che fa la roda',
    '🤼' => 'persunas che lutgan',
    '🤽' => 'persuna che gioga ballanataziun',
    '🤾' => 'persuna che gioga ballamaun',
    '🤹' => 'persuna che schonglescha',
    '🧘' => 'persuna en la posiziun da lotos',
    '🛀' => 'persuna che fa bogn',
    '🛌' => 'persuna en letg',
    '👭' => 'dunnas che tegnan il maun',
    '👫' => 'dunna ed um che tegnan ils mauns',
    '👬' => 'umens che tegnan il maun',
    '💏' => 'bitsch',
    '💑' => 'pèr cun cor',
    '🗣' => 'chau che discurra',
    '👤' => 'schema foto da passaport',
    '👥' => 'schema da dus chaus',
    '🫂' => 'persunas che s’embratschan',
    '👪' => 'famiglia',
    '👣' => 'passidas',
    '🫆' => 'impronta dal det',
    '🦰' => 'chavels cotschens',
    '🦱' => 'chavels ritschads',
    '🦳' => 'chavels alvs',
    '🦲' => 'chau blut',
    '🐵' => 'fatscha da schimgia',
    '🐒' => 'schimgia',
    '🦍' => 'gorilla',
    '🦧' => 'orangutan',
    '🐶' => 'fatscha da chaun',
    '🐕' => 'chaun',
    '🦮' => 'chaun per tschorvs',
    '🐩' => 'pudel',
    '🐺' => 'luf',
    '🦊' => 'vulp',
    '🦝' => 'urset american',
    '🐱' => 'fatscha da giat',
    '🐈' => 'giat',
    '🦁' => 'liun',
    '🐯' => 'fatscha da tigher',
    '🐅' => 'tigher',
    '🐆' => 'leopard',
    '🐴' => 'chau da chaval',
    '🫎' => 'elan',
    '🫏' => 'asen',
    '🐎' => 'chaval',
    '🦄' => 'unicorn',
    '🦓' => 'zebra',
    '🦌' => 'tschierv',
    '🦬' => 'bison',
    '🐮' => 'chau da vatga',
    '🐂' => 'bov',
    '🐃' => 'biffel da l’aua',
    '🐄' => 'vatga',
    '🐷' => 'chau da portg',
    '🐖' => 'portg',
    '🐗' => 'portg selvadi',
    '🐽' => 'gnif da portg',
    '🐏' => 'botsch',
    '🐑' => 'nursa',
    '🐐' => 'chaura',
    '🐪' => 'dromedar',
    '🐫' => 'chamel',
    '🦙' => 'lama',
    '🦒' => 'giraffa',
    '🐘' => 'elefant',
    '🦣' => 'mamut',
    '🦏' => 'rinoceros',
    '🦛' => 'ippopotam',
    '🐭' => 'chau da mieur',
    '🐁' => 'mieur',
    '🐀' => 'ratun',
    '🐹' => 'raspun',
    '🐰' => 'chau da lieur',
    '🐇' => 'lieur',
    '🐿' => 'stgilat',
    '🦫' => 'castur',
    '🦔' => 'erizun',
    '🦇' => 'utschè-mezmieur',
    '🐻' => 'chau da l’urs',
    '🐨' => 'koala',
    '🐼' => 'panda',
    '🦥' => 'smarschun',
    '🦦' => 'ludra',
    '🦨' => 'scunc',
    '🦘' => 'kenguru',
    '🦡' => 'tais',
    '🐾' => 'fastizs',
    '🦃' => 'galdin',
    '🐔' => 'giaglina',
    '🐓' => 'cot',
    '🐣' => 'pulschain che vegn or da l’ov',
    '🐤' => 'pulschain',
    '🐥' => 'pulschain da davanten',
    '🐦' => 'utschè',
    '🐧' => 'pinguin',
    '🕊' => 'columba',
    '🦅' => 'evla',
    '🦆' => 'anda',
    '🦢' => 'cign',
    '🦉' => 'tschuetta',
    '🦤' => 'dodo',
    '🪶' => 'plima',
    '🦩' => 'flamingo',
    '🦚' => 'pavun',
    '🦜' => 'papagagl',
    '🪽' => 'ala',
    '🪿' => 'auca',
    '🐸' => 'rauna',
    '🐊' => 'crocodil',
    '🐢' => 'tartaruga',
    '🦎' => 'luschard',
    '🐍' => 'serp',
    '🐲' => 'chau da dragun',
    '🐉' => 'dragun',
    '🦕' => 'sauropod',
    '🦖' => 'tirannosaur',
    '🐳' => 'balena che squitta aua',
    '🐋' => 'balena',
    '🐬' => 'delfin',
    '🫍' => 'orca',
    '🦭' => 'foca',
    '🐟' => 'pesch',
    '🐠' => 'pesch tropic',
    '🐡' => 'pesch-ballun',
    '🦈' => 'squagl',
    '🐙' => 'octopus',
    '🐚' => 'chasa da la lindorna',
    '🪸' => 'cural',
    '🪼' => 'medusa',
    '🦀' => 'giomber',
    '🦞' => 'giomber da mar',
    '🦐' => 'crevetta',
    '🦑' => 'chalimar',
    '🦪' => 'austra',
    '🐌' => 'lindorna',
    '🦋' => 'tgiralla',
    '🐛' => 'rasulauna',
    '🐜' => 'furmia',
    '🐝' => 'avieul',
    '🪲' => 'bau',
    '🐞' => 'bau da Nossadunna',
    '🦗' => 'grigl',
    '🪳' => 'chamulauna da cuschina',
    '🕷' => 'filien',
    '🕸' => 'taila-filien',
    '🦂' => 'scorpiun',
    '🦟' => 'mosquito',
    '🪰' => 'mustga',
    '🪱' => 'verm',
    '🦠' => 'microba',
    '💐' => 'matg flurs',
    '🌸' => 'flur da tscharescha',
    '💮' => 'flur alva',
    '🪷' => 'flur da lotos',
    '🏵' => 'planta a rosettas',
    '🌹' => 'rosa',
    '🥀' => 'flur sflurida',
    '🌺' => 'ibiscus',
    '🌻' => 'flur-sulegl',
    '🌼' => 'flur',
    '🌷' => 'tulipana',
    '🪻' => 'giacinta',
    '🌱' => 'scherm',
    '🪴' => 'planta en vasch',
    '🌲' => 'pign',
    '🌳' => 'planta da feglia',
    '🌴' => 'palma',
    '🌵' => 'cactus',
    '🌾' => 'spia da ris',
    '🌿' => 'ervas',
    '☘' => 'traifegl',
    '🍀' => 'quatterfegl',
    '🍁' => 'fegl d’ischi',
    '🍂' => 'feglia',
    '🍃' => 'fegl che sgulatscha en il vent',
    '🪹' => 'igniv vid',
    '🪺' => 'igniv cun ovs',
    '🍄' => 'bulieu',
    '🪾' => 'planta senza feglia',
    '🍇' => 'iva',
    '🍈' => 'melona',
    '🍉' => 'melona d’aua',
    '🍊' => 'mandarina',
    '🍋' => 'citrona',
    '🍌' => 'banana',
    '🍍' => 'ananas',
    '🥭' => 'mango',
    '🍎' => 'mail cotschen',
    '🍏' => 'mail verd',
    '🍐' => 'pair',
    '🍑' => 'persic',
    '🍒' => 'tschareschas',
    '🍓' => 'fraja',
    '🫐' => 'izun',
    '🥝' => 'kiwi',
    '🍅' => 'tomata',
    '🫒' => 'uliva',
    '🥥' => 'nusch da cocos',
    '🥑' => 'avocado',
    '🍆' => 'oberschina',
    '🥔' => 'tartuffel',
    '🥕' => 'carotta',
    '🌽' => 'spia da tirc',
    '🌶' => 'chili',
    '🫑' => 'peperoni',
    '🥒' => 'cucumera',
    '🥬' => 'legums da feglia',
    '🥦' => 'broccoli',
    '🧄' => 'agl',
    '🧅' => 'tschagula',
    '🥜' => 'spagnoletta',
    '🫘' => 'fava',
    '🌰' => 'nitschola',
    '🫚' => 'ragisch da schentsch',
    '🫛' => 'arveglia',
    '🫜' => 'legums da ragisch',
    '🍞' => 'paun',
    '🥐' => 'stortin',
    '🥖' => 'baghet',
    '🫓' => 'paun plat',
    '🥨' => 'brezel',
    '🥯' => 'bagel',
    '🥞' => 'pancakes',
    '🧇' => 'guafla',
    '🧀' => 'chaschiel',
    '🍖' => 'charn cun oss',
    '🍗' => 'chalun-pulaster',
    '🥩' => 'toc charn',
    '🥓' => 'charnpiertg',
    '🍔' => 'hamburger',
    '🍟' => 'pomfrits',
    '🍕' => 'pizza',
    '🌭' => 'hotdog',
    '🥪' => 'sandwich',
    '🌮' => 'taco',
    '🌯' => 'burrito',
    '🫔' => 'tamale',
    '🥙' => 'kebab',
    '🧆' => 'falafel',
    '🥚' => 'ov',
    '🍳' => 'ov en paintg en ina padella',
    '🥘' => 'padella cun plat unì',
    '🍲' => 'avnaun cun legums',
    '🫕' => 'fondue',
    '🥣' => 'cuppa cun tschadun',
    '🥗' => 'salata',
    '🍿' => 'popcorn',
    '🧈' => 'paintg',
    '🧂' => 'sal',
    '🥫' => 'vivonda da conserva',
    '🍱' => 'boxa per la marenda',
    '🍘' => 'guafla da ris',
    '🍙' => 'culla da ris',
    '🍚' => 'ris cuschinà',
    '🍛' => 'curry cun ris',
    '🍜' => 'cuppa cun tratga e bastunets chinais',
    '🍝' => 'spaghets',
    '🍠' => 'patat dultsch',
    '🍢' => 'oden',
    '🍣' => 'sushi',
    '🍤' => 'crevetta frittada',
    '🍥' => 'fricadella da pesch cun spirala',
    '🥮' => 'turta da glina',
    '🍡' => 'dango',
    '🥟' => 'tastgina da pasta',
    '🥠' => 'biscuit da fortuna',
    '🥡' => 'stgatla per take-away',
    '🍦' => 'soft ice',
    '🍧' => 'glatsch d’aua',
    '🍨' => 'glatsch',
    '🍩' => 'donut',
    '🍪' => 'biscuit',
    '🎂' => 'turta d’anniversari',
    '🍰' => 'toc turta',
    '🧁' => 'cupcake',
    '🥧' => 'petta',
    '🍫' => 'tschigulatta',
    '🍬' => 'zutgerin',
    '🍭' => 'tschitsch',
    '🍮' => 'chau da caramella',
    '🍯' => 'magiel mel d’avieuls',
    '🍼' => 'clocca',
    '🥛' => 'magiel da latg',
    '☕' => 'bavronda chauda',
    '🫖' => 'cria da té',
    '🍵' => 'cuppin da té senza ureglia',
    '🍶' => 'saké',
    '🍾' => 'buttiglia cun cucun che siglia davent',
    '🍷' => 'magiel vin',
    '🍸' => 'coctail',
    '🍹' => 'coctail exotic',
    '🍺' => 'biera',
    '🍻' => 'viva cun buccaluns',
    '🥂' => 'far viva',
    '🥃' => 'magiel tumbler',
    '🫗' => 'derscher ora liquid',
    '🥤' => 'cup cun strom',
    '🧋' => 'bubble tea',
    '🧃' => 'pachet cun bavronda',
    '🧉' => 'mate',
    '🧊' => 'quadrin da glatsch',
    '🥢' => 'bastunets chinais',
    '🍽' => 'furtgetta e cuntè cun plat',
    '🍴' => 'furtgetta e cuntè',
    '🥄' => 'tschadun',
    '🔪' => 'cuntè da cuschina',
    '🫙' => 'confitura',
    '🏺' => 'amfora',
    '🌍' => 'globus che mussa l’Europa e l’Africa',
    '🌎' => 'globus che mussa l’America',
    '🌏' => 'globus che mussa l’Asia e l’Australia',
    '🌐' => 'globus cun meridians',
    '🗺' => 'charta dal mund',
    '🗾' => 'charta dal Giapun',
    '🧭' => 'cumpass',
    '🏔' => 'muntogna cuverta da naiv',
    '⛰' => 'muntogna',
    '🛘' => 'bova',
    '🌋' => 'vulcan',
    '🗻' => 'muntogna Fuji',
    '🏕' => 'campadi',
    '🏖' => 'splagia cun parasol',
    '🏜' => 'desert',
    '🏝' => 'insla solitaria',
    '🏞' => 'parc naziunal',
    '🏟' => 'stadion',
    '🏛' => 'edifizi antic',
    '🏗' => 'edifizi en construcziun',
    '🧱' => 'mir da quadrels',
    '🪨' => 'grip',
    '🪵' => 'lain',
    '🛖' => 'chamona',
    '🏘' => 'chasas',
    '🏚' => 'chasa en decadenza',
    '🏠' => 'chasa',
    '🏡' => 'chasa cun curtin',
    '🏢' => 'edifizi da biros',
    '🏣' => 'posta giapunaisa',
    '🏤' => 'posta',
    '🏥' => 'ospital',
    '🏦' => 'banca',
    '🏨' => 'hotel',
    '🏩' => 'hotel per ura',
    '🏪' => 'butietta da 24 uras',
    '🏫' => 'scola',
    '🏬' => 'negozi',
    '🏭' => 'fabrica',
    '🏯' => 'chastè giapunais',
    '🏰' => 'chastè',
    '💒' => 'nozzas',
    '🗼' => 'Tur da Tokyo',
    '🗽' => 'statua da la libertad',
    '⛪' => 'baselgia',
    '🕌' => 'moschea',
    '🛕' => 'tempel hinduistic',
    '🕍' => 'sinagoga',
    '⛩' => 'sanctuari schintoistic',
    '🕋' => 'kaaba',
    '⛲' => 'funtauna siglinta',
    '⛺' => 'tenda',
    '🌁' => 'brentinus',
    '🌃' => 'notg cun stailas',
    '🏙' => 'cuntrada urbana',
    '🌄' => 'levada dal sulegl en las muntognas',
    '🌅' => 'levada dal sulegl',
    '🌆' => 'citad sin il far notg',
    '🌇' => 'tramunt',
    '🌉' => 'punt da notg',
    '♨' => 'funtaunas chaudas',
    '🎠' => 'chaval da carussel',
    '🛝' => 'ruschnera',
    '🎡' => 'roda panoramica',
    '🎢' => 'rodaglia auta',
    '💈' => 'segn da barbier',
    '🎪' => 'tenda da circus',
    '🚂' => 'locomotiva',
    '🚃' => 'vagun',
    '🚄' => 'tren ad auta sveltezza',
    '🚅' => 'tren ad auta sveltezza cun nas radund',
    '🚆' => 'tren',
    '🚇' => 'metro',
    '🚈' => 'tren urban',
    '🚉' => 'staziun',
    '🚊' => 'tram',
    '🚝' => 'monorodaglia',
    '🚞' => 'viafier da muntogna',
    '🚋' => 'vagun da tram',
    '🚌' => 'bus',
    '🚍' => 'bus da davanten',
    '🚎' => 'trolleybus',
    '🚐' => 'minibus',
    '🚑' => 'ambulanza',
    '🚒' => 'auto da pumpiers',
    '🚓' => 'auto da polizia',
    '🚔' => 'auto da polizia che arriva',
    '🚕' => 'taxi',
    '🚖' => 'taxi da davanten',
    '🚗' => 'auto',
    '🚘' => 'auto da davanten',
    '🚙' => 'SUV',
    '🛻' => 'camiunetta',
    '🚚' => 'camiun',
    '🚛' => 'camiun-tractor',
    '🚜' => 'tractor',
    '🏎' => 'auto da cursa',
    '🏍' => 'moto',
    '🛵' => 'motoretta',
    '🦽' => 'sutga cun rodas manuala',
    '🦼' => 'sutga cun rodas electrica',
    '🛺' => 'mototaxi',
    '🚲' => 'velo',
    '🛴' => 'trottinet',
    '🛹' => 'skateboard',
    '🛼' => 'patins cun rodas',
    '🚏' => 'fermada dal bus',
    '🛣' => 'autostrada',
    '🛤' => 'rodaglias',
    '🛢' => 'butschin dad ieli',
    '⛽' => 'distributur da benzin',
    '🛞' => 'roda',
    '🚨' => 'glisch d’avertiment',
    '🚥' => 'ampla orizontala',
    '🚦' => 'ampla verticala',
    '🛑' => 'signal da stop',
    '🚧' => 'plazzal',
    '⚓' => 'ancra',
    '🛟' => 'rintg da salvament',
    '⛵' => 'bartga a vela',
    '🛶' => 'canu',
    '🚤' => 'bartga rapida',
    '🛳' => 'nav da passagiers',
    '⛴' => 'nav-fera',
    '🛥' => 'bartga a motor',
    '🚢' => 'bastiment',
    '✈' => 'aviun',
    '🛩' => 'pitschen aviun',
    '🛫' => 'partenza d’in aviun',
    '🛬' => 'atterrament d’in aviun',
    '🪂' => 'paracrudada',
    '💺' => 'sez',
    '🚁' => 'helicopter',
    '🚟' => 'viafier pendenta',
    '🚠' => 'teleferica',
    '🚡' => 'pendiculara',
    '🛰' => 'satellit',
    '🚀' => 'racheta',
    '🛸' => 'ufo',
    '🛎' => 'scalin d’hotel',
    '🧳' => 'bagascha',
    '⌛' => 'ura da sablun',
    '⏳' => 'ura da sablun che scurra',
    '⌚' => 'ura da bratsch',
    '⏰' => 'svegliarin',
    '⏱' => 'cronometer',
    '⏲' => 'ura d’ovs',
    '🕰' => 'ura da cheminé',
    '🕛' => 'las dudesch',
    '🕧' => 'las dudesch e mesa',
    '🕐' => 'l’ina',
    '🕜' => 'l’ina e mesa',
    '🕑' => 'las duas',
    '🕝' => 'las duas e mesa',
    '🕒' => 'las trais',
    '🕞' => 'las trais e mesa',
    '🕓' => 'las quatter',
    '🕟' => 'las quatter e mesa',
    '🕔' => 'las tschintg',
    '🕠' => 'las tschintg e mesa',
    '🕕' => 'las sis',
    '🕡' => 'las sis e mesa',
    '🕖' => 'las set',
    '🕢' => 'las set e mesa',
    '🕗' => 'las otg',
    '🕣' => 'las otg e mesa',
    '🕘' => 'las nov',
    '🕤' => 'las nov e mesa',
    '🕙' => 'las diesch',
    '🕥' => 'las diesch e mesa',
    '🕚' => 'las endisch',
    '🕦' => 'las endisch e mesa',
    '🌑' => 'glina nova',
    '🌒' => 'farcla glina creschenta',
    '🌓' => 'mesa glina creschenta',
    '🌔' => 'glina creschenta per trais quarts plaina',
    '🌕' => 'glina plaina',
    '🌖' => 'glina digren per trais quarts plaina',
    '🌗' => 'mesa glina digren',
    '🌘' => 'farcla glina digren',
    '🌙' => 'glina creschenta',
    '🌚' => 'fatscha glina nova',
    '🌛' => 'farcla da la glina creschenta cun fatscha',
    '🌜' => 'farcla da la glina digren cun fatscha',
    '🌡' => 'termometer',
    '☀' => 'sulegl',
    '🌝' => 'fatscha da glina plaina',
    '🌞' => 'sulegl cun fatscha',
    '🪐' => 'planet cun rintg',
    '⭐' => 'staila',
    '🌟' => 'staila che briglia',
    '🌠' => 'staila crudanta',
    '🌌' => 'via da latg',
    '☁' => 'nivel',
    '⛅' => 'sulegl davos in nivel',
    '⛈' => 'nivel cun chametg e plievgia',
    '🌤' => 'sulegl davos in pitschen nivel',
    '🌥' => 'sulegl davos in grond nivel',
    '🌦' => 'sulegl davos in nivel da plievgia',
    '🌧' => 'nivel cun plievgia',
    '🌨' => 'nivel cun scrottas da naiv',
    '🌩' => 'nivel cun chametg',
    '🌪' => 'tornado',
    '🌫' => 'tschajera',
    '🌬' => 'vent cun fatscha',
    '🌀' => 'ciclon',
    '🌈' => 'artg s. Martin',
    '🌂' => 'paraplievgia serrà',
    '☂' => 'paraplievgia',
    '☔' => 'paraplievgia cun daguts da plievgia',
    '⛱' => 'parasol sin il sablun',
    '⚡' => 'auta tensiun',
    '❄' => 'floc da naiv',
    '☃' => 'um da naiv cun flocs da naiv',
    '⛄' => 'um da naiv',
    '☄' => 'comet',
    '🔥' => 'fieu',
    '💧' => 'dagut',
    '🌊' => 'unda',
    '🎃' => 'zitga da Halloween',
    '🎄' => 'pignol da Nadal',
    '🎆' => 'fieu artifizial',
    '🎇' => 'chandaila magica',
    '🧨' => 'petarda chastrada',
    '✨' => 'sbrinzlas',
    '🎈' => 'ballun',
    '🎉' => 'bumba da confettis',
    '🎊' => 'confettis',
    '🎋' => 'planta da tanabata',
    '🎍' => 'bambus decorà',
    '🎎' => 'poppas giapunaisas',
    '🎏' => 'dragun da carpas',
    '🎐' => 'carillon da vent',
    '🎑' => 'ceremonia da contemplaziun da la glina',
    '🧧' => 'busta cotschna',
    '🎀' => 'mascha',
    '🎁' => 'regal',
    '🎗' => 'mascha da regurdanza',
    '🎟' => 'bigliets d’entrada',
    '🎫' => 'bigliet',
    '🎖' => 'medaglia militara',
    '🏆' => 'pocal',
    '🏅' => 'medaglia da sport',
    '🥇' => 'medaglia d’aur',
    '🥈' => 'medaglia d’argient',
    '🥉' => 'medaglia da bronz',
    '⚽' => 'balla da ballape',
    '⚾' => 'balla da baseball',
    '🥎' => 'balla da softball',
    '🏀' => 'balla-basket',
    '🏐' => 'balla-volley',
    '🏈' => 'balla dad american football',
    '🏉' => 'balla da rugby',
    '🎾' => 'tennis',
    '🥏' => 'frisbee',
    '🎳' => 'bowling',
    '🏏' => 'crichet',
    '🏑' => 'unihockey',
    '🏒' => 'hockey sin glatsch',
    '🥍' => 'lacrosse',
    '🏓' => 'pingpong',
    '🏸' => 'badminton',
    '🥊' => 'guant da boxar',
    '🥋' => 'mandura da sports da cumbat',
    '🥅' => 'gol',
    '⛳' => 'bandiera da golf',
    '⛸' => 'patin',
    '🎣' => 'pertga cun pesch',
    '🤿' => 'mascra da sfunsar',
    '🎽' => 'chamischola da currer',
    '🎿' => 'skis',
    '🛷' => 'scarsola',
    '🥌' => 'crap da curling',
    '🎯' => 'schiba da darts',
    '🪀' => 'jojo',
    '🔫' => 'pistola d’aua',
    '🎱' => 'culla da bigliard',
    '🔮' => 'culla da cristal',
    '🪄' => 'batgetta magica',
    '🎮' => 'controller',
    '🕹' => 'joystick',
    '🎰' => 'automat da gieu',
    '🎲' => 'dat da gieu',
    '🧩' => 'toc da puzzle',
    '🧸' => 'urset',
    '🪅' => 'piñata',
    '🪩' => 'culla da disco',
    '🪆' => 'matroschka',
    '♠' => 'palas',
    '♥' => 'cors',
    '♦' => 'pizs',
    '♣' => 'cruschs',
    '♟' => 'figura da schah',
    '🃏' => 'joker',
    '🀄' => 'dragun cotschen mahjong',
    '🎴' => 'carta da gieu cun flurs',
    '🎭' => 'mascras',
    '🖼' => 'maletg enramà',
    '🎨' => 'paletta da colurs',
    '🧵' => 'spol da fil',
    '🪡' => 'guglia da cuser',
    '🧶' => 'chanè da launa',
    '🪢' => 'nuf',
    '👓' => 'egliers',
    '🕶' => 'egliers da sulegl',
    '🥽' => 'egliers da protecziun',
    '🥼' => 'scussal da labor',
    '🦺' => 'vesta da segirezza',
    '👔' => 'cravatta',
    '👕' => 't-shirt',
    '👖' => 'jeans',
    '🧣' => 'schal',
    '🧤' => 'guants',
    '🧥' => 'mantè',
    '🧦' => 'soccas',
    '👗' => 'vestgì',
    '👘' => 'kimono',
    '🥻' => 'sari',
    '🩱' => 'vestgì da bogn en in toc',
    '🩲' => 'slip',
    '🩳' => 'schorts',
    '👙' => 'bikini',
    '👚' => 'resti da dunnas',
    '🪭' => 'ventagl',
    '👛' => 'bursa',
    '👜' => 'tastga da maun',
    '👝' => 'tastgetta da maun',
    '🛍' => 'satgs',
    '🎒' => 'satgados',
    '🩴' => 'flip-flops',
    '👞' => 'chalzer dad umens',
    '👟' => 'chalzer da sport',
    '🥾' => 'chalzers da viandar',
    '🥿' => 'chalzer plat',
    '👠' => 'chalzer cun tatg aut',
    '👡' => 'sandala da dunnas',
    '🩰' => 'chalzers da ballet',
    '👢' => 'stivals da dunnas',
    '🪮' => 'petgen afro',
    '👑' => 'curuna',
    '👒' => 'chapè da dunnas',
    '🎩' => 'cilinder',
    '🎓' => 'chapè universitar',
    '🧢' => 'chapè da baseball',
    '🪖' => 'chapellina militara',
    '⛑' => 'chapellina cun crusch alva',
    '📿' => 'rusari',
    '💄' => 'lefzagl',
    '💍' => 'anè',
    '💎' => 'pedra preziusa',
    '🔇' => 'autpledader deactivà',
    '🔈' => 'autpledader da bass',
    '🔉' => 'autpledader cun volumen mesaun',
    '🔊' => 'autpledader dad aut',
    '📢' => 'autpledader',
    '📣' => 'megafon',
    '📯' => 'corn da postigliun',
    '🔔' => 'brunsina',
    '🔕' => 'brunsina deactivada',
    '🎼' => 'clav da violina',
    '🎵' => 'nota musicala',
    '🎶' => 'notas musicalas',
    '🎙' => 'microfon da studio',
    '🎚' => 'reglader ruschnant',
    '🎛' => 'regladers rotativs',
    '🎤' => 'microfon',
    '🎧' => 'uregliers',
    '📻' => 'radio',
    '🎷' => 'saxofon',
    '🎺' => 'trumbetta',
    '🪊' => 'posauna',
    '🪗' => 'accordeon',
    '🎸' => 'ghitarra',
    '🎹' => 'claviatura',
    '🎻' => 'gìa',
    '🪕' => 'banjo',
    '🥁' => 'schumber',
    '🪘' => 'schumber conga',
    '🪇' => 'maracas',
    '🪈' => 'flauta',
    '🪉' => 'arpa',
    '📱' => 'telefonin',
    '📲' => 'telefonin cun frizza',
    '☎' => 'telefon',
    '📞' => 'corn dal telefon',
    '📟' => 'pager',
    '📠' => 'fax',
    '🔋' => 'battaria',
    '🪫' => 'battaria vida',
    '🔌' => 'spina',
    '💻' => 'laptop',
    '🖥' => 'computer desktop',
    '🖨' => 'stampader',
    '⌨' => 'tastatura',
    '🖱' => 'mieur dal computer',
    '🖲' => 'trackball',
    '💽' => 'minidisc',
    '💾' => 'floppydisc',
    '💿' => 'DC',
    '📀' => 'DVD',
    '🧮' => 'abacus',
    '🎥' => 'camera',
    '🎞' => 'bindel da film',
    '📽' => 'projectur da films',
    '🎬' => 'clappa da film',
    '📺' => 'televisiun',
    '📷' => 'apparat da fotografar',
    '📸' => 'apparat da fotografar cun chametg',
    '📹' => 'camera da video',
    '📼' => 'videocassetta',
    '🔍' => 'marella a sanestra',
    '🔎' => 'marella a dretga',
    '🕯' => 'chandaila',
    '💡' => 'pair electric',
    '🔦' => 'lampa da maun',
    '🏮' => 'laterna da palpiri cotschna',
    '🪔' => 'glisch dad ieli',
    '📔' => 'cudeschet da notizias cun liadira decorativa',
    '📕' => 'cudesch serrà',
    '📖' => 'cudesch avert',
    '📗' => 'cudesch verd',
    '📘' => 'cudesch blau',
    '📙' => 'cudesch oransch',
    '📚' => 'cudeschs',
    '📓' => 'cudeschet da notizias',
    '📒' => 'carnet a spirala',
    '📃' => 'fegl rudlà en',
    '📜' => 'pergiamina rullada',
    '📄' => 'vart davant dad in fegl',
    '📰' => 'gasetta',
    '🗞' => 'gasetta rudlada en',
    '📑' => 'segnapaginas che tatgan',
    '🔖' => 'segnapagina',
    '🏷' => 'etichetta',
    '🪙' => 'munaida',
    '💰' => 'satg cun daners',
    '🪎' => 'trucca da stgazis',
    '💴' => 'bancnota yen',
    '💵' => 'bancnota dollar',
    '💶' => 'bancnota euro',
    '💷' => 'bancnota glivra sterlina',
    '💸' => 'daners cun alas',
    '💳' => 'carta da credit',
    '🧾' => 'quittanza',
    '💹' => 'curs creschent cun yen',
    '✉' => 'cuverta',
    '📧' => 'e-mail',
    '📨' => 'cuverta che arriva',
    '📩' => 'cuverta cun frizza',
    '📤' => 'posta sortida',
    '📥' => 'posta entrada',
    '📦' => 'pac',
    '📫' => 'chascha da brevs serrada cun posta',
    '📪' => 'chascha da brevs serrada senza posta',
    '📬' => 'chascha da brevs averta cun posta',
    '📭' => 'chascha da brevs averta senza posta',
    '📮' => 'chascha da posta',
    '🗳' => 'urna cun cedel da votar',
    '✏' => 'rispli',
    '✒' => 'stilograf nair',
    '🖋' => 'penna',
    '🖊' => 'culli',
    '🖌' => 'penel',
    '🖍' => 'colur da tschaira',
    '📝' => 'notizia',
    '💼' => 'mappa d’actas',
    '📁' => 'dossier',
    '📂' => 'dossier avert',
    '🗂' => 'chavallets',
    '📅' => 'chalender',
    '📆' => 'chalender da fegliets',
    '🗒' => 'bloc da notizias cun spirala',
    '🗓' => 'chalender cun spirala',
    '📇' => 'cartoteca',
    '📈' => 'graf ascendent',
    '📉' => 'graf descendent',
    '📊' => 'diagram a travs',
    '📋' => 'tegnafegls',
    '📌' => 'pidera',
    '📍' => 'gluva',
    '📎' => 'fermagl',
    '🖇' => 'fermagls entretschads',
    '📏' => 'lingera',
    '📐' => 'geotriangul',
    '✂' => 'forsch',
    '🗃' => 'cartoteca en ina stgatla',
    '🗄' => 'stgaffa d’actas',
    '🗑' => 'chanaster da palpiri',
    '🔒' => 'marschlos serrà',
    '🔓' => 'marschlos avert',
    '🔏' => 'marschlos cun stilograf',
    '🔐' => 'marschlos cun clav',
    '🔑' => 'clav',
    '🗝' => 'clav veglia',
    '🔨' => 'martè',
    '🪓' => 'manera',
    '⛏' => 'zappun',
    '⚒' => 'martè e mazzot',
    '🛠' => 'martè e clav da struvas',
    '🗡' => 'stilet',
    '⚔' => 'spadas cruschadas',
    '💣' => 'bumba',
    '🪃' => 'bumerang',
    '🏹' => 'artg cun frizza',
    '🛡' => 'scut',
    '🪚' => 'resgia a maun',
    '🔧' => 'clav da struvas',
    '🪛' => 'tirastruvas',
    '🔩' => 'struva cun vaira',
    '⚙' => 'roda dentada',
    '🗜' => 'serraditscha',
    '⚖' => 'ballantscha',
    '🦯' => 'channa da tschorvs',
    '🔗' => 'colliaziun',
    '⛓' => 'chadainas',
    '🪝' => 'crutsch',
    '🧰' => 'chascha d’utensils',
    '🧲' => 'magnet',
    '🪜' => 'stgala',
    '🪏' => 'badigl',
    '⚗' => 'alambic',
    '🧪' => 'vaider da reagenza',
    '🧫' => 'cuppina da Petri',
    '🧬' => 'ADN',
    '🔬' => 'microscop',
    '🔭' => 'telescop',
    '📡' => 'antenna parabolica',
    '💉' => 'squitta',
    '🩸' => 'gut da sang',
    '💊' => 'tabletta',
    '🩹' => 'plaster',
    '🩼' => 'crutscha',
    '🩺' => 'stetoscop',
    '🩻' => 'radiografia',
    '🚪' => 'isch',
    '🛗' => 'ascensur',
    '🪞' => 'spievel',
    '🪟' => 'fanestra',
    '🛏' => 'letg',
    '🛋' => 'canapé cun lampa',
    '🪑' => 'sutga',
    '🚽' => 'tualetta',
    '🪠' => 'tschitschader',
    '🚿' => 'duscha',
    '🛁' => 'bognera',
    '🪤' => 'trapla da mieurs',
    '🪒' => 'rasuir',
    '🧴' => 'buttiglia da loziun',
    '🧷' => 'gluva da serra',
    '🧹' => 'scua',
    '🧺' => 'chanaster',
    '🧻' => 'rolla da cuschina',
    '🪣' => 'sadella',
    '🧼' => 'savun',
    '🫧' => 'borlas da savun',
    '🪥' => 'barschun da dents',
    '🧽' => 'spungia',
    '🧯' => 'stizzafieu',
    '🛒' => 'charret da cumpras',
    '🚬' => 'cigaretta',
    '⚰' => 'vaschè',
    '🪦' => 'crap da fossa',
    '⚱' => 'urna',
    '🧿' => 'amulet da nazar',
    '🪬' => 'hamsa',
    '🗿' => 'moai',
    '🪧' => 'tavla da protest',
    '🪪' => 'carta d’identitad',
    '🏧' => 'segn automat da daners',
    '🚮' => 'simbol chanaster da palpiri',
    '🚰' => 'aua da baiver',
    '♿' => 'simbol sutga cun rodas',
    '🚹' => 'tualetta d’umens',
    '🚺' => 'tualetta da dunnas',
    '🚼' => 'simbol poppa',
    '🚾' => 'WC',
    '🛂' => 'controlla da passaport',
    '🛃' => 'controlla da duana',
    '🛄' => 'distribuziun da bagascha',
    '🛅' => 'deposit da bagascha',
    '⚠' => 'avertiment',
    '🚸' => 'uffants traversan la via',
    '⛔' => 'nagin access',
    '🚫' => 'scumandà',
    '🚳' => 'scumond da velos',
    '🚭' => 'scumandà da fimar',
    '🚯' => 'scumandà da deponer rument',
    '🚱' => 'aua betg da baiver',
    '🚷' => 'scumandà per peduns',
    '📵' => 'scumond per telefonins',
    '🔞' => 'scumandà per minorens',
    '☢' => 'radioactiv',
    '☣' => 'signal da privel biologic',
    '⬆' => 'frizza ensi',
    '↗' => 'frizza vers sura a dretga',
    '➡' => 'frizza a dretga',
    '↘' => 'frizza vers sut a dretga',
    '⬇' => 'frizza engiu',
    '↙' => 'frizza vers sut a sanestra',
    '⬅' => 'frizza a sanestra',
    '↖' => 'frizza vers sura a sanestra',
    '↕' => 'frizza ensi ed engiu',
    '↔' => 'frizza a dretga ed a sanestra',
    '↩' => 'frizza curvada a sanestra',
    '↪' => 'frizza curvada a dretga',
    '⤴' => 'frizza curvada ensi',
    '⤵' => 'frizza curvada engiu',
    '🔃' => 'frizzas circularas en direcziun da l’ura',
    '🔄' => 'frizzas circularas en senn cuntrari a l’ura',
    '🔙' => 'frizza BACK',
    '🔚' => 'frizza END',
    '🔛' => 'frizza ON!',
    '🔜' => 'frizza SOON',
    '🔝' => 'frizza TOP',
    '🛐' => 'lieu religius',
    '⚛' => 'simbol d’atom',
    '🕉' => 'om',
    '✡' => 'staila da David',
    '☸' => 'roda da Dharma',
    '☯' => 'yin e yang',
    '✝' => 'crusch latina',
    '☦' => 'crusch ortodoxa',
    '☪' => 'farcla da la glina cun staila',
    '☮' => 'segn da pasch',
    '🕎' => 'menora',
    '🔯' => 'hexagram cun punct',
    '🪯' => 'khanda',
    '♈' => 'Botsch',
    '♉' => 'Taur',
    '♊' => 'Schumellins',
    '♋' => 'Giomber',
    '♌' => 'Liun',
    '♍' => 'Giuvintschella',
    '♎' => 'Stadaira',
    '♏' => 'Scorpiun',
    '♐' => 'Tiradur',
    '♑' => 'Capricorn',
    '♒' => 'Um da l’aua',
    '♓' => 'Peschs',
    '⛎' => 'Portaserps',
    '🔀' => 'modus casual',
    '🔁' => 'repeter',
    '🔂' => 'repeter il toc',
    '▶' => 'reproducziun',
    '⏩' => 'buttun d’avanzament svelt',
    '⏭' => 'buttun proxim toc',
    '⏯' => 'buttun per far ir u interrumper',
    '◀' => 'buttun revers',
    '⏪' => 'buttun da returnar svelt',
    '⏮' => 'buttun ultim toc',
    '🔼' => 'buttun ensi',
    '⏫' => 'buttun svelt ensi',
    '🔽' => 'buttun engiu',
    '⏬' => 'buttun svelt engiu',
    '⏸' => 'buttun da pausa',
    '⏹' => 'buttun per fermar',
    '⏺' => 'buttun per registrar',
    '⏏' => 'buttun per bittar ora',
    '🎦' => 'kino',
    '🔅' => 'buttun stgirentar',
    '🔆' => 'buttun sclerentar',
    '📶' => 'travs da rait',
    '🛜' => 'senza fil',
    '📳' => 'modus da vibraziun',
    '📴' => 'telefonin ord funcziun',
    '♀' => 'simbol da las dunnas',
    '♂' => 'simbol masculin',
    '⚧' => 'simbol transgender',
    '✖' => 'multiplicaziun',
    '➕' => 'plus',
    '➖' => 'minus',
    '➗' => 'divider',
    '🟰' => 'egual',
    '♾' => 'infinit',
    '‼' => 'segn d’exclamaziun dubel',
    '⁉' => 'segn d’exclamaziun e da dumonda',
    '❓' => 'segn da dumonda cotschen',
    '❔' => 'segn da dumonda alv',
    '❕' => 'segn d’exclamaziun alv',
    '❗' => 'segn d’exclamaziun cotschen',
    '〰' => 'lingia ondulada',
    '💱' => 'stgomi da daners',
    '💲' => 'segn da dollar',
    '⚕' => 'bastun d’Esculap',
    '♻' => 'simbol da recicladi',
    '⚜' => 'gilgia eraldica',
    '🔱' => 'trianza',
    '📛' => 'tavla dal num',
    '🔰' => 'simbol giapunais per principiants',
    '⭕' => 'rudè vid cotschen',
    '✅' => 'crutschet controllà',
    '☑' => 'quadrat cun crutschet',
    '✔' => 'crutschet grass',
    '❌' => 'crusch per marcar',
    '❎' => 'buttun cun crusch',
    '➰' => 'latsch',
    '➿' => 'latsch dubel',
    '〽' => 'simbol dad alternanza da las parts',
    '✳' => 'asterisc cun otg radis',
    '✴' => 'staila cun otg radis',
    '❇' => 'sbrinzlar',
    '™' => 'marca',
    '🫟' => 'flatg',
    '🔠' => 'buttun cun maiusclas latinas',
    '🔡' => 'buttun cun minusclas latinas',
    '🔢' => 'buttun cun cifras',
    '🔣' => 'buttun cun simbols',
    '🔤' => 'buttun cun letras latinas',
    '🅰' => 'buttun A (gruppa da sang)',
    '🆎' => 'buttun AB (gruppa da sang)',
    '🅱' => 'buttun B (gruppa da sang)',
    '🆑' => 'buttun CL',
    '🆒' => 'buttun COOL',
    '🆓' => 'buttun FREE',
    'ℹ' => 'infurmaziun',
    '🆔' => 'buttun ID',
    'Ⓜ' => 'M en rudè',
    '🆕' => 'buttun NEW',
    '🆖' => 'buttun NG',
    '🅾' => 'buttun 0 (gruppa da sang)',
    '🆗' => 'buttun OK',
    '🅿' => 'buttun P',
    '🆘' => 'buttun SOS',
    '🆙' => 'buttun UP!',
    '🆚' => 'buttun VS',
    '🈁' => 'buttun giapunais «qua»',
    '🈂' => 'buttun giapunais «custs dal servetsch»',
    '🈷' => 'buttun giapunais «import mensil»',
    '🈶' => 'buttun giapunais «betg gratuit»',
    '🈯' => 'buttun giapunais «reservà»',
    '🉐' => 'buttun giapunais «sgnappet»',
    '🈹' => 'buttun giapunais «rabat»',
    '🈚' => 'buttun giapunais «gratuit»',
    '🈲' => 'buttun giapunais «scumandà»',
    '🉑' => 'buttun giapunais «acceptabel»',
    '🈸' => 'buttun giapunais «applicaziun»',
    '🈴' => 'buttun giapunais «nota cun success»',
    '🈳' => 'buttun giapunais «chombras libras»',
    '㊗' => 'buttun giapunais «gratulaziun»',
    '㊙' => 'buttun giapunais «secret»',
    '🈺' => 'buttun giapunais «avert»',
    '🈵' => 'buttun giapunais «naginas chombras libras»',
    '🔴' => 'rudè cotschen',
    '🟠' => 'rudè oransch',
    '🟡' => 'rudè mellen',
    '🟢' => 'rudè verd',
    '🔵' => 'rudè blau',
    '🟣' => 'rudè violet',
    '🟤' => 'rudè brin',
    '⚫' => 'rudè nair',
    '⚪' => 'rudè alv',
    '🟥' => 'quadrat cotschen',
    '🟧' => 'quadrat oransch',
    '🟨' => 'quadrat mellen',
    '🟩' => 'quadrat verd',
    '🟦' => 'quadrat blau',
    '🟪' => 'quadrat violet',
    '🟫' => 'quadrat brin',
    '⬛' => 'quadrat nair grond',
    '⬜' => 'quadrat alv grond',
    '◼' => 'quadrat nair mesaun',
    '◻' => 'quadrat alv mesaun',
    '◾' => 'quadrat nair mesaun-pitschen',
    '◽' => 'quadrat alv mesaun-pitschen',
    '▪' => 'quadrat nair pitschen',
    '▫' => 'quadrat alv pitschen',
    '🔶' => 'piz oransch grond',
    '🔷' => 'piz blau grond',
    '🔸' => 'piz oransch pitschen',
    '🔹' => 'piz blau pitschen',
    '🔺' => 'triangul cotschen che mussa ensi',
    '🔻' => 'triangul cotschen che mussa engiu',
    '💠' => 'piz cun in punct amez',
    '🔘' => 'buttun d’opziun',
    '🔳' => 'buttun quadratic alv',
    '🔲' => 'buttun quadratic nair',
    '🏁' => 'bandiera cun muster da schah',
    '🚩' => 'bandiera cotschna triangulara',
    '🎌' => 'bandieras cruschadas',
    '🏴' => 'bandiera naira',
    '🏳' => 'bandiera alva',
];
